/*
* Copyright 2020 elementary, Inc. (https://elementary.io)
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public
* License as published by the Free Software Foundation; either
* version 3 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
* Boston, MA 02110-1301 USA.
*/
@define-color STRAWBERRY_100 #ff8c82;
@define-color STRAWBERRY_300 #ed5353;
@define-color STRAWBERRY_500 #c6262e;
@define-color STRAWBERRY_700 #a10705;
@define-color STRAWBERRY_900 #7a0000;
@define-color ORANGE_100 #ffc27d;
@define-color ORANGE_300 #ffa154;
@define-color ORANGE_500 #f37329;
@define-color ORANGE_700 #cc3b02;
@define-color ORANGE_900 #a62100;
@define-color BANANA_100 #fff394;
@define-color BANANA_300 #ffe16b;
@define-color BANANA_500 #f9c440;
@define-color BANANA_700 #d48e15;
@define-color BANANA_900 #ad5f00;
@define-color LIME_100 #d1ff82;
@define-color LIME_300 #9bdb4d;
@define-color LIME_500 #68b723;
@define-color LIME_700 #3a9104;
@define-color LIME_900 #206b00;
@define-color MINT_100 #89ffdd;
@define-color MINT_300 #43d6b5;
@define-color MINT_500 #28bca3;
@define-color MINT_700 #0e9a83;
@define-color MINT_900 #007367;
@define-color BLUEBERRY_100 #8cd5ff;
@define-color BLUEBERRY_300 #64baff;
@define-color BLUEBERRY_500 #3689e6;
@define-color BLUEBERRY_700 #0d52bf;
@define-color BLUEBERRY_900 #002e99;
@define-color BUBBLEGUM_100 #fe9ab8;
@define-color BUBBLEGUM_300 #f4679d;
@define-color BUBBLEGUM_500 #de3e80;
@define-color BUBBLEGUM_700 #bc245d;
@define-color BUBBLEGUM_900 #910e38;
@define-color GRAPE_100 #e4c6fa;
@define-color GRAPE_300 #cd9ef7;
@define-color GRAPE_500 #a56de2;
@define-color GRAPE_700 #7239b3;
@define-color GRAPE_900 #452981;
@define-color COCOA_100 #a3907c;
@define-color COCOA_300 #8a715e;
@define-color COCOA_500 #715344;
@define-color COCOA_700 #57392d;
@define-color COCOA_900 #3d211b;
@define-color SILVER_100 #fafafa;
@define-color SILVER_300 #d4d4d4;
@define-color SILVER_500 #abacae;
@define-color SILVER_700 #7e8087;
@define-color SILVER_900 #555761;
@define-color SLATE_100 #95a3ab;
@define-color SLATE_300 #667885;
@define-color SLATE_500 #485a6c;
@define-color SLATE_700 #273445;
@define-color SLATE_900 #0e141f;
@define-color BLACK_100 #666;
@define-color BLACK_300 #4d4d4d;
@define-color BLACK_500 #333;
@define-color BLACK_700 #1a1a1a;
@define-color BLACK_900 #000;
@define-color LATTE_100 #efdfc4;
@define-color LATTE_300 #e7c591;
@define-color LATTE_500 #cfa25e;
@define-color LATTE_700 #b6802e;
@define-color LATTE_900 #804b00;
/* Accent Shades */
@define-color accent_color_100 @BUBBLEGUM_100;
@define-color accent_color_300 @BUBBLEGUM_300;
@define-color accent_color_500 @BUBBLEGUM_500;
@define-color accent_color_700 @BUBBLEGUM_700;
@define-color accent_color_900 @BUBBLEGUM_900;
@define-color accent_color mix(@BUBBLEGUM_300, @BUBBLEGUM_500, 0.5);
actionbar,
.bottom-toolbar, switch slider, switch:checked:not(.mode-switch):not(:backdrop), scale slider, progressbar.horizontal progress:backdrop, progressbar.horizontal trough, levelbar.horizontal block, headerbar, .color-button check,
.color-button check:checked,
.color-button radio,
.color-button radio:checked, check,
radio, .linked button.flat, .linked .sidebar .inline-toolbar button, .linked .sidebar actionbar.flat button,
.linked .sidebar .bottom-toolbar.flat button,
.linked .sidebar window.preferences.csd headerbar.bottom-toolbar button,
window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button,
.linked .sidebar .dialog.csd > headerbar.bottom-toolbar button,
.linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button,
bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button,
.linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button,
floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button,
.linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button,
.linked .sidebar window.csd.about > headerbar.bottom-toolbar button,
popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button, .sidebar .inline-toolbar .linked button, .sidebar actionbar.flat .linked button,
.sidebar .bottom-toolbar.flat .linked button,
.sidebar window.preferences.csd headerbar.bottom-toolbar .linked button,
window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button,
.sidebar .dialog.csd > headerbar.bottom-toolbar .linked button,
.sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button,
bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button,
.sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button,
floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button,
.sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button,
.sidebar window.csd.about > headerbar.bottom-toolbar .linked button, .linked .sidebar popover.emoji-picker .emoji-toolbar button, .sidebar popover.emoji-picker .emoji-toolbar .linked button, .linked popover.emoji-picker .sidebar .emoji-toolbar button, popover.emoji-picker .sidebar .emoji-toolbar .linked button, .linked button.image-button, .linked button.image-button:not(.text-button), button.circular.image-button, button.model.image-button, button.raised.image-button, button.raised, .messagedialog .response-area button, button, avatar {
  background-image: linear-gradient(to bottom, alpha(@highlight_color, 0.2), rgba(255, 255, 255, 0)); }
  actionbar:backdrop,
  .bottom-toolbar:backdrop, switch slider:backdrop, switch:backdrop:checked:not(.mode-switch):not(:backdrop), scale slider:backdrop, progressbar.horizontal progress:backdrop, progressbar.horizontal trough:backdrop, levelbar.horizontal block:backdrop, headerbar:backdrop, check:backdrop,
  radio:backdrop, .linked button.flat:backdrop, .linked .sidebar .inline-toolbar button:backdrop, .linked .sidebar actionbar.flat button:backdrop,
  .linked .sidebar .bottom-toolbar.flat button:backdrop,
  .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button:backdrop,
  window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button:backdrop,
  .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button:backdrop,
  .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:backdrop,
  bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button:backdrop,
  .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:backdrop,
  floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button:backdrop,
  .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button:backdrop,
  .linked .sidebar window.csd.about > headerbar.bottom-toolbar button:backdrop,
  popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button:backdrop, .sidebar .inline-toolbar .linked button:backdrop, .sidebar actionbar.flat .linked button:backdrop,
  .sidebar .bottom-toolbar.flat .linked button:backdrop,
  .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button:backdrop,
  window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button:backdrop,
  .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button:backdrop,
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button:backdrop,
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button:backdrop,
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button:backdrop,
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button:backdrop,
  .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button:backdrop,
  .sidebar window.csd.about > headerbar.bottom-toolbar .linked button:backdrop, .linked .sidebar popover.emoji-picker .emoji-toolbar button:backdrop, .sidebar popover.emoji-picker .emoji-toolbar .linked button:backdrop, .linked popover.emoji-picker .sidebar .emoji-toolbar button:backdrop, popover.emoji-picker .sidebar .emoji-toolbar .linked button:backdrop, .linked button.image-button:backdrop, button.circular.image-button:backdrop, button.model.image-button:backdrop, button.raised:backdrop, .messagedialog .response-area button:backdrop, button:backdrop, avatar:backdrop {
    background-image: linear-gradient(to bottom, alpha(@highlight_color, 0.35), alpha(@highlight_color, 0.3)); }

progressbar.vertical progress,
progressbar.vertical trough, levelbar.vertical block {
  background-image: linear-gradient(to right, alpha(@highlight_color, 0.2), rgba(255, 255, 255, 0)); }
  progressbar.vertical progress:backdrop,
  progressbar.vertical trough:backdrop, levelbar.vertical block:backdrop {
    background-image: linear-gradient(to right, alpha(@highlight_color, 0.35), alpha(@highlight_color, 0.3)); }

.spin {
  animation: spin 600ms linear infinite; }

@keyframes spin {
  to {
    -gtk-icon-transform: rotate(1turn); } }

@define-color highlight_color white;
@define-color highlight_color rgba(255, 255, 255, 0.2);
@define-color color_primary #2a2a2a;
@define-color placeholder_text_color #cecece;
@define-color error_color #ed5353;
@define-color success_color #9bdb4d;
@define-color warning_color #fff394;
@define-color menu_separator rgba(0, 0, 0, 0.15);
@define-color menu_separator_shadow rgba(255, 255, 255, 0.8);
@define-color selected_bg_color alpha(@accent_color, 0.25);
@define-color selected_fg_color shade(@accent_color, 0.5);
@define-color theme_unfocused_selected_bg_color alpha(@text_color, 0.10);
@define-color theme_unfocused_selected_fg_color white;
@define-color tab_base_color #3a3a3a;
@define-color menu_separator rgba(0, 0, 0, 0.35);
@define-color menu_separator_shadow rgba(255, 255, 255, 0.05);
@define-color selected_bg_color alpha(shade(@accent_color, 0.85), 0.5);
@define-color selected_fg_color mix(shade(@accent_color, 1.1), white, 0.75);
@define-color tab_base_color #333;
@define-color base_color #3a3a3a;
@define-color theme_base_color #3a3a3a;
@define-color theme_unfocused_base_color #3a3a3a;
@define-color insensitive_base_color rgba(0, 0, 0, 0.075);
@define-color borders rgba(0, 0, 0, 0.75);
@define-color unfocused_borders rgba(0, 0, 0, 0.75);
@define-color bg_color #333;
@define-color theme_bg_color #333;
@define-color content_view_bg #333;
@define-color insensitive_bg_color #313131;
@define-color theme_unfocused_bg_color #333;
@define-color fg_color white;
@define-color theme_fg_color white;
@define-color insensitive_fg_color #999999;
@define-color unfocused_insensitive_color #999999;
@define-color text_color white;
@define-color theme_text_color white;
@define-color theme_unfocused_fg_color white;
@define-color theme_unfocused_text_color white;
@define-color theme_selected_bg_color @selected_bg_color;
@define-color theme_selected_fg_color @selected_fg_color;
@define-color wm_shadow rgba(0, 0, 0, 0.2);
overshoot.left,
overshoot.right,
overshoot.top,
overshoot.bottom,
undershoot.left,
undershoot.right,
undershoot.top,
undershoot.bottom {
  background-image: none;
  background-color: transparent;
  border: none;
  box-shadow: none; }

overshoot.top {
  background: linear-gradient(to top, alpha(@accent_color, 0) 80%, alpha(@accent_color, 0.25) 100%); }

overshoot.right {
  background: linear-gradient(to right, alpha(@accent_color, 0) 80%, alpha(@accent_color, 0.25) 100%); }

overshoot.bottom {
  background: linear-gradient(to bottom, alpha(@accent_color, 0) 80%, alpha(@accent_color, 0.25) 100%); }

overshoot.left {
  background: linear-gradient(to left, alpha(@accent_color, 0) 80%, alpha(@accent_color, 0.25) 100%); }

:backdrop overshoot.top {
  background: linear-gradient(to top, rgba(255, 255, 255, 0) 80%, rgba(255, 255, 255, 0.15) 100%); }

:backdrop overshoot.right {
  background: linear-gradient(to right, rgba(255, 255, 255, 0) 80%, rgba(255, 255, 255, 0.15) 100%); }

:backdrop overshoot.bottom {
  background: linear-gradient(to bottom, rgba(255, 255, 255, 0) 80%, rgba(255, 255, 255, 0.15) 100%); }

:backdrop overshoot.left {
  background: linear-gradient(to left, rgba(255, 255, 255, 0) 80%, rgba(255, 255, 255, 0.15) 100%); }

.dialog .dialog-vbox .title, window.preferences.csd .dialog-vbox .title, bottom-sheet sheet .dialog-vbox .title,
floating-sheet sheet .dialog-vbox .title, dialog.about .dialog-vbox .title,
window.about .dialog-vbox .title,
.primary {
  font-weight: 500;
  font-size: 1.22em; }

.small-label, viewswitcher button stack > box.narrow, list.boxed-list > row .title + .subtitle, scale mark label {
  font-size: 0.85em; }

.accent, calendar.view .day-number.today, button.link,
link {
  color: mix(@accent_color, white, 0.1); }
  .accent.red, calendar.view .red.day-number.today, button.red.link,
  link.red {
    color: #f6706b; }
  .accent.orange, calendar.view .orange.day-number.today, button.orange.link,
  link.orange {
    color: #f67f34; }
  .accent.yellow, calendar.view .yellow.day-number.today, button.yellow.link,
  link.yellow {
    color: #f9c440; }
  .accent.green, calendar.view .green.day-number.today, button.green.link,
  link.green {
    color: #68b723; }
  .accent.blue, calendar.view .blue.day-number.today, button.blue.link,
  link.blue {
    color: #4da2f3; }
  .accent.purple, calendar.view .purple.day-number.today, button.purple.link,
  link.purple {
    color: #b986ed; }
  .accent.brown, calendar.view .brown.day-number.today, button.brown.link,
  link.brown {
    color: #ac9b89; }
  .accent.mint, calendar.view .mint.day-number.today, button.mint.link,
  link.mint {
    color: #22b49b; }
  .accent.pink, calendar.view .pink.day-number.today, button.pink.link,
  link.pink {
    color: #f774a4; }
  .accent.slate, calendar.view .slate.day-number.today, button.slate.link,
  link.slate {
    color: #95a3ab; }
  .accent.latte, calendar.view .latte.day-number.today, button.latte.link,
  link.latte {
    color: #efdfc4; }
  .accent:backdrop, calendar.view .day-number.today:backdrop, button.link:backdrop,
  link:backdrop {
    color: white;
    opacity: 0.6; }

button.link,
link {
  text-decoration: underline; }

.dim-label, list.boxed-list > row .title + .subtitle, scale mark label,
:visited {
  opacity: 0.75; }

label:disabled {
  color: #999999; }

:link:hover label {
  text-decoration: underline; }

.monospace {
  font-family: monospace; }

selection, dialog.about .main-page .app-version,
window.about .main-page .app-version,
bottom-sheet sheet.about .main-page .app-version,
floating-sheet sheet.about .main-page .app-version, gridview child:focus-visible:selected,
flowboxchild:focus-visible:selected, iconview.view.cell:focus-visible:selected, treeview.view.cell:focus-visible:selected, list row:focus-visible:selected,
listview row:focus-visible:selected, dropdown popover listview row.activatable image:last-child, columnview listview row:focus-visible:selected, calendar.view .day-number:selected, .linked button.flat.suggested-action:not(:disabled), .linked .sidebar .inline-toolbar button.suggested-action:not(:disabled), .linked .sidebar actionbar.flat button.suggested-action:not(:disabled),
.linked .sidebar .bottom-toolbar.flat button.suggested-action:not(:disabled),
.linked .sidebar window.preferences.csd headerbar.bottom-toolbar button.suggested-action:not(:disabled),
window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar .dialog.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar window.csd.preferences > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
bottom-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
floating-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
bottom-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
floating-sheet bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
floating-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
bottom-sheet floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar window.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
bottom-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
floating-sheet bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
.linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
floating-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
bottom-sheet floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled),
popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button.suggested-action:not(:disabled), .sidebar .inline-toolbar .linked button.suggested-action:not(:disabled), .sidebar actionbar.flat .linked button.suggested-action:not(:disabled),
.sidebar .bottom-toolbar.flat .linked button.suggested-action:not(:disabled),
.sidebar window.preferences.csd headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar .dialog.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar window.csd.preferences > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar window.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
.sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled),
floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled), .linked .sidebar popover.emoji-picker .emoji-toolbar button.suggested-action:not(:disabled), .sidebar popover.emoji-picker .emoji-toolbar .linked button.suggested-action:not(:disabled), .linked popover.emoji-picker .sidebar .emoji-toolbar button.suggested-action:not(:disabled), popover.emoji-picker .sidebar .emoji-toolbar .linked button.suggested-action:not(:disabled), .linked button.flat.suggested:not(:disabled), .linked .sidebar .inline-toolbar button.suggested:not(:disabled), .linked .sidebar actionbar.flat button.suggested:not(:disabled),
.linked .sidebar .bottom-toolbar.flat button.suggested:not(:disabled),
.linked .sidebar window.preferences.csd headerbar.bottom-toolbar button.suggested:not(:disabled),
window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar .dialog.csd > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar window.csd.preferences > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled),
bottom-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled),
floating-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled),
floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled),
bottom-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled),
bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled),
bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled),
floating-sheet bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled),
bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled),
floating-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled),
floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled),
bottom-sheet floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled),
floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar window.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
bottom-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
floating-sheet bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
.linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
floating-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
bottom-sheet floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled),
popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button.suggested:not(:disabled), .sidebar .inline-toolbar .linked button.suggested:not(:disabled), .sidebar actionbar.flat .linked button.suggested:not(:disabled),
.sidebar .bottom-toolbar.flat .linked button.suggested:not(:disabled),
.sidebar window.preferences.csd headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar .dialog.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar window.csd.preferences > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar window.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
.sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled),
floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled), .linked .sidebar popover.emoji-picker .emoji-toolbar button.suggested:not(:disabled), .sidebar popover.emoji-picker .emoji-toolbar .linked button.suggested:not(:disabled), .linked popover.emoji-picker .sidebar .emoji-toolbar button.suggested:not(:disabled), popover.emoji-picker .sidebar .emoji-toolbar .linked button.suggested:not(:disabled), .linked button.image-button.suggested-action:not(:disabled), .linked button.image-button.suggested:not(:disabled), button.circular.image-button.suggested-action:not(:disabled), button.image-button.suggested:not(:disabled), button.model.image-button.suggested-action:not(:disabled), button.image-button.suggested:not(:disabled), button.raised.image-button.suggested-action:not(:disabled), .messagedialog .response-area button.image-button.suggested-action:not(:disabled), button.image-button.suggested:not(:disabled), button.raised.suggested-action:not(:disabled), .messagedialog .response-area button.suggested-action:not(:disabled), button.raised.suggested:not(:disabled), .messagedialog .response-area button.suggested:not(:disabled), button.suggested-action:not(:disabled), button.suggested:not(:disabled), button.flat:focus-visible, .sidebar .inline-toolbar button:focus-visible, .sidebar actionbar.flat button:focus-visible,
.sidebar .bottom-toolbar.flat button:focus-visible,
.sidebar window.preferences.csd headerbar.bottom-toolbar button:focus-visible,
window.preferences.csd .sidebar headerbar.bottom-toolbar button:focus-visible,
.sidebar .dialog.csd > headerbar.bottom-toolbar button:focus-visible,
.sidebar window.csd.preferences > headerbar.bottom-toolbar button:focus-visible,
.sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button:focus-visible,
bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar button:focus-visible,
.sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button:focus-visible,
floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar button:focus-visible,
.sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button:focus-visible,
.sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:focus-visible,
.sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button:focus-visible,
floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:focus-visible,
bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar button:focus-visible,
bottom-sheet .sidebar sheet > headerbar.bottom-toolbar button:focus-visible,
bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:focus-visible,
floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar button:focus-visible,
.sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button:focus-visible,
.sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button:focus-visible,
bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:focus-visible,
.sidebar floating-sheet sheet > headerbar.bottom-toolbar button:focus-visible,
floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar button:focus-visible,
floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:focus-visible,
bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar button:focus-visible,
floating-sheet .sidebar sheet > headerbar.bottom-toolbar button:focus-visible,
.sidebar dialog.csd.about > headerbar.bottom-toolbar button:focus-visible,
.sidebar window.csd.about > headerbar.bottom-toolbar button:focus-visible,
.sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button:focus-visible,
.sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button:focus-visible,
.sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button:focus-visible,
floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button:focus-visible,
bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar button:focus-visible,
bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar button:focus-visible,
bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button:focus-visible,
floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar button:focus-visible,
.sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button:focus-visible,
.sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button:focus-visible,
bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button:focus-visible,
.sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button:focus-visible,
floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar button:focus-visible,
floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button:focus-visible,
bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar button:focus-visible,
floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar button:focus-visible, .sidebar popover.emoji-picker .emoji-toolbar button:focus-visible, popover.emoji-picker .sidebar .emoji-toolbar button:focus-visible, button.image-button:not(.text-button):focus-visible, .badge.flat, window.preferences.csd headerbar.badge, .sidebar .inline-toolbar button.badge, .sidebar actionbar.flat button.badge,
.sidebar .bottom-toolbar.flat button.badge,
.sidebar window.preferences.csd headerbar.bottom-toolbar button.badge,
window.preferences.csd .sidebar headerbar.bottom-toolbar button.badge,
.sidebar .dialog.csd > headerbar.bottom-toolbar button.badge,
.sidebar window.csd.preferences > headerbar.bottom-toolbar button.badge,
.sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.badge,
bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar button.badge,
.sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.badge,
floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar button.badge,
.sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.badge,
.sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.badge,
.sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.badge,
floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.badge,
bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar button.badge,
bottom-sheet .sidebar sheet > headerbar.bottom-toolbar button.badge,
bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.badge,
floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar button.badge,
.sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.badge,
.sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.badge,
bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.badge,
.sidebar floating-sheet sheet > headerbar.bottom-toolbar button.badge,
floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar button.badge,
floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.badge,
bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar button.badge,
floating-sheet .sidebar sheet > headerbar.bottom-toolbar button.badge,
.sidebar dialog.csd.about > headerbar.bottom-toolbar button.badge,
.sidebar window.csd.about > headerbar.bottom-toolbar button.badge,
.sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button.badge,
.sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.badge,
.sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button.badge,
floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.badge,
bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar button.badge,
bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar button.badge,
bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.badge,
floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar button.badge,
.sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button.badge,
.sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button.badge,
bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.badge,
.sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.badge,
floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar button.badge,
floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.badge,
bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar button.badge,
floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar button.badge, .sidebar popover.emoji-picker .emoji-toolbar button.badge, popover.emoji-picker .sidebar .emoji-toolbar button.badge, .dialog.csd > headerbar.badge, window.csd.preferences > headerbar.badge, bottom-sheet sheet.dialog > headerbar.badge,
floating-sheet sheet.dialog > headerbar.badge, bottom-sheet sheet.csd > headerbar.badge, bottom-sheet sheet > headerbar.badge,
bottom-sheet floating-sheet sheet > headerbar.badge,
floating-sheet bottom-sheet sheet > headerbar.badge,
floating-sheet sheet.csd > headerbar.badge,
floating-sheet bottom-sheet sheet > headerbar.badge,
bottom-sheet floating-sheet sheet > headerbar.badge,
floating-sheet sheet > headerbar.badge, dialog.csd.about > headerbar.badge,
window.csd.about > headerbar.badge,
bottom-sheet sheet.csd.about > headerbar.badge,
bottom-sheet sheet.about > headerbar.badge,
bottom-sheet floating-sheet sheet.about > headerbar.badge,
floating-sheet bottom-sheet sheet.about > headerbar.badge,
floating-sheet sheet.csd.about > headerbar.badge,
floating-sheet bottom-sheet sheet.about > headerbar.badge,
bottom-sheet floating-sheet sheet.about > headerbar.badge,
floating-sheet sheet.about > headerbar.badge {
  background-color: @selected_bg_color;
  color: @selected_fg_color; }
  selection:backdrop, dialog.about .main-page .app-version:backdrop,
  window.about .main-page .app-version:backdrop,
  bottom-sheet sheet.about .main-page .app-version:backdrop,
  floating-sheet sheet.about .main-page .app-version:backdrop, gridview child:backdrop:focus-visible:selected,
  flowboxchild:backdrop:focus-visible:selected, iconview.view.cell:backdrop:focus-visible:selected, treeview.view.cell:backdrop:focus-visible:selected, list row:backdrop:focus-visible:selected,
  listview row:backdrop:focus-visible:selected, dropdown popover listview row.activatable image:backdrop:last-child, calendar.view .day-number:backdrop:selected, .linked button.flat.suggested-action:backdrop:not(:disabled), .linked .sidebar .inline-toolbar button.suggested-action:backdrop:not(:disabled), .linked .sidebar actionbar.flat button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar .bottom-toolbar.flat button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar window.csd.preferences > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  floating-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  floating-sheet bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  floating-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  bottom-sheet floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar window.csd.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  floating-sheet bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  floating-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  bottom-sheet floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:backdrop:not(:disabled),
  popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button.suggested-action:backdrop:not(:disabled), .sidebar .inline-toolbar .linked button.suggested-action:backdrop:not(:disabled), .sidebar actionbar.flat .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar .bottom-toolbar.flat .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar window.csd.preferences > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar window.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled),
  floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:backdrop:not(:disabled), .linked .sidebar popover.emoji-picker .emoji-toolbar button.suggested-action:backdrop:not(:disabled), .sidebar popover.emoji-picker .emoji-toolbar .linked button.suggested-action:backdrop:not(:disabled), .linked popover.emoji-picker .sidebar .emoji-toolbar button.suggested-action:backdrop:not(:disabled), popover.emoji-picker .sidebar .emoji-toolbar .linked button.suggested-action:backdrop:not(:disabled), .linked button.flat.suggested:backdrop:not(:disabled), .linked .sidebar .inline-toolbar button.suggested:backdrop:not(:disabled), .linked .sidebar actionbar.flat button.suggested:backdrop:not(:disabled),
  .linked .sidebar .bottom-toolbar.flat button.suggested:backdrop:not(:disabled),
  .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar window.csd.preferences > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  floating-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  floating-sheet bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  floating-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  bottom-sheet floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar window.csd.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  floating-sheet bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  floating-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  bottom-sheet floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:backdrop:not(:disabled),
  popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button.suggested:backdrop:not(:disabled), .sidebar .inline-toolbar .linked button.suggested:backdrop:not(:disabled), .sidebar actionbar.flat .linked button.suggested:backdrop:not(:disabled),
  .sidebar .bottom-toolbar.flat .linked button.suggested:backdrop:not(:disabled),
  .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar window.csd.preferences > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar window.csd.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled),
  floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:backdrop:not(:disabled), .linked .sidebar popover.emoji-picker .emoji-toolbar button.suggested:backdrop:not(:disabled), .sidebar popover.emoji-picker .emoji-toolbar .linked button.suggested:backdrop:not(:disabled), .linked popover.emoji-picker .sidebar .emoji-toolbar button.suggested:backdrop:not(:disabled), popover.emoji-picker .sidebar .emoji-toolbar .linked button.suggested:backdrop:not(:disabled), .linked button.image-button.suggested-action:backdrop:not(:disabled), button.circular.image-button.suggested-action:backdrop:not(:disabled), button.image-button.suggested:backdrop:not(:disabled), button.model.image-button.suggested-action:backdrop:not(:disabled), button.raised.suggested-action:backdrop:not(:disabled), .messagedialog .response-area button.suggested-action:backdrop:not(:disabled), button.raised.suggested:backdrop:not(:disabled), .messagedialog .response-area button.suggested:backdrop:not(:disabled), button.suggested-action:backdrop:not(:disabled), button.suggested:backdrop:not(:disabled), button.flat:backdrop:focus-visible, .sidebar .inline-toolbar button:backdrop:focus-visible, .sidebar actionbar.flat button:backdrop:focus-visible,
  .sidebar .bottom-toolbar.flat button:backdrop:focus-visible,
  .sidebar window.preferences.csd headerbar.bottom-toolbar button:backdrop:focus-visible,
  window.preferences.csd .sidebar headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar .dialog.csd > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar window.csd.preferences > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button:backdrop:focus-visible,
  bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button:backdrop:focus-visible,
  floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button:backdrop:focus-visible,
  floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:backdrop:focus-visible,
  bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar button:backdrop:focus-visible,
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar button:backdrop:focus-visible,
  bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:backdrop:focus-visible,
  floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button:backdrop:focus-visible,
  bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:backdrop:focus-visible,
  floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar button:backdrop:focus-visible,
  floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:backdrop:focus-visible,
  bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar button:backdrop:focus-visible,
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar dialog.csd.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar window.csd.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar button:backdrop:focus-visible,
  floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar button:backdrop:focus-visible, .sidebar popover.emoji-picker .emoji-toolbar button:backdrop:focus-visible, popover.emoji-picker .sidebar .emoji-toolbar button:backdrop:focus-visible, button.image-button:backdrop:not(.text-button):focus-visible, .badge.flat:backdrop, window.preferences.csd headerbar.badge:backdrop, .sidebar .inline-toolbar button.badge:backdrop, .sidebar actionbar.flat button.badge:backdrop,
  .sidebar .bottom-toolbar.flat button.badge:backdrop,
  .sidebar window.preferences.csd headerbar.bottom-toolbar button.badge:backdrop,
  window.preferences.csd .sidebar headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar .dialog.csd > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar window.csd.preferences > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.badge:backdrop,
  bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.badge:backdrop,
  floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.badge:backdrop,
  floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.badge:backdrop,
  bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar button.badge:backdrop,
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar button.badge:backdrop,
  bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.badge:backdrop,
  floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.badge:backdrop,
  bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.badge:backdrop,
  floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar button.badge:backdrop,
  floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.badge:backdrop,
  bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar button.badge:backdrop,
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar dialog.csd.about > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar window.csd.about > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button.badge:backdrop,
  floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.badge:backdrop,
  bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar button.badge:backdrop,
  bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar button.badge:backdrop,
  bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.badge:backdrop,
  floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button.badge:backdrop,
  bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.badge:backdrop,
  .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.badge:backdrop,
  floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar button.badge:backdrop,
  floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.badge:backdrop,
  bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar button.badge:backdrop,
  floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar button.badge:backdrop, .sidebar popover.emoji-picker .emoji-toolbar button.badge:backdrop, popover.emoji-picker .sidebar .emoji-toolbar button.badge:backdrop, .dialog.csd > headerbar.badge:backdrop, window.csd.preferences > headerbar.badge:backdrop, bottom-sheet sheet.dialog > headerbar.badge:backdrop,
  floating-sheet sheet.dialog > headerbar.badge:backdrop, bottom-sheet sheet.csd > headerbar.badge:backdrop, bottom-sheet sheet > headerbar.badge:backdrop,
  bottom-sheet floating-sheet sheet > headerbar.badge:backdrop,
  floating-sheet bottom-sheet sheet > headerbar.badge:backdrop,
  floating-sheet sheet.csd > headerbar.badge:backdrop,
  floating-sheet bottom-sheet sheet > headerbar.badge:backdrop,
  bottom-sheet floating-sheet sheet > headerbar.badge:backdrop,
  floating-sheet sheet > headerbar.badge:backdrop, dialog.csd.about > headerbar.badge:backdrop,
  window.csd.about > headerbar.badge:backdrop,
  bottom-sheet sheet.csd.about > headerbar.badge:backdrop,
  bottom-sheet sheet.about > headerbar.badge:backdrop,
  bottom-sheet floating-sheet sheet.about > headerbar.badge:backdrop,
  floating-sheet bottom-sheet sheet.about > headerbar.badge:backdrop,
  floating-sheet sheet.csd.about > headerbar.badge:backdrop,
  floating-sheet bottom-sheet sheet.about > headerbar.badge:backdrop,
  bottom-sheet floating-sheet sheet.about > headerbar.badge:backdrop,
  floating-sheet sheet.about > headerbar.badge:backdrop {
    background-color: @theme_unfocused_selected_bg_color;
    color: @theme_unfocused_selected_fg_color; }

.checkerboard {
  background-color: #313131;
  background-image: linear-gradient(45deg, rgba(0, 0, 0, 0.05) 0.750000001rem, transparent 0.750000001rem, transparent 2.1666666677rem, rgba(0, 0, 0, 0.05) 2.1666666677rem, rgba(0, 0, 0, 0.05)), linear-gradient(45deg, rgba(0, 0, 0, 0.05) 0.750000001rem, transparent 0.750000001rem, transparent 2.1666666677rem, rgba(0, 0, 0, 0.05) 2.1666666677rem, rgba(0, 0, 0, 0.05));
  background-size: 2.000000001rem 2.000000001rem;
  background-position: 0 0, 1.000000001rem 1.000000001rem; }

.circular {
  border-radius: 9999px; }

.error {
  color: @error_color; }

.success {
  color: @success_color; }

.warning {
  color: @warning_color; }

.avatar,
avatar {
  border: 1px solid rgba(0, 0, 0, 0.35);
  border-radius: 50%;
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24); }

avatar {
  background-color: @accent_color_300;
  border-color: alpha(@accent_color_500, 0.5);
  color: @accent_color_900;
  border: none;
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px rgba(0, 0, 0, 0.1), 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24); }
  avatar.color1 {
    background-color: #64baff;
    border-color: rgba(54, 137, 230, 0.5);
    color: #002e99; }
  avatar.color2 {
    background-color: #8cd5ff;
    border-color: rgba(100, 186, 255, 0.5);
    color: #0d52bf; }
  avatar.color3 {
    background-color: #43d6b5;
    border-color: rgba(40, 188, 163, 0.5);
    color: #007367; }
  avatar.color4 {
    background-color: #9bdb4d;
    border-color: rgba(104, 183, 35, 0.5);
    color: #206b00; }
  avatar.color5 {
    background-color: #f9c440;
    border-color: rgba(212, 142, 21, 0.5);
    color: #ad5f00; }
  avatar.color6 {
    background-color: #fcb34a;
    border-color: rgba(228, 129, 31, 0.5);
    color: #aa4000; }
  avatar.color7 {
    background-color: #ffa154;
    border-color: rgba(243, 115, 41, 0.5);
    color: #a62100; }
  avatar.color8 {
    background-color: #ed5353;
    border-color: rgba(198, 38, 46, 0.5);
    color: #7a0000; }
  avatar.color9 {
    background-color: #f4679d;
    border-color: rgba(222, 62, 128, 0.5);
    color: #910e38; }
  avatar.color10 {
    background-color: #cd9ef7;
    border-color: rgba(165, 109, 226, 0.5);
    color: #452981; }
  avatar.color11 {
    background-color: #6d78db;
    border-color: rgba(89, 96, 209, 0.5);
    color: #232c8d; }
  avatar.color12 {
    background-color: #d1c288;
    border-color: rgba(181, 140, 66, 0.5);
    color: #895818; }
  avatar.color13 {
    background-color: #8a715e;
    border-color: rgba(113, 83, 68, 0.5);
    color: #3d211b; }
  avatar.color14 {
    background-color: #667885;
    border-color: rgba(72, 90, 108, 0.5);
    color: #0e141f; }
  avatar.image {
    border-color: rgba(0, 0, 0, 0.3);
    background: none; }

.badge {
  background-image: linear-gradient(to bottom, #ed5353, #c6262e);
  border: 1px solid #a10705;
  border-radius: 99px;
  box-shadow: inset 0 0 0 1px rgba(255, 255, 255, 0.05), inset 0 1px 0 0 rgba(255, 255, 255, 0.25), inset 0 -1px 0 0 rgba(255, 255, 255, 0.1), 0 1px 2px rgba(0, 0, 0, 0.3);
  color: white;
  font-weight: 700;
  min-height: 1.8333333343rem;
  min-width: 1.8333333343rem;
  text-shadow: 0 1px 1px #7a0000;
  background-clip: padding-box;
  border-color: rgba(0, 0, 0, 0.75); }
  .badge.flat, window.preferences.csd headerbar.badge, .sidebar .inline-toolbar button.badge, .sidebar actionbar.flat button.badge,
  .sidebar .bottom-toolbar.flat button.badge,
  .sidebar window.preferences.csd headerbar.bottom-toolbar button.badge,
  window.preferences.csd .sidebar headerbar.bottom-toolbar button.badge,
  .sidebar .dialog.csd > headerbar.bottom-toolbar button.badge,
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.badge,
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar button.badge,
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.badge,
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar button.badge,
  .sidebar dialog.csd.about > headerbar.bottom-toolbar button.badge,
  .sidebar window.csd.about > headerbar.bottom-toolbar button.badge, .sidebar popover.emoji-picker .emoji-toolbar button.badge, popover.emoji-picker .sidebar .emoji-toolbar button.badge, .dialog.csd > headerbar.badge, bottom-sheet sheet.dialog > headerbar.badge,
  floating-sheet sheet.dialog > headerbar.badge, bottom-sheet sheet.csd > headerbar.badge, bottom-sheet sheet > headerbar.badge,
  bottom-sheet floating-sheet sheet > headerbar.badge,
  floating-sheet bottom-sheet sheet > headerbar.badge,
  floating-sheet sheet.csd > headerbar.badge,
  floating-sheet bottom-sheet sheet > headerbar.badge,
  bottom-sheet floating-sheet sheet > headerbar.badge,
  floating-sheet sheet > headerbar.badge, dialog.csd.about > headerbar.badge,
  window.csd.about > headerbar.badge, .sidebar .badge, .badge.sidebar.view.cell {
    background-image: none;
    border-width: 0;
    box-shadow: none;
    margin: 0 3px;
    padding: 0 0.500000001rem;
    text-shadow: none; }
  .sidebar .badge, .badge.sidebar.view.cell {
    background-color: alpha(@text_color, 0.1);
    color: alpha(@text_color, 0.7); }
  .badge.flat, window.preferences.csd headerbar.badge, .sidebar .inline-toolbar button.badge, .sidebar actionbar.flat button.badge,
  .sidebar .bottom-toolbar.flat button.badge,
  .sidebar window.preferences.csd headerbar.bottom-toolbar button.badge,
  window.preferences.csd .sidebar headerbar.bottom-toolbar button.badge,
  .sidebar .dialog.csd > headerbar.bottom-toolbar button.badge,
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.badge,
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar button.badge,
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.badge,
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar button.badge,
  .sidebar dialog.csd.about > headerbar.bottom-toolbar button.badge,
  .sidebar window.csd.about > headerbar.bottom-toolbar button.badge, .sidebar popover.emoji-picker .emoji-toolbar button.badge, popover.emoji-picker .sidebar .emoji-toolbar button.badge, .dialog.csd > headerbar.badge, bottom-sheet sheet.dialog > headerbar.badge,
  floating-sheet sheet.dialog > headerbar.badge, bottom-sheet sheet.csd > headerbar.badge, bottom-sheet sheet > headerbar.badge,
  bottom-sheet floating-sheet sheet > headerbar.badge,
  floating-sheet bottom-sheet sheet > headerbar.badge,
  floating-sheet sheet.csd > headerbar.badge,
  floating-sheet bottom-sheet sheet > headerbar.badge,
  bottom-sheet floating-sheet sheet > headerbar.badge,
  floating-sheet sheet > headerbar.badge, dialog.csd.about > headerbar.badge,
  window.csd.about > headerbar.badge {
    min-height: 0;
    min-width: 1.3333333343rem; }
    row:selected:not(:focus-visible) .badge.flat, row:selected:not(:focus-visible) window.preferences.csd headerbar.badge, window.preferences.csd row:selected:not(:focus-visible) headerbar.badge, row:selected:not(:focus-visible) .sidebar .inline-toolbar button.badge, row:selected:not(:focus-visible) .sidebar actionbar.flat button.badge,
    row:selected:not(:focus-visible) .sidebar .bottom-toolbar.flat button.badge,
    row:selected:not(:focus-visible) .sidebar window.preferences.csd headerbar.bottom-toolbar button.badge,
    window.preferences.csd row:selected:not(:focus-visible) .sidebar headerbar.bottom-toolbar button.badge,
    row:selected:not(:focus-visible) .sidebar .dialog.csd > headerbar.bottom-toolbar button.badge,
    row:selected:not(:focus-visible) .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.badge,
    bottom-sheet row:selected:not(:focus-visible) .sidebar sheet > headerbar.bottom-toolbar button.badge,
    row:selected:not(:focus-visible) .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.badge,
    floating-sheet row:selected:not(:focus-visible) .sidebar sheet > headerbar.bottom-toolbar button.badge,
    row:selected:not(:focus-visible) .sidebar dialog.csd.about > headerbar.bottom-toolbar button.badge,
    row:selected:not(:focus-visible) .sidebar window.csd.about > headerbar.bottom-toolbar button.badge,
    popover.emoji-picker row:selected:not(:focus-visible) .sidebar .emoji-toolbar button.bottom-toolbar button.badge, .sidebar .inline-toolbar row:selected:not(:focus-visible) button.badge, .sidebar actionbar.flat row:selected:not(:focus-visible) button.badge,
    .sidebar .bottom-toolbar.flat row:selected:not(:focus-visible) button.badge,
    .sidebar window.preferences.csd headerbar.bottom-toolbar row:selected:not(:focus-visible) button.badge,
    window.preferences.csd .sidebar headerbar.bottom-toolbar row:selected:not(:focus-visible) button.badge,
    .sidebar .dialog.csd > headerbar.bottom-toolbar row:selected:not(:focus-visible) button.badge,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar row:selected:not(:focus-visible) button.badge,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar row:selected:not(:focus-visible) button.badge,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar row:selected:not(:focus-visible) button.badge,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar row:selected:not(:focus-visible) button.badge,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar row:selected:not(:focus-visible) button.badge,
    .sidebar window.csd.about > headerbar.bottom-toolbar row:selected:not(:focus-visible) button.badge, row:selected:not(:focus-visible) .sidebar popover.emoji-picker .emoji-toolbar button.badge, .sidebar popover.emoji-picker .emoji-toolbar row:selected:not(:focus-visible) button.badge, row:selected:not(:focus-visible) popover.emoji-picker .sidebar .emoji-toolbar button.badge, popover.emoji-picker .sidebar .emoji-toolbar row:selected:not(:focus-visible) button.badge, row:selected:not(:focus-visible) .dialog.csd > headerbar.badge, row:selected:not(:focus-visible) bottom-sheet sheet > headerbar.badge, bottom-sheet row:selected:not(:focus-visible) sheet > headerbar.badge,
    row:selected:not(:focus-visible) floating-sheet sheet > headerbar.badge,
    floating-sheet row:selected:not(:focus-visible) sheet > headerbar.badge, row:selected:not(:focus-visible) dialog.csd.about > headerbar.badge,
    row:selected:not(:focus-visible) window.csd.about > headerbar.badge {
      color: inherit;
      background: rgba(255, 255, 255, 0.15); }

.buttonbox button.text-button,
.dialog-action-area button.text-button {
  min-width: 5.000000001rem; }

.buttonbox button:dir(ltr) + button,
.dialog-action-area button:dir(ltr) + button {
  margin-left: 0.500000001rem; }

.buttonbox button:dir(rtl) + button,
.dialog-action-area button:dir(rtl) + button {
  margin-right: 0.500000001rem; }

button {
  background-clip: padding-box;
  border-radius: 0.250000001rem;
  color: @fg_color;
  font-weight: 500;
  padding: 0.3333333343rem 0.5833333343rem;
  transition: background 100ms cubic-bezier(0.4, 0, 0.2, 1); }
  button.flat, .sidebar .inline-toolbar button, .sidebar actionbar.flat button,
  .sidebar .bottom-toolbar.flat button,
  .sidebar window.preferences.csd headerbar.bottom-toolbar button,
  window.preferences.csd .sidebar headerbar.bottom-toolbar button,
  .sidebar .dialog.csd > headerbar.bottom-toolbar button,
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button,
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar button,
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar button,
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar button,
  .sidebar dialog.csd.about > headerbar.bottom-toolbar button,
  .sidebar window.csd.about > headerbar.bottom-toolbar button,
  .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar button,
  popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar button, .sidebar popover.emoji-picker .emoji-toolbar button, popover.emoji-picker .sidebar .emoji-toolbar button, button.image-button:not(.text-button) {
    background: none;
    border: none;
    box-shadow: none; }
    button.flat:checked, .sidebar .inline-toolbar button:checked, .sidebar actionbar.flat button:checked,
    .sidebar .bottom-toolbar.flat button:checked,
    .sidebar window.preferences.csd headerbar.bottom-toolbar button:checked,
    window.preferences.csd .sidebar headerbar.bottom-toolbar button:checked,
    .sidebar .dialog.csd > headerbar.bottom-toolbar button:checked,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:checked,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar button:checked,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:checked,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar button:checked,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar button:checked,
    .sidebar window.csd.about > headerbar.bottom-toolbar button:checked, .sidebar popover.emoji-picker .emoji-toolbar button:checked, popover.emoji-picker .sidebar .emoji-toolbar button:checked, button.image-button:not(.text-button):checked {
      background: rgba(255, 255, 255, 0.15); }
    button.flat:focus-visible, .sidebar .inline-toolbar button:focus-visible, .sidebar actionbar.flat button:focus-visible,
    .sidebar .bottom-toolbar.flat button:focus-visible,
    .sidebar window.preferences.csd headerbar.bottom-toolbar button:focus-visible,
    window.preferences.csd .sidebar headerbar.bottom-toolbar button:focus-visible,
    .sidebar .dialog.csd > headerbar.bottom-toolbar button:focus-visible,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:focus-visible,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar button:focus-visible,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:focus-visible,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar button:focus-visible,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar button:focus-visible,
    .sidebar window.csd.about > headerbar.bottom-toolbar button:focus-visible, .sidebar popover.emoji-picker .emoji-toolbar button:focus-visible, popover.emoji-picker .sidebar .emoji-toolbar button:focus-visible, button.image-button:not(.text-button):focus-visible {
      outline-style: none; }
    headerbar button.flat, headerbar .sidebar .inline-toolbar button, headerbar .sidebar actionbar.flat button,
    headerbar .sidebar .bottom-toolbar.flat button,
    headerbar .sidebar window.preferences.csd headerbar.bottom-toolbar button,
    window.preferences.csd headerbar .sidebar headerbar.bottom-toolbar button,
    headerbar .sidebar .dialog.csd > headerbar.bottom-toolbar button,
    headerbar .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button,
    bottom-sheet headerbar .sidebar sheet > headerbar.bottom-toolbar button,
    headerbar .sidebar floating-sheet sheet > headerbar.bottom-toolbar button,
    floating-sheet headerbar .sidebar sheet > headerbar.bottom-toolbar button,
    headerbar .sidebar dialog.csd.about > headerbar.bottom-toolbar button,
    headerbar .sidebar window.csd.about > headerbar.bottom-toolbar button,
    headerbar .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar button,
    headerbar popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar button,
    popover.emoji-picker headerbar .sidebar .emoji-toolbar button.bottom-toolbar button, .sidebar .inline-toolbar headerbar button, .sidebar actionbar.flat headerbar button,
    .sidebar .bottom-toolbar.flat headerbar button,
    .sidebar window.preferences.csd headerbar.bottom-toolbar headerbar button,
    window.preferences.csd .sidebar headerbar.bottom-toolbar headerbar button,
    .sidebar .dialog.csd > headerbar.bottom-toolbar headerbar button,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar headerbar button,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar headerbar button,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar headerbar button,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar headerbar button,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar headerbar button,
    .sidebar window.csd.about > headerbar.bottom-toolbar headerbar button,
    .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar headerbar button,
    popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar headerbar button, headerbar .sidebar popover.emoji-picker .emoji-toolbar button, .sidebar popover.emoji-picker .emoji-toolbar headerbar button, headerbar popover.emoji-picker .sidebar .emoji-toolbar button, popover.emoji-picker .sidebar .emoji-toolbar headerbar button, headerbar button.image-button:not(.text-button) {
      border-radius: 99px; }
  .linked button.flat, .linked .sidebar .inline-toolbar button, .linked .sidebar actionbar.flat button,
  .linked .sidebar .bottom-toolbar.flat button,
  .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button,
  window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button,
  .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button,
  .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button,
  bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button,
  .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button,
  floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button,
  .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button,
  .linked .sidebar window.csd.about > headerbar.bottom-toolbar button,
  popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button, .sidebar .inline-toolbar .linked button, .sidebar actionbar.flat .linked button,
  .sidebar .bottom-toolbar.flat .linked button,
  .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button,
  window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button,
  .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button,
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button,
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button,
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button,
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button,
  .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button,
  .sidebar window.csd.about > headerbar.bottom-toolbar .linked button, .linked .sidebar popover.emoji-picker .emoji-toolbar button, .sidebar popover.emoji-picker .emoji-toolbar .linked button, .linked popover.emoji-picker .sidebar .emoji-toolbar button, popover.emoji-picker .sidebar .emoji-toolbar .linked button, .linked button.image-button, .linked button.image-button:not(.text-button), button.circular.image-button, button.model.image-button, button.raised.image-button, button.raised, .messagedialog .response-area button, button {
    background-clip: padding-box;
    background-color: #404040;
    border: 1px solid rgba(0, 0, 0, 0.3);
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 1px 1px rgba(0, 0, 0, 0.07), 0 1px 2px rgba(0, 0, 0, 0.08); }
    headerbar .linked button.flat, headerbar .linked .sidebar .inline-toolbar button, headerbar .linked .sidebar actionbar.flat button,
    headerbar .linked .sidebar .bottom-toolbar.flat button,
    headerbar .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button,
    window.preferences.csd headerbar .linked .sidebar headerbar.bottom-toolbar button,
    headerbar .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button,
    headerbar .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button,
    bottom-sheet headerbar .linked .sidebar sheet > headerbar.bottom-toolbar button,
    headerbar .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button,
    floating-sheet headerbar .linked .sidebar sheet > headerbar.bottom-toolbar button,
    headerbar .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button,
    headerbar .linked .sidebar window.csd.about > headerbar.bottom-toolbar button,
    popover.emoji-picker headerbar .linked .sidebar .emoji-toolbar button.bottom-toolbar button, .sidebar .inline-toolbar headerbar .linked button, .sidebar actionbar.flat headerbar .linked button,
    .sidebar .bottom-toolbar.flat headerbar .linked button,
    .sidebar window.preferences.csd headerbar.bottom-toolbar headerbar .linked button,
    window.preferences.csd .sidebar headerbar.bottom-toolbar headerbar .linked button,
    .sidebar .dialog.csd > headerbar.bottom-toolbar headerbar .linked button,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar headerbar .linked button,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar headerbar .linked button,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar headerbar .linked button,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar headerbar .linked button,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar headerbar .linked button,
    .sidebar window.csd.about > headerbar.bottom-toolbar headerbar .linked button, headerbar .linked .sidebar popover.emoji-picker .emoji-toolbar button, .sidebar popover.emoji-picker .emoji-toolbar headerbar .linked button, headerbar .linked popover.emoji-picker .sidebar .emoji-toolbar button, popover.emoji-picker .sidebar .emoji-toolbar headerbar .linked button, headerbar .linked button.image-button, headerbar .linked button.image-button:not(.text-button), headerbar button.circular.image-button, headerbar button.model.image-button, headerbar button.raised.image-button, headerbar button.raised, headerbar .messagedialog .response-area button, .messagedialog .response-area headerbar button, headerbar button {
      border-radius: 0.250000001rem; }
    .linked button.flat.destructive-action:not(:disabled), .linked .sidebar popover.emoji-picker .emoji-toolbar button.destructive-action:not(:disabled), .sidebar popover.emoji-picker .emoji-toolbar .linked button.destructive-action:not(:disabled), .linked popover.emoji-picker .sidebar .emoji-toolbar button.destructive-action:not(:disabled), popover.emoji-picker .sidebar .emoji-toolbar .linked button.destructive-action:not(:disabled), .linked button.image-button.destructive-action:not(:disabled), .linked button.image-button:not(.text-button).destructive-action:not(:disabled), .linked button.destructive:not(.text-button):not(:disabled), button.circular.image-button.destructive-action:not(:disabled), button.model.image-button.destructive-action:not(:disabled), button.raised.image-button.destructive-action:not(:disabled), button.raised.destructive-action:not(:disabled), button.destructive-action:not(:disabled), button.destructive:not(:disabled) {
      background-color: #c6262e;
      color: white;
      text-shadow: 0 1px 1px #c6262e;
      -gtk-icon-shadow: 0 1px 1px #c6262e; }
      .linked button.flat.destructive-action:not(:disabled).keyboard-activating, .linked .sidebar popover.emoji-picker .emoji-toolbar button.destructive-action:not(:disabled).keyboard-activating, .sidebar popover.emoji-picker .emoji-toolbar .linked button.destructive-action:not(:disabled).keyboard-activating, .linked popover.emoji-picker .sidebar .emoji-toolbar button.destructive-action:not(:disabled).keyboard-activating, popover.emoji-picker .sidebar .emoji-toolbar .linked button.destructive-action:not(:disabled).keyboard-activating, .linked button.flat.destructive-action:not(:disabled):active, .linked .sidebar popover.emoji-picker .emoji-toolbar button.destructive-action:not(:disabled):active, .sidebar popover.emoji-picker .emoji-toolbar .linked button.destructive-action:not(:disabled):active, .linked popover.emoji-picker .sidebar .emoji-toolbar button.destructive-action:not(:disabled):active, popover.emoji-picker .sidebar .emoji-toolbar .linked button.destructive-action:not(:disabled):active, .linked button.flat.destructive-action:not(:disabled):checked, .linked .sidebar popover.emoji-picker .emoji-toolbar button.destructive-action:not(:disabled):checked, .sidebar popover.emoji-picker .emoji-toolbar .linked button.destructive-action:not(:disabled):checked, .linked popover.emoji-picker .sidebar .emoji-toolbar button.destructive-action:not(:disabled):checked, popover.emoji-picker .sidebar .emoji-toolbar .linked button.destructive-action:not(:disabled):checked, .linked button.flat.destructive-action:not(:disabled):focus-visible.keyboard-activating, .linked button.flat.destructive-action:not(:disabled):focus-visible:active, .linked button.flat.destructive-action:not(:disabled):focus-visible:checked, .linked button.image-button.destructive-action:not(:disabled).keyboard-activating, .linked button.image-button.destructive-action:not(:disabled):active, .linked button.image-button.destructive-action:not(:disabled):checked, .linked button.image-button.destructive-action:not(:disabled):focus-visible.keyboard-activating, .linked button.image-button.destructive-action:not(:disabled):focus-visible:active, .linked button.image-button.destructive-action:not(:disabled):focus-visible:checked, .linked button.image-button:not(.text-button).destructive-action:not(:disabled).keyboard-activating, .linked button.image-button:not(.text-button).destructive-action:not(:disabled):active, .linked button.image-button:not(.text-button).destructive-action:not(:disabled):checked, .linked button.image-button:not(.text-button).destructive-action:not(:disabled):focus-visible.keyboard-activating, .linked button.image-button:not(.text-button).destructive-action:not(:disabled):focus-visible:active, .linked button.image-button:not(.text-button).destructive-action:not(:disabled):focus-visible:checked, button.circular.image-button.destructive-action:not(:disabled).keyboard-activating, button.circular.image-button.destructive-action:not(:disabled):active, button.circular.image-button.destructive-action:not(:disabled):checked, button.circular.image-button.destructive-action:not(:disabled):focus-visible.keyboard-activating, button.circular.image-button.destructive-action:not(:disabled):focus-visible:active, button.circular.image-button.destructive-action:not(:disabled):focus-visible:checked, button.model.image-button.destructive-action:not(:disabled).keyboard-activating, button.model.image-button.destructive-action:not(:disabled):active, button.model.image-button.destructive-action:not(:disabled):checked, button.model.image-button.destructive-action:not(:disabled):focus-visible.keyboard-activating, button.model.image-button.destructive-action:not(:disabled):focus-visible:active, button.model.image-button.destructive-action:not(:disabled):focus-visible:checked, button.raised.image-button.destructive-action:not(:disabled).keyboard-activating, button.raised.image-button.destructive-action:not(:disabled):active, button.raised.image-button.destructive-action:not(:disabled):checked, button.raised.image-button.destructive-action:not(:disabled):focus-visible.keyboard-activating, button.raised.image-button.destructive-action:not(:disabled):focus-visible:active, button.raised.image-button.destructive-action:not(:disabled):focus-visible:checked, button.raised.destructive-action:not(:disabled).keyboard-activating, button.raised.destructive-action:not(:disabled):active, button.raised.destructive-action:not(:disabled):checked, button.raised.destructive-action:not(:disabled):focus-visible.keyboard-activating, button.raised.destructive-action:not(:disabled):focus-visible:active, button.raised.destructive-action:not(:disabled):focus-visible:checked, button.destructive-action:not(:disabled).keyboard-activating, button.destructive:not(:disabled).keyboard-activating, button.destructive-action:not(:disabled):active, button.destructive:not(:disabled):active, button.destructive-action:not(:disabled):checked, button.destructive:not(:disabled):checked, button.destructive-action:not(:disabled):focus-visible.keyboard-activating, button.destructive-action:not(:disabled):focus-visible:active, button.destructive-action:not(:disabled):focus-visible:checked {
        border-color: rgba(0, 0, 0, 0.7); }
      .linked button.flat.destructive-action:not(:disabled):focus-visible, .linked .sidebar popover.emoji-picker .emoji-toolbar button.destructive-action:not(:disabled):focus-visible, .sidebar popover.emoji-picker .emoji-toolbar .linked button.destructive-action:not(:disabled):focus-visible, .linked popover.emoji-picker .sidebar .emoji-toolbar button.destructive-action:not(:disabled):focus-visible, popover.emoji-picker .sidebar .emoji-toolbar .linked button.destructive-action:not(:disabled):focus-visible, .linked button.image-button.destructive-action:not(:disabled):focus-visible, .linked button.image-button:not(.text-button).destructive-action:not(:disabled):focus-visible, button.circular.image-button.destructive-action:not(:disabled):focus-visible, button.model.image-button.destructive-action:not(:disabled):focus-visible, button.raised.image-button.destructive-action:not(:disabled):focus-visible, button.raised.destructive-action:not(:disabled):focus-visible, button.destructive-action:not(:disabled):focus-visible, button.destructive:not(:disabled):focus-visible {
        outline-color: rgba(237, 83, 83, 0.5); }
    .linked button.flat.suggested-action:not(:disabled).keyboard-activating, .linked .sidebar .inline-toolbar button.suggested-action:not(:disabled).keyboard-activating, .linked .sidebar actionbar.flat button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar .bottom-toolbar.flat button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar window.csd.preferences > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar window.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar .inline-toolbar button.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    .linked popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating,
    popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button.suggested-action:not(:disabled).keyboard-activating, .sidebar .inline-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating, .sidebar actionbar.flat .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar .bottom-toolbar.flat .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar window.csd.preferences > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar window.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar .inline-toolbar button.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating,
    popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating, .linked .sidebar popover.emoji-picker .emoji-toolbar button.suggested-action:not(:disabled).keyboard-activating, .sidebar popover.emoji-picker .emoji-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating, .linked popover.emoji-picker .sidebar .emoji-toolbar button.suggested-action:not(:disabled).keyboard-activating, popover.emoji-picker .sidebar .emoji-toolbar .linked button.suggested-action:not(:disabled).keyboard-activating, .linked button.flat.suggested:not(:disabled).keyboard-activating, .linked .sidebar .inline-toolbar button.suggested:not(:disabled).keyboard-activating, .linked .sidebar actionbar.flat button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar .bottom-toolbar.flat button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar window.csd.preferences > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    floating-sheet bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar window.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    floating-sheet bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar .inline-toolbar button.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    .linked popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar button.suggested:not(:disabled).keyboard-activating,
    popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button.suggested:not(:disabled).keyboard-activating, .sidebar .inline-toolbar .linked button.suggested:not(:disabled).keyboard-activating, .sidebar actionbar.flat .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar .bottom-toolbar.flat .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar window.csd.preferences > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar window.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar .inline-toolbar button.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating,
    popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar .linked button.suggested:not(:disabled).keyboard-activating, .linked .sidebar popover.emoji-picker .emoji-toolbar button.suggested:not(:disabled).keyboard-activating, .sidebar popover.emoji-picker .emoji-toolbar .linked button.suggested:not(:disabled).keyboard-activating, .linked popover.emoji-picker .sidebar .emoji-toolbar button.suggested:not(:disabled).keyboard-activating, popover.emoji-picker .sidebar .emoji-toolbar .linked button.suggested:not(:disabled).keyboard-activating, .linked button.flat.suggested-action:not(:disabled):active, .linked .sidebar .inline-toolbar button.suggested-action:not(:disabled):active, .linked .sidebar actionbar.flat button.suggested-action:not(:disabled):active,
    .linked .sidebar .bottom-toolbar.flat button.suggested-action:not(:disabled):active,
    .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar window.csd.preferences > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    bottom-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    floating-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    bottom-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    floating-sheet bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    floating-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    bottom-sheet floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar window.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    bottom-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    floating-sheet bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    floating-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    bottom-sheet floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar .inline-toolbar button.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar button.suggested-action:not(:disabled):active,
    .linked popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar button.suggested-action:not(:disabled):active,
    popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button.suggested-action:not(:disabled):active, .sidebar .inline-toolbar .linked button.suggested-action:not(:disabled):active, .sidebar actionbar.flat .linked button.suggested-action:not(:disabled):active,
    .sidebar .bottom-toolbar.flat .linked button.suggested-action:not(:disabled):active,
    .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar window.csd.preferences > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar window.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar .inline-toolbar button.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar .linked button.suggested-action:not(:disabled):active,
    popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar .linked button.suggested-action:not(:disabled):active, .linked .sidebar popover.emoji-picker .emoji-toolbar button.suggested-action:not(:disabled):active, .sidebar popover.emoji-picker .emoji-toolbar .linked button.suggested-action:not(:disabled):active, .linked popover.emoji-picker .sidebar .emoji-toolbar button.suggested-action:not(:disabled):active, popover.emoji-picker .sidebar .emoji-toolbar .linked button.suggested-action:not(:disabled):active, .linked button.flat.suggested:not(:disabled):active, .linked .sidebar .inline-toolbar button.suggested:not(:disabled):active, .linked .sidebar actionbar.flat button.suggested:not(:disabled):active,
    .linked .sidebar .bottom-toolbar.flat button.suggested:not(:disabled):active,
    .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar window.csd.preferences > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    bottom-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    floating-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    bottom-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    floating-sheet bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    floating-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    bottom-sheet floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar window.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    bottom-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    floating-sheet bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    floating-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    bottom-sheet floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar .inline-toolbar button.bottom-toolbar button.suggested:not(:disabled):active,
    .linked .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar button.suggested:not(:disabled):active,
    .linked popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar button.suggested:not(:disabled):active,
    popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button.suggested:not(:disabled):active, .sidebar .inline-toolbar .linked button.suggested:not(:disabled):active, .sidebar actionbar.flat .linked button.suggested:not(:disabled):active,
    .sidebar .bottom-toolbar.flat .linked button.suggested:not(:disabled):active,
    .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar window.csd.preferences > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar window.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar .inline-toolbar button.bottom-toolbar .linked button.suggested:not(:disabled):active,
    .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar .linked button.suggested:not(:disabled):active,
    popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar .linked button.suggested:not(:disabled):active, .linked .sidebar popover.emoji-picker .emoji-toolbar button.suggested:not(:disabled):active, .sidebar popover.emoji-picker .emoji-toolbar .linked button.suggested:not(:disabled):active, .linked popover.emoji-picker .sidebar .emoji-toolbar button.suggested:not(:disabled):active, popover.emoji-picker .sidebar .emoji-toolbar .linked button.suggested:not(:disabled):active, .linked button.flat.suggested-action:not(:disabled):checked, .linked .sidebar .inline-toolbar button.suggested-action:not(:disabled):checked, .linked .sidebar actionbar.flat button.suggested-action:not(:disabled):checked,
    .linked .sidebar .bottom-toolbar.flat button.suggested-action:not(:disabled):checked,
    .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar window.csd.preferences > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    bottom-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    floating-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    bottom-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    floating-sheet bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    floating-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    bottom-sheet floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar window.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    bottom-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    floating-sheet bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    floating-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    bottom-sheet floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar .inline-toolbar button.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar button.suggested-action:not(:disabled):checked,
    .linked popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar button.suggested-action:not(:disabled):checked,
    popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button.suggested-action:not(:disabled):checked, .sidebar .inline-toolbar .linked button.suggested-action:not(:disabled):checked, .sidebar actionbar.flat .linked button.suggested-action:not(:disabled):checked,
    .sidebar .bottom-toolbar.flat .linked button.suggested-action:not(:disabled):checked,
    .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar window.csd.preferences > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar window.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar .inline-toolbar button.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar .linked button.suggested-action:not(:disabled):checked,
    popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar .linked button.suggested-action:not(:disabled):checked, .linked .sidebar popover.emoji-picker .emoji-toolbar button.suggested-action:not(:disabled):checked, .sidebar popover.emoji-picker .emoji-toolbar .linked button.suggested-action:not(:disabled):checked, .linked popover.emoji-picker .sidebar .emoji-toolbar button.suggested-action:not(:disabled):checked, popover.emoji-picker .sidebar .emoji-toolbar .linked button.suggested-action:not(:disabled):checked, .linked button.flat.suggested:not(:disabled):checked, .linked .sidebar .inline-toolbar button.suggested:not(:disabled):checked, .linked .sidebar actionbar.flat button.suggested:not(:disabled):checked,
    .linked .sidebar .bottom-toolbar.flat button.suggested:not(:disabled):checked,
    .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar window.csd.preferences > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    bottom-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    floating-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    bottom-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    floating-sheet bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    floating-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    bottom-sheet floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar window.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    bottom-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    floating-sheet bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    floating-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    bottom-sheet floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar .inline-toolbar button.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar button.suggested:not(:disabled):checked,
    .linked popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar button.suggested:not(:disabled):checked,
    popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button.suggested:not(:disabled):checked, .sidebar .inline-toolbar .linked button.suggested:not(:disabled):checked, .sidebar actionbar.flat .linked button.suggested:not(:disabled):checked,
    .sidebar .bottom-toolbar.flat .linked button.suggested:not(:disabled):checked,
    .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar window.csd.preferences > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar window.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar .inline-toolbar button.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar .linked button.suggested:not(:disabled):checked,
    popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar .linked button.suggested:not(:disabled):checked, .linked .sidebar popover.emoji-picker .emoji-toolbar button.suggested:not(:disabled):checked, .sidebar popover.emoji-picker .emoji-toolbar .linked button.suggested:not(:disabled):checked, .linked popover.emoji-picker .sidebar .emoji-toolbar button.suggested:not(:disabled):checked, popover.emoji-picker .sidebar .emoji-toolbar .linked button.suggested:not(:disabled):checked, .linked button.image-button.suggested-action:not(:disabled).keyboard-activating, .linked button.image-button.suggested-action:not(:disabled):active, .linked button.image-button.suggested-action:not(:disabled):checked, .linked button.image-button:not(.text-button).suggested-action:not(:disabled).keyboard-activating, .linked button.suggested:not(.text-button):not(:disabled).keyboard-activating, .linked button.image-button:not(.text-button).suggested-action:not(:disabled):active, .linked button.suggested:not(.text-button):not(:disabled):active, .linked button.image-button:not(.text-button).suggested-action:not(:disabled):checked, .linked button.suggested:not(.text-button):not(:disabled):checked, button.circular.image-button.suggested-action:not(:disabled).keyboard-activating, button.image-button.suggested:not(:disabled).keyboard-activating, button.circular.image-button.suggested-action:not(:disabled):active, button.image-button.suggested:not(:disabled):active, button.circular.image-button.suggested-action:not(:disabled):checked, button.image-button.suggested:not(:disabled):checked, button.model.image-button.suggested-action:not(:disabled).keyboard-activating, button.model.image-button.suggested-action:not(:disabled):active, button.model.image-button.suggested-action:not(:disabled):checked, button.raised.image-button.suggested-action:not(:disabled).keyboard-activating, .messagedialog .response-area button.image-button.suggested-action:not(:disabled).keyboard-activating, button.raised.image-button.suggested-action:not(:disabled):active, .messagedialog .response-area button.image-button.suggested-action:not(:disabled):active, button.raised.image-button.suggested-action:not(:disabled):checked, .messagedialog .response-area button.image-button.suggested-action:not(:disabled):checked, button.raised.suggested-action:not(:disabled).keyboard-activating, .messagedialog .response-area button.suggested-action:not(:disabled).keyboard-activating, button.raised.suggested:not(:disabled).keyboard-activating, .messagedialog .response-area button.suggested:not(:disabled).keyboard-activating, button.raised.suggested-action:not(:disabled):active, .messagedialog .response-area button.suggested-action:not(:disabled):active, button.raised.suggested:not(:disabled):active, .messagedialog .response-area button.suggested:not(:disabled):active, button.raised.suggested-action:not(:disabled):checked, .messagedialog .response-area button.suggested-action:not(:disabled):checked, button.raised.suggested:not(:disabled):checked, .messagedialog .response-area button.suggested:not(:disabled):checked, button.suggested-action:not(:disabled).keyboard-activating, button.suggested:not(:disabled).keyboard-activating, button.suggested-action:not(:disabled):active, button.suggested:not(:disabled):active, button.suggested-action:not(:disabled):checked, button.suggested:not(:disabled):checked {
      border-color: rgba(0, 0, 0, 0.5); }
    .linked button.flat.keyboard-activating, .linked .sidebar .inline-toolbar button.keyboard-activating, .linked .sidebar actionbar.flat button.keyboard-activating,
    .linked .sidebar .bottom-toolbar.flat button.keyboard-activating,
    .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button.keyboard-activating,
    window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar window.csd.preferences > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.keyboard-activating,
    bottom-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.keyboard-activating,
    floating-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.keyboard-activating,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.keyboard-activating,
    bottom-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.keyboard-activating,
    bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.keyboard-activating,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.keyboard-activating,
    floating-sheet bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.keyboard-activating,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.keyboard-activating,
    floating-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button.keyboard-activating,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.keyboard-activating,
    bottom-sheet floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.keyboard-activating,
    floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar window.csd.about > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button.keyboard-activating,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.keyboard-activating,
    bottom-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.keyboard-activating,
    bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.keyboard-activating,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.keyboard-activating,
    floating-sheet bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button.keyboard-activating,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.keyboard-activating,
    .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button.keyboard-activating,
    floating-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button.keyboard-activating,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button.keyboard-activating,
    bottom-sheet floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.keyboard-activating,
    floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button.keyboard-activating,
    popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button.keyboard-activating, .sidebar .inline-toolbar .linked button.keyboard-activating, .sidebar actionbar.flat .linked button.keyboard-activating,
    .sidebar .bottom-toolbar.flat .linked button.keyboard-activating,
    .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button.keyboard-activating,
    window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar window.csd.preferences > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.keyboard-activating,
    bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .linked button.keyboard-activating,
    floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .linked button.keyboard-activating,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.keyboard-activating,
    bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.keyboard-activating,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.keyboard-activating,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.keyboard-activating,
    floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .linked button.keyboard-activating,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button.keyboard-activating,
    floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button.keyboard-activating,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button.keyboard-activating,
    bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.keyboard-activating,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar window.csd.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.keyboard-activating,
    floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button.keyboard-activating, .linked .sidebar popover.emoji-picker .emoji-toolbar button.keyboard-activating, .sidebar popover.emoji-picker .emoji-toolbar .linked button.keyboard-activating, .linked popover.emoji-picker .sidebar .emoji-toolbar button.keyboard-activating, popover.emoji-picker .sidebar .emoji-toolbar .linked button.keyboard-activating, .linked button.flat:active, .linked .sidebar .inline-toolbar button:active, .linked .sidebar actionbar.flat button:active,
    .linked .sidebar .bottom-toolbar.flat button:active,
    .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button:active,
    window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button:active,
    .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button:active,
    .linked .sidebar window.csd.preferences > headerbar.bottom-toolbar button:active,
    .linked .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button:active,
    bottom-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button:active,
    .linked .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button:active,
    floating-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button:active,
    .linked .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button:active,
    .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:active,
    .linked .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button:active,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:active,
    bottom-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button:active,
    bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button:active,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:active,
    floating-sheet bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button:active,
    .linked .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button:active,
    .linked .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button:active,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:active,
    .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:active,
    floating-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button:active,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:active,
    bottom-sheet floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button:active,
    floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button:active,
    .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button:active,
    .linked .sidebar window.csd.about > headerbar.bottom-toolbar button:active,
    .linked .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button:active,
    .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button:active,
    .linked .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button:active,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button:active,
    bottom-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button:active,
    bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button:active,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button:active,
    floating-sheet bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button:active,
    .linked .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button:active,
    .linked .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button:active,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button:active,
    .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button:active,
    floating-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button:active,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button:active,
    bottom-sheet floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button:active,
    floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button:active,
    popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button:active, .sidebar .inline-toolbar .linked button:active, .sidebar actionbar.flat .linked button:active,
    .sidebar .bottom-toolbar.flat .linked button:active,
    .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button:active,
    window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button:active,
    .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button:active,
    .sidebar window.csd.preferences > headerbar.bottom-toolbar .linked button:active,
    .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .linked button:active,
    bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button:active,
    .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .linked button:active,
    floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button:active,
    .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .linked button:active,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button:active,
    .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .linked button:active,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button:active,
    bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button:active,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button:active,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button:active,
    floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button:active,
    .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .linked button:active,
    .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .linked button:active,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button:active,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button:active,
    floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button:active,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button:active,
    bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button:active,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button:active,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button:active,
    .sidebar window.csd.about > headerbar.bottom-toolbar .linked button:active,
    .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button:active,
    .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button:active,
    .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar .linked button:active,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button:active,
    bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button:active,
    bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button:active,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button:active,
    floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button:active,
    .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button:active,
    .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button:active,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button:active,
    .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button:active,
    floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button:active,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button:active,
    bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button:active,
    floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button:active, .linked .sidebar popover.emoji-picker .emoji-toolbar button:active, .sidebar popover.emoji-picker .emoji-toolbar .linked button:active, .linked popover.emoji-picker .sidebar .emoji-toolbar button:active, popover.emoji-picker .sidebar .emoji-toolbar .linked button:active, .linked button.flat:checked, .linked .sidebar .inline-toolbar button:checked, .linked .sidebar actionbar.flat button:checked,
    .linked .sidebar .bottom-toolbar.flat button:checked,
    .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button:checked,
    window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button:checked,
    .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button:checked,
    .linked .sidebar window.csd.preferences > headerbar.bottom-toolbar button:checked,
    .linked .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button:checked,
    bottom-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button:checked,
    .linked .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button:checked,
    floating-sheet .linked .sidebar sheet.dialog > headerbar.bottom-toolbar button:checked,
    .linked .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button:checked,
    .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:checked,
    .linked .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button:checked,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:checked,
    bottom-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button:checked,
    bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button:checked,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:checked,
    floating-sheet bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button:checked,
    .linked .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button:checked,
    .linked .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button:checked,
    bottom-sheet .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:checked,
    .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:checked,
    floating-sheet .linked .sidebar sheet.csd > headerbar.bottom-toolbar button:checked,
    floating-sheet .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:checked,
    bottom-sheet floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button:checked,
    floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button:checked,
    .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button:checked,
    .linked .sidebar window.csd.about > headerbar.bottom-toolbar button:checked,
    .linked .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar button:checked,
    .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button:checked,
    .linked .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar button:checked,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button:checked,
    bottom-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button:checked,
    bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button:checked,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button:checked,
    floating-sheet bottom-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button:checked,
    .linked .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar button:checked,
    .linked .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar button:checked,
    bottom-sheet .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button:checked,
    .linked .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar button:checked,
    floating-sheet .linked .sidebar sheet.csd.about > headerbar.bottom-toolbar button:checked,
    floating-sheet .linked .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar button:checked,
    bottom-sheet floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button:checked,
    floating-sheet .linked .sidebar sheet.about > headerbar.bottom-toolbar button:checked,
    popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button:checked, .sidebar .inline-toolbar .linked button:checked, .sidebar actionbar.flat .linked button:checked,
    .sidebar .bottom-toolbar.flat .linked button:checked,
    .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button:checked,
    window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button:checked,
    .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button:checked,
    .sidebar window.csd.preferences > headerbar.bottom-toolbar .linked button:checked,
    .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .linked button:checked,
    bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button:checked,
    .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .linked button:checked,
    floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .linked button:checked,
    .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .linked button:checked,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button:checked,
    .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .linked button:checked,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button:checked,
    bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button:checked,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button:checked,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button:checked,
    floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button:checked,
    .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .linked button:checked,
    .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .linked button:checked,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button:checked,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button:checked,
    floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .linked button:checked,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button:checked,
    bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button:checked,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button:checked,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button:checked,
    .sidebar window.csd.about > headerbar.bottom-toolbar .linked button:checked,
    .sidebar bottom-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button:checked,
    .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button:checked,
    .sidebar bottom-sheet floating-sheet sheet.about > headerbar.bottom-toolbar .linked button:checked,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button:checked,
    bottom-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button:checked,
    bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button:checked,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button:checked,
    floating-sheet bottom-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button:checked,
    .sidebar floating-sheet sheet.csd.about > headerbar.bottom-toolbar .linked button:checked,
    .sidebar floating-sheet bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button:checked,
    bottom-sheet .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button:checked,
    .sidebar floating-sheet sheet.about > headerbar.bottom-toolbar .linked button:checked,
    floating-sheet .sidebar sheet.csd.about > headerbar.bottom-toolbar .linked button:checked,
    floating-sheet .sidebar bottom-sheet sheet.about > headerbar.bottom-toolbar .linked button:checked,
    bottom-sheet floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button:checked,
    floating-sheet .sidebar sheet.about > headerbar.bottom-toolbar .linked button:checked, .linked .sidebar popover.emoji-picker .emoji-toolbar button:checked, .sidebar popover.emoji-picker .emoji-toolbar .linked button:checked, .linked popover.emoji-picker .sidebar .emoji-toolbar button:checked, popover.emoji-picker .sidebar .emoji-toolbar .linked button:checked, .linked button.image-button.keyboard-activating, .linked button.image-button:active, .linked button.image-button:checked, .linked button.image-button:not(.text-button).keyboard-activating, .linked button.image-button:not(.text-button):active, .linked button.image-button:not(.text-button):checked, button.circular.image-button.keyboard-activating, button.circular.image-button:active, button.circular.image-button:checked, button.model.image-button.keyboard-activating, button.model.image-button:active, button.model.image-button:checked, button.raised.image-button.keyboard-activating, .messagedialog .response-area button.image-button.keyboard-activating, button.raised.image-button:active, .messagedialog .response-area button.image-button:active, button.raised.image-button:checked, .messagedialog .response-area button.image-button:checked, button.raised.keyboard-activating, .messagedialog .response-area button.keyboard-activating, button.raised:active, .messagedialog .response-area button:active, button.raised:checked, .messagedialog .response-area button:checked, button.keyboard-activating, button:active, button:checked {
      background: rgba(0, 0, 0, 0.05);
      box-shadow: 0 1px 0 0 alpha(@highlight_color, 0.3), inset 0 1px 1px rgba(0, 0, 0, 0.05), inset 0 0 1px 1px rgba(0, 0, 0, 0.05);
      background: rgba(0, 0, 0, 0.15); }
    .linked button.flat:disabled, .linked .sidebar .inline-toolbar button:disabled, .linked .sidebar actionbar.flat button:disabled,
    .linked .sidebar .bottom-toolbar.flat button:disabled,
    .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button:disabled,
    window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button:disabled,
    .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button:disabled,
    .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:disabled,
    bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button:disabled,
    .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:disabled,
    floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button:disabled,
    .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button:disabled,
    .linked .sidebar window.csd.about > headerbar.bottom-toolbar button:disabled,
    popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button:disabled, .sidebar .inline-toolbar .linked button:disabled, .sidebar actionbar.flat .linked button:disabled,
    .sidebar .bottom-toolbar.flat .linked button:disabled,
    .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button:disabled,
    window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button:disabled,
    .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button:disabled,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button:disabled,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button:disabled,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button:disabled,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button:disabled,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button:disabled,
    .sidebar window.csd.about > headerbar.bottom-toolbar .linked button:disabled, .linked .sidebar popover.emoji-picker .emoji-toolbar button:disabled, .sidebar popover.emoji-picker .emoji-toolbar .linked button:disabled, .linked popover.emoji-picker .sidebar .emoji-toolbar button:disabled, popover.emoji-picker .sidebar .emoji-toolbar .linked button:disabled, .linked button.image-button:disabled, .linked button.image-button:not(.text-button):disabled, button.circular.image-button:disabled, button.model.image-button:disabled, button.raised.image-button:disabled, button.raised:disabled, .messagedialog .response-area button:disabled, button:disabled {
      background: rgba(0, 0, 0, 0.03);
      box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 1px 1px rgba(0, 0, 0, 0.05); }
    .linked button.flat:focus-visible, .linked .sidebar .inline-toolbar button:focus-visible, .linked .sidebar actionbar.flat button:focus-visible,
    .linked .sidebar .bottom-toolbar.flat button:focus-visible,
    .linked .sidebar window.preferences.csd headerbar.bottom-toolbar button:focus-visible,
    window.preferences.csd .linked .sidebar headerbar.bottom-toolbar button:focus-visible,
    .linked .sidebar .dialog.csd > headerbar.bottom-toolbar button:focus-visible,
    .linked .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button:focus-visible,
    bottom-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button:focus-visible,
    .linked .sidebar floating-sheet sheet > headerbar.bottom-toolbar button:focus-visible,
    floating-sheet .linked .sidebar sheet > headerbar.bottom-toolbar button:focus-visible,
    .linked .sidebar dialog.csd.about > headerbar.bottom-toolbar button:focus-visible,
    .linked .sidebar window.csd.about > headerbar.bottom-toolbar button:focus-visible,
    popover.emoji-picker .linked .sidebar .emoji-toolbar button.bottom-toolbar button:focus-visible, .sidebar .inline-toolbar .linked button:focus-visible, .sidebar actionbar.flat .linked button:focus-visible,
    .sidebar .bottom-toolbar.flat .linked button:focus-visible,
    .sidebar window.preferences.csd headerbar.bottom-toolbar .linked button:focus-visible,
    window.preferences.csd .sidebar headerbar.bottom-toolbar .linked button:focus-visible,
    .sidebar .dialog.csd > headerbar.bottom-toolbar .linked button:focus-visible,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .linked button:focus-visible,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button:focus-visible,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar .linked button:focus-visible,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar .linked button:focus-visible,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar .linked button:focus-visible,
    .sidebar window.csd.about > headerbar.bottom-toolbar .linked button:focus-visible, .linked .sidebar popover.emoji-picker .emoji-toolbar button:focus-visible, .sidebar popover.emoji-picker .emoji-toolbar .linked button:focus-visible, .linked popover.emoji-picker .sidebar .emoji-toolbar button:focus-visible, popover.emoji-picker .sidebar .emoji-toolbar .linked button:focus-visible, .linked button.image-button:focus-visible, .linked button.image-button:not(.text-button):focus-visible, button.circular.image-button:focus-visible, button.model.image-button:focus-visible, button.raised.image-button:focus-visible, button.raised:focus-visible, .messagedialog .response-area button:focus-visible, button:focus-visible {
      color: @selected_fg_color;
      outline-color: alpha(@accent_color, 0.3);
      outline-width: 0.1666666677rem;
      outline-style: solid; }
  button.back-button {
    background-repeat: no-repeat no-repeat;
    background-size: 16px, cover; }
    button.back-button:dir(ltr) {
      background-image: -gtk-icontheme("go-previous-symbolic"), linear-gradient(to bottom, alpha(@highlight_color, 0.2), rgba(255, 255, 255, 0));
      padding-left: calc(0.750000001rem + 16px);
      background-position: 0.500000001rem 50%, center, center; }
    button.back-button:dir(rtl) {
      background-image: -gtk-icontheme("go-next-symbolic"), linear-gradient(to bottom, alpha(@highlight_color, 0.2), rgba(255, 255, 255, 0));
      padding-right: calc(0.750000001rem + 16px);
      background-position: calc(100% - 0.500000001rem) 50%, center, center; }
  button:disabled {
    color: #999999; }
  button:backdrop {
    filter: opacity(0.5); }
  button.color, button.combo, button.image-button {
    padding: 0.3333333343rem; }
  button.text-button.link {
    padding: 0; }
  button.color colorswatch,
  button.color overlay {
    border-radius: 0.1666666677rem; }
  button arrow {
    min-width: 1.3333333343rem;
    min-height: 1.3333333343rem;
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
  button:dir(ltr) box image + label, button:dir(rtl) box label + image {
    margin-left: 0.250000001rem; }

fontbutton separator.vertical {
  margin: 0 0.500000001rem; }

calendar.view {
  background: transparent; }
  calendar.view .day-name {
    font-weight: 700;
    opacity: 0.8;
    padding-bottom: 0.5em;
    padding-top: 0.5em; }
  calendar.view .day-number.today {
    font-weight: bold; }
  calendar.view .day-number.other-month {
    color: #999999; }
  calendar.view .day-number:selected {
    border-radius: 99px; }

.deck {
  background-color: #313131; }

paper,
.card {
  background-color: #3a3a3a;
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 4px rgba(0, 0, 0, 0.25), 0 3px 3px -3px rgba(0, 0, 0, 0.45);
  transition: background 100ms cubic-bezier(0.4, 0, 0.2, 1), box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1); }
  paper.collapsed,
  .card.collapsed {
    background-color: #333;
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px rgba(0, 0, 0, 0.1), 0 1px 3px rgba(0, 0, 0, 0.42), 0 1px 2px rgba(0, 0, 0, 0.44);
    transition: background 100ms cubic-bezier(0.4, 0, 0.2, 1), box-shadow 250ms cubic-bezier(0.4, 0, 0.2, 1); }
  paper.rounded,
  .card.rounded {
    border-radius: 0.250000001rem; }

check,
radio {
  background-color: #404040;
  border: 1px solid rgba(0, 0, 0, 0.3);
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 1px 1px rgba(0, 0, 0, 0.05);
  min-height: 1.000000001rem;
  min-width: 1.000000001rem;
  transition: all 100ms cubic-bezier(0.4, 0, 0.2, 1);
  -gtk-icon-source: none;
  -gtk-icon-size: 1.000000001rem; }
  check:dir(ltr),
  radio:dir(ltr) {
    margin-right: 0.500000001rem; }
  check:dir(rtl),
  radio:dir(rtl) {
    margin-left: 0.500000001rem; }
  check:checked,
  radio:checked {
    background-color: @accent_color;
    color: white;
    -gtk-icon-source: -gtk-icontheme("check-active-symbolic");
    -gtk-icon-shadow: 0 1px 1px shade(@accent_color, 0.7);
    background-clip: padding-box; }
    check:checked:backdrop:not(:disabled):not(.colorbutton),
    radio:checked:backdrop:not(:disabled):not(.colorbutton) {
      background-image: none;
      background-color: #252525;
      -gtk-icon-shadow: 0 1px 1px rgba(0, 0, 0, 0.3); }
  check:disabled,
  radio:disabled {
    background: rgba(0, 0, 0, 0.075);
    box-shadow: 0 1px 0 0 alpha(@bg_highlight_color, 0.3);
    color: #999999;
    -gtk-icon-shadow: 0 1px 1px alpha(@bg_highlight_color, 0.3); }
  check:indeterminate,
  radio:indeterminate {
    -gtk-icon-source: -gtk-icontheme("check-mixed-symbolic"); }
  check:focus-visible,
  radio:focus-visible {
    box-shadow: 0 0 0 2px alpha(@accent_color, 0.3), inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 1px 1px rgba(0, 0, 0, 0.05); }

check {
  border-radius: 0.250000001rem; }

radio {
  border-radius: 50%; }

checkbutton.image-button {
  border: 1px solid transparent;
  padding: 0.500000001rem; }
  checkbutton.image-button:checked {
    background: alpha(@selected_bg_color, 0.4);
    border-color: @selected_bg_color;
    border-radius: 0.250000001rem;
    color: @selected_fg_color; }
    checkbutton.image-button:checked:backdrop {
      background: rgba(255, 255, 255, 0.05);
      border-color: rgba(255, 255, 255, 0.25);
      color: inherit; }

.color-button check,
.color-button check:checked,
.color-button radio,
.color-button radio:checked {
  background-image: none;
  border: 1px solid rgba(0, 0, 0, 0.2);
  border-radius: 50%;
  box-shadow: 0 1px 0 0 alpha(@highlight_color, 0.3), inset 0 1px 1px rgba(0, 0, 0, 0.05), inset 0 0 1px 1px rgba(0, 0, 0, 0.05);
  min-height: 1.000000001rem;
  min-width: 1.000000001rem;
  padding: 0.250000001rem;
  background-clip: padding-box;
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 1px 1px rgba(0, 0, 0, 0.07), 0 1px 2px rgba(0, 0, 0, 0.08); }

.color-button.red check, .color-button.red radio, .color-button.strawberry check, .color-button.strawberry radio {
  background-color: @STRAWBERRY_300;
  -gtk-icon-shadow: 0 1px 1px @STRAWBERRY_500; }

.color-button.orange check, .color-button.orange radio {
  background-color: @ORANGE_300;
  -gtk-icon-shadow: 0 1px 1px @ORANGE_500; }

.color-button.yellow check, .color-button.yellow radio, .color-button.banana check, .color-button.banana radio {
  background-color: @BANANA_500;
  -gtk-icon-shadow: 0 1px 1px @BANANA_700; }

.color-button.green check, .color-button.green radio, .color-button.lime check, .color-button.lime radio {
  background-color: @LIME_500;
  -gtk-icon-shadow: 0 1px 1px @LIME_700; }

.color-button.blue check, .color-button.blue radio, .color-button.blueberry check, .color-button.blueberry radio {
  background-color: @BLUEBERRY_500;
  -gtk-icon-shadow: 0 1px 1px @BLUEBERRY_700; }

.color-button.purple check, .color-button.purple radio, .color-button.grape check, .color-button.grape radio {
  background-color: @GRAPE_500;
  -gtk-icon-shadow: 0 1px 1px @GRAPE_700; }

.color-button.brown check, .color-button.brown radio, .color-button.cocoa check, .color-button.cocoa radio {
  background-color: @COCOA_300;
  -gtk-icon-shadow: 0 1px 1px @COCOA_500; }

.color-button.mint check, .color-button.mint radio {
  background-color: @MINT_500;
  -gtk-icon-shadow: 0 1px 1px @MINT_700; }

.color-button.pink check, .color-button.pink radio, .color-button.bubblegum check, .color-button.bubblegum radio {
  background-color: @BUBBLEGUM_500;
  -gtk-icon-shadow: 0 1px 1px @BUBBLEGUM_700; }

.color-button.slate check, .color-button.slate radio {
  background-color: @SLATE_300;
  -gtk-icon-shadow: 0 1px 1px @SLATE_500; }

.color-button.latte check, .color-button.latte radio {
  background-color: @LATTE_300;
  -gtk-icon-shadow: 0 1px 1px @LATTE_500; }

.color-button.auto radio {
  background-image: url("assets/color-button-auto.png");
  background-position: -1px -1px;
  background-repeat: no-repeat;
  background-size: calc(100% + 2px); }

colorchooser {
  /* This is 1px larger in the dark style because it's outside the swatch
     * instead of on top */
  /*Value and Custom shades*/ }
  colorchooser colorswatch {
    margin: -1px 3px; }
    colorchooser colorswatch.top {
      border-top-width: 1px;
      border-top-left-radius: 0.250000001rem;
      border-top-right-radius: 0.250000001rem; }
      colorchooser colorswatch.top overlay {
        border-top-width: 1px;
        border-top-left-radius: 0.3333333343rem;
        border-top-right-radius: 0.3333333343rem;
        box-shadow: inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07); }
    colorchooser colorswatch.bottom {
      border-bottom-width: 1px;
      border-bottom-left-radius: 0.250000001rem;
      border-bottom-right-radius: 0.250000001rem;
      box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24); }
      colorchooser colorswatch.bottom overlay {
        border-bottom-width: 1px;
        border-bottom-left-radius: 0.3333333343rem;
        border-bottom-right-radius: 0.3333333343rem;
        box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07); }
    colorchooser colorswatch overlay {
      border: 1px solid rgba(0, 0, 0, 0.2);
      border-bottom-width: 0;
      border-top-width: 0;
      box-shadow: inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07);
      margin: -2px 2px; }
    colorchooser colorswatch.dark overlay {
      color: white;
      -gtk-icon-shadow: 0 0.0833333343rem 0.1666666677rem rgba(0, 0, 0, 0.3); }
    colorchooser colorswatch.light overlay {
      color: rgba(0, 0, 0, 0.6);
      -gtk-icon-shadow: 0 0.0833333343rem 0.0833333343rem rgba(255, 255, 255, 0.2); }
  colorchooser grid:nth-child(2) colorswatch,
  colorchooser box box colorswatch {
    border-radius: 0.250000001rem;
    box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24); }
    colorchooser grid:nth-child(2) colorswatch overlay,
    colorchooser box box colorswatch overlay {
      border-radius: 0.3333333343rem;
      border-width: 1px;
      box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07); }

columnview header button {
  border-radius: 0;
  border-left-width: 0;
  border-top-width: 0; }
  columnview header button:last-child {
    border-right-width: 0; }
  columnview header button label {
    font-weight: 600;
    opacity: 0.8; }
  columnview header button:backdrop label {
    opacity: 0.6; }
  columnview header button sort-indicator {
    min-height: 16px;
    min-width: 16px; }
    columnview header button sort-indicator.ascending {
      -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
    columnview header button sort-indicator.descending {
      -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

columnview listview row {
  padding: 0.250000001rem 0.500000001rem; }
  columnview listview row:selected {
    background: rgba(255, 255, 255, 0.15); }

dropdown popover listview,
dropdown popover listview.view {
  background: transparent; }
  dropdown popover listview row.activatable image:last-child,
  dropdown popover listview.view row.activatable image:last-child {
    border-radius: 0.6666666677rem;
    -gtk-icon-size: 1.000000001rem;
    margin: 0 0.500000001rem;
    min-height: 1.3333333343rem;
    min-width: 1.3333333343rem; }

dropdown popover .dropdown-searchbar {
  padding: 0.500000001rem 1.000000001rem; }

popover.emoji-picker entry {
  margin: 1.000000001rem;
  margin-bottom: 0.250000001rem; }

popover.emoji-picker scrolledwindow.view box.vertical > label {
  margin-left: 0.5833333343rem;
  margin-right: 0.5833333343rem; }

popover.emoji-picker .emoji {
  min-height: 36px;
  min-width: 36px;
  font-size: 16px; }

popover.emoji-picker button.emoji-section.image-button {
  background: none;
  border-width: 0;
  border-radius: 0;
  box-shadow: none;
  min-height: 24px;
  min-width: 24px;
  opacity: 0.6;
  outline-style: none; }
  popover.emoji-picker button.emoji-section.image-button:checked {
    opacity: 1; }
  popover.emoji-picker button.emoji-section.image-button:hover {
    opacity: 0.8; }
  popover.emoji-picker button.emoji-section.image-button image {
    color: inherit; }

spinbutton, entry {
  background-color: #3a3a3a;
  background-clip: padding-box;
  border: 1px solid rgba(0, 0, 0, 0.3);
  border-radius: 0.250000001rem;
  box-shadow: 0 1px 0 0 alpha(@highlight_color, 0.3), inset 0 1px 1px rgba(0, 0, 0, 0.05), inset 0 0 1px 1px rgba(0, 0, 0, 0.05);
  color: @fg_color; }
  spinbutton:disabled, entry:disabled {
    background: rgba(0, 0, 0, 0.075);
    box-shadow: 0 1px 0 0 alpha(@highlight_color, 0.3), inset 0 1px 1px rgba(0, 0, 0, 0.05);
    color: #999999; }
  spinbutton.flat, entry.flat {
    background: transparent;
    border-color: transparent;
    border-radius: 0;
    box-shadow: none; }
    spinbutton.flat:focus, entry.flat:focus {
      border-bottom-color: @accent_color; }
  spinbutton:focus-within, entry:focus-within {
    box-shadow: 0 0 0 0.1666666677rem alpha(@accent_color, 0.3), 0 1px 0 0 alpha(@highlight_color, 0.3), inset 0 1px 1px rgba(0, 0, 0, 0.05), inset 0 0 1px 1px rgba(0, 0, 0, 0.05); }
  spinbutton placeholder, entry placeholder {
    color: @placeholder_text_color;
    margin: 0; }

entry {
  color: @placeholder_text_color;
  min-height: 16px; }
  entry text {
    color: @text_color;
    padding: 0.3333333343rem; }
    entry text:disabled {
      color: #999999; }
  entry image {
    -gtk-icon-size: 16px;
    padding: 0 0.3333333343rem;
    transition: all 100ms cubic-bezier(0.4, 0, 0.2, 1); }
  entry:dir(ltr) image.right:hover, entry:dir(rtl) image.left:hover {
    color: @text_color; }
  headerbar entry {
    margin: 1px; }
  entry progress > trough {
    margin: 0.3333333343rem; }
    entry progress > trough > progress {
      background: @accent_color;
      border-radius: 0.1666666677rem;
      min-height: 0.1666666677rem;
      min-width: 0.1666666677rem; }
  entry.date-picker popover > contents {
    padding: 0.500000001rem; }
  entry.time-picker popover > contents {
    padding: 1.000000001rem; }
  entry.password {
    background-image: -gtk-icontheme("dialog-password-symbolic");
    background-size: 16px;
    background-repeat: no-repeat; }
    entry.password:dir(ltr) {
      background-position: 0.500000001rem 0.3333333343rem;
      padding-left: 2.000000001rem; }
    entry.password:dir(rtl) {
      background-position: calc(100% - 0.500000001rem) 0.3333333343rem;
      padding-right: 2.000000001rem; }

expander {
  min-height: 16px;
  min-width: 16px;
  transition: all 100ms cubic-bezier(0.4, 0, 0.2, 1);
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }
  expander:dir(rtl) {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }
  expander:checked {
    -gtk-icon-transform: rotate(90deg); }
    expander:checked:dir(rtl) {
      -gtk-icon-transform: rotate(-90deg); }

headerbar {
  background-color: @color_primary;
  border-radius: 0.500000001rem 0.500000001rem 0 0;
  color: white; }
  headerbar .title {
    font-weight: bold;
    text-shadow: 0 1px rgba(0, 0, 0, 0.67); }
  headerbar .subtitle {
    opacity: 0.75;
    font-size: 80%; }
  headerbar windowcontrols button,
  headerbar .image-button,
  headerbar .mode-switch {
    -gtk-icon-shadow: 0 1px rgba(0, 0, 0, 0.67); }
  headerbar popover,
  headerbar menu {
    text-shadow: none;
    -gtk-icon-shadow: none; }
  headerbar box.start,
  headerbar box.end {
    border-spacing: 0.500000001rem; }
  headerbar box.start:dir(ltr),
  headerbar box.end:dir(rtl) {
    margin-right: 1.000000001rem; }
  headerbar box.end:dir(ltr),
  headerbar box.start:dir(rtl) {
    margin-left: 1.000000001rem; }
  headerbar .large-icons {
    -gtk-icon-size: 24px; }
  headerbar revealer headerbar {
    border-bottom: 1px solid rgba(0, 0, 0, 0.75);
    border-radius: 0.500000001rem 0.500000001rem 0 0;
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07);
    padding: 0.500000001rem; }
  .csd headerbar, bottom-sheet sheet headerbar,
  floating-sheet sheet headerbar {
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 1px 0 0 alpha(shade(@color_primary, 0.7), 0.4), 0 1px 0.1666666677rem rgba(0, 0, 0, 0.2);
    padding: 0.500000001rem;
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px alpha(shade(@color_primary, 0.5), 0.5), 0 1px 0.1666666677rem rgba(0, 0, 0, 0.2); }
    .csd headerbar:backdrop, bottom-sheet sheet headerbar:backdrop,
    floating-sheet sheet headerbar:backdrop {
      box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px alpha(shade(@color_primary, 0.7), 0.3), 0 1px 0.1666666677rem rgba(0, 0, 0, 0.15); }
    .csd headerbar.default-decoration, bottom-sheet sheet headerbar.default-decoration,
    floating-sheet sheet headerbar.default-decoration {
      padding: 0.250000001rem; }
    .csd headerbar.flat, window.preferences.csd headerbar, bottom-sheet sheet headerbar.flat,
    floating-sheet sheet headerbar.flat, .dialog.csd > headerbar, bottom-sheet sheet.dialog > headerbar,
    floating-sheet sheet.dialog > headerbar, bottom-sheet sheet.csd > headerbar, bottom-sheet sheet > headerbar,
    floating-sheet sheet.csd > headerbar,
    floating-sheet sheet > headerbar, dialog.csd.about > headerbar,
    window.csd.about > headerbar,
    bottom-sheet sheet.csd.about > headerbar,
    bottom-sheet sheet.about > headerbar,
    floating-sheet sheet.csd.about > headerbar,
    floating-sheet sheet.about > headerbar {
      background: inherit;
      color: inherit;
      box-shadow: inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07); }
  .ssd headerbar {
    border-bottom: 1px solid rgba(0, 0, 0, 0.75);
    border-radius: 6px 6px 0 0;
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07);
    padding: 3px; }
    .ssd headerbar button {
      border-radius: 3px;
      padding: 3px; }

image {
  -gtk-icon-palette: error @error_color, success @success_color, warning #f9c440; }
  image:disabled {
    filter: opacity(0.5); }

.normal-icons {
  -gtk-icon-size: 16px; }

.large-icons {
  -gtk-icon-size: 32px; }

infobar revealer > box {
  background-color: #3a3a3a;
  background-image: -gtk-icontheme("dialog-information-symbolic");
  background-repeat: no-repeat;
  background-size: 16px;
  border-color: rgba(0, 0, 0, 0.3);
  border-style: solid;
  border-width: 0 0 1px;
  border-spacing: 1.000000001rem;
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07);
  padding: 0.500000001rem;
  background-clip: padding-box; }
  infobar revealer > box:dir(ltr) {
    background-position: 0.750000001rem calc(50% + 0.5px);
    padding-left: calc(16px + 1.000000001rem); }
  infobar revealer > box:dir(rtl) {
    background-position: calc(100% - 0.750000001rem) calc(50% + 0.5px);
    padding-right: calc(16px + 1.000000001rem); }
  infobar revealer > box > box:first-child {
    padding: 6px; }
  infobar revealer > box button.close.image-button {
    background: alpha(white, 0.8);
    border-radius: 50%;
    color: inherit;
    padding: 0.250000001rem; }
  infobar revealer > box button.text-button {
    background-clip: border-box; }

infobar.error revealer > box {
  background-color: mix(@STRAWBERRY_300, white, 0.75);
  background-image: -gtk-icontheme("process-error-symbolic");
  color: #a10705;
  -gtk-icon-palette: error #a10705; }

infobar.warning revealer > box {
  background-color: mix(@BANANA_300, white, 0.6);
  background-image: -gtk-icontheme("dialog-warning-symbolic");
  color: shade(@BANANA_900, 0.8);
  -gtk-icon-palette: warning shade(@BANANA_900, 0.8); }

infobar.question revealer > box {
  background-color: mix(@BLUEBERRY_300, white, 0.75);
  background-image: -gtk-icontheme("dialog-question-symbolic");
  color: shade(@BLUEBERRY_300, 0.5); }

infobar.frame {
  border: none; }
  infobar.frame revealer > box {
    border-width: 1px;
    border-radius: 0.500000001rem;
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 1px 1px rgba(0, 0, 0, 0.07), 0 1px 2px rgba(0, 0, 0, 0.08);
    margin: 0.250000001rem; }

levelbar block {
  background-color: @accent_color_300;
  border: 1px solid rgba(0, 0, 0, 0.3);
  border-radius: 0.500000001rem;
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 1px 1px rgba(0, 0, 0, 0.05);
  transition: all 100ms cubic-bezier(0.4, 0, 0.2, 1);
  background-clip: padding-box; }
  levelbar block.filled.low {
    background-color: #c6262e; }
  levelbar block.filled.middle {
    background-color: #f9c440; }
  levelbar block.filled.high {
    background-color: #64baff; }
  levelbar block.filled.full {
    background-color: #9bdb4d; }
  levelbar block.filled:backdrop {
    background-color: #252525; }
  levelbar block.empty {
    background-color: #404040; }

levelbar.discrete.horizontal block {
  min-width: 2.000000001rem; }
  levelbar.discrete.horizontal block:not(:first-child) {
    margin-left: 0.250000001rem; }

levelbar.discrete.vertical block {
  margin: 2px 0;
  min-height: 2.000000001rem; }

levelbar.inverted block.filled.low {
  background-color: #9bdb4d; }

levelbar.inverted block.filled.middle {
  background-color: #64baff; }

levelbar.inverted block.filled.high {
  background-color: #f9c440; }

levelbar.inverted block.filled.full {
  background-color: #c6262e; }

levelbar.horizontal block {
  min-height: 0.500000001rem;
  min-width: 0.250000001rem; }

levelbar.vertical block {
  min-height: 0.250000001rem;
  min-width: 0.500000001rem; }

levelbar.flat block {
  border: none;
  box-shadow: none; }
  levelbar.flat block.empty {
    background: rgba(255, 255, 255, 0.2); }
  levelbar.flat block.filled.low:not(:backdrop) {
    background: #ed5353; }
    levelbar.flat block.filled.low:not(:backdrop) + .empty:not(:backdrop) {
      background: rgba(237, 83, 83, 0.2); }
  levelbar.flat block.filled.middle:not(:backdrop) {
    background: #fff394; }
    levelbar.flat block.filled.middle:not(:backdrop) + .empty:not(:backdrop) {
      background: rgba(255, 243, 148, 0.2); }
  levelbar.flat block.filled.high:not(:backdrop) {
    background: rgba(255, 255, 255, 0.6); }
  levelbar.flat block.filled.full:not(:backdrop) {
    background: #9bdb4d; }
    levelbar.flat block.filled.full:not(:backdrop) + .empty:not(:backdrop) {
      background: rgba(155, 219, 77, 0.2); }
  levelbar.flat block.filled:backdrop {
    background: rgba(255, 255, 255, 0.2); }

levelbar.flat.inverted block.filled.low:not(:backdrop) {
  background: #9bdb4d; }
  levelbar.flat.inverted block.filled.low:not(:backdrop) + .empty:not(:backdrop) {
    background: rgba(155, 219, 77, 0.2); }

levelbar.flat.inverted block.filled.middle:not(:backdrop) {
  background: rgba(255, 255, 255, 0.6); }

levelbar.flat.inverted block.filled.high:not(:backdrop) {
  background: #fff394; }
  levelbar.flat.inverted block.filled.high:not(:backdrop) + .empty:not(:backdrop) {
    background: rgba(255, 243, 148, 0.2); }

levelbar.flat.inverted block.filled.full:not(:backdrop) {
  background: #ed5353; }
  levelbar.flat.inverted block.filled.full:not(:backdrop) + .empty:not(:backdrop) {
    background: rgba(237, 83, 83, 0.2); }

.linked:not(.vertical) > combobox:dir(ltr):not(:first-child) > box > button.combo, .linked:not(.vertical) > combobox:dir(rtl):not(:last-child) > box > button.combo, combobox.linked button:nth-child(2), viewswitcher > box > button.horizontal.radio:dir(ltr):not(:first-child), viewswitcher > box > button.horizontal.radio:dir(rtl):not(:last-child),
.linked:not(.vertical) > button:dir(ltr):not(:first-child),
.linked:not(.vertical) > button:dir(rtl):not(:last-child),
.linked:not(.vertical) > button.image-button:dir(ltr):not(:first-child),
.linked:not(.vertical) > button.image-button:dir(rtl):not(:last-child),
.linked:not(.vertical) > entry:dir(ltr):not(:first-child),
.linked:not(.vertical) > entry:dir(rtl):not(:last-child),
.linked:not(.vertical) > spinbutton:dir(ltr):not(:first-child),
.linked:not(.vertical) > spinbutton:dir(rtl):not(:last-child) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  margin-left: 0; }

.linked:not(.vertical) > combobox:dir(ltr):not(:last-child) > box > button.combo, .linked:not(.vertical) > combobox:dir(rtl):not(:first-child) > box > button.combo, viewswitcher > box > button.horizontal.radio:dir(ltr):not(:last-child), viewswitcher > box > button.horizontal.radio:dir(rtl):not(:first-child),
.linked:not(.vertical) > button:dir(ltr):not(:last-child),
.linked:not(.vertical) > button:dir(rtl):not(:first-child),
.linked:not(.vertical) > button.image-button:dir(ltr):not(:last-child),
.linked:not(.vertical) > button.image-button:dir(rtl):not(:first-child),
.linked:not(.vertical) > entry:dir(ltr):not(:last-child),
.linked:not(.vertical) > entry:dir(rtl):not(:first-child),
.linked:not(.vertical) > spinbutton:dir(ltr):not(:last-child),
.linked:not(.vertical) > spinbutton:dir(rtl):not(:first-child) {
  border-right-style: none;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  margin-right: 0; }

.linked.vertical > combobox:dir(ltr):not(:first-child) > box > button.combo, .linked.vertical > combobox:dir(rtl):not(:last-child) > box > button.combo, .linked.vertical > button:dir(ltr):not(:first-child), .linked.vertical > button:dir(rtl):not(:last-child),
.linked.vertical > button.image-button:dir(ltr):not(:first-child),
.linked.vertical > button.image-button:dir(rtl):not(:last-child),
.linked.vertical > entry:dir(ltr):not(:first-child),
.linked.vertical > entry:dir(rtl):not(:last-child),
.linked.vertical > spinbutton:dir(ltr):not(:first-child),
.linked.vertical > spinbutton:dir(rtl):not(:last-child) {
  border-top-left-radius: 0;
  border-top-right-radius: 0; }

.linked.vertical > combobox:dir(ltr):not(:last-child) > box > button.combo, .linked.vertical > combobox:dir(rtl):not(:first-child) > box > button.combo, .linked.vertical > button:dir(ltr):not(:last-child), .linked.vertical > button:dir(rtl):not(:first-child),
.linked.vertical > button.image-button:dir(ltr):not(:last-child),
.linked.vertical > button.image-button:dir(rtl):not(:first-child),
.linked.vertical > entry:dir(ltr):not(:last-child),
.linked.vertical > entry:dir(rtl):not(:first-child),
.linked.vertical > spinbutton:dir(ltr):not(:last-child),
.linked.vertical > spinbutton:dir(rtl):not(:first-child) {
  border-bottom-style: none;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0; }

list,
listview {
  background-color: #3a3a3a; }
  popover list, popover listview {
    background-color: transparent; }
  list row:focus-visible, list row:selected,
  listview row:focus-visible,
  listview row:selected {
    background: rgba(255, 255, 255, 0.15); }
  list header,
  list .title-4,
  list .h4,
  list shortcuts-group > label,
  list popover.emoji-picker scrolledwindow.view box.vertical > label,
  popover.emoji-picker scrolledwindow.view list box.vertical > label,
  listview header,
  listview .title-4,
  listview .h4,
  listview shortcuts-group > label,
  listview popover.emoji-picker scrolledwindow.view box.vertical > label,
  popover.emoji-picker scrolledwindow.view listview box.vertical > label {
    margin: 0.5em; }
  list.rich-list > row,
  listview.rich-list > row {
    padding: 0.500000001rem;
    min-height: 2.6666666677rem; }
    list.rich-list > row > box button.toggle,
    list.rich-list > row > box > fontbutton,
    list.rich-list > row > box > entry,
    list.rich-list > row > box > spinbutton,
    listview.rich-list > row > box button.toggle,
    listview.rich-list > row > box > fontbutton,
    listview.rich-list > row > box > entry,
    listview.rich-list > row > box > spinbutton {
      margin: 0.250000001rem 0; }
  list.horizontal row.separator, list.separators.horizontal > row:not(.separator) + row:not(.separator),
  listview.horizontal row.separator,
  listview.separators.horizontal > row:not(.separator) + row:not(.separator) {
    border-right: 1px solid @menu_separator; }
  list:not(.horizontal) row.separator, list.separators:not(.horizontal) > row:not(.separator) + row:not(.separator),
  listview:not(.horizontal) row.separator,
  listview.separators:not(.horizontal) > row:not(.separator) + row:not(.separator) {
    border-top: 1px solid @menu_separator; }

menubar > item {
  padding: 0.250000001rem 0.500000001rem; }
  menubar > item image,
  menubar > item label {
    padding: 0.250000001rem; }

tabbar .box, notebook header {
  background-color: shade(@tab_base_color, 0.95);
  background-color: shade(@tab_base_color, 0.87);
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0), rgba(0, 0, 0, 0) calc(100% - 0.1666666677rem), rgba(0, 0, 0, 0.05) calc(100% - 0.0833333343rem), rgba(0, 0, 0, 0.15)); }
  tabbar .bottom.box, notebook header.bottom {
    background-image: linear-gradient(to top, rgba(0, 0, 0, 0), rgba(0, 0, 0, 0) calc(100% - 0.1666666677rem), rgba(0, 0, 0, 0.05) calc(100% - 0.0833333343rem), rgba(0, 0, 0, 0.15)); }
  tabbar .right.box, notebook header.right {
    background-image: linear-gradient(to left, rgba(0, 0, 0, 0), rgba(0, 0, 0, 0) calc(100% - 0.1666666677rem), rgba(0, 0, 0, 0.05) calc(100% - 0.0833333343rem), rgba(0, 0, 0, 0.15)); }
  tabbar .left.box, notebook header.left {
    background-image: linear-gradient(to right, rgba(0, 0, 0, 0), rgba(0, 0, 0, 0) calc(100% - 0.1666666677rem), rgba(0, 0, 0, 0.05) calc(100% - 0.0833333343rem), rgba(0, 0, 0, 0.15)); }
  tabbar .box:backdrop, notebook header:backdrop {
    background-color: shade(@tab_base_color, 0.98); }

notebook header > box > button.image-button,
notebook header > button.image-button {
  min-width: 2.000000001rem; }

notebook header arrow {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
  min-height: 16px;
  min-width: 16px; }
  notebook header arrow.down {
    -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }
  notebook header arrow:disabled {
    color: #999999; }

notebook viewport {
  background-color: #3a3a3a; }

tab {
  border-radius: 0.250000001rem;
  transition: all 100ms cubic-bezier(0.4, 0, 0.2, 1);
  min-width: 24px;
  padding: 0.250000001rem; }
  .bottom tab, .top tab {
    margin: 0.250000001rem 0; }
  .left tab, .right tab {
    margin: 0 0.250000001rem; }
  tab:hover:not(:checked):not(:selected) {
    background-color: shade(@tab_base_color, 0.9); }
  tab:checked, tab:selected {
    background-color: @tab_base_color;
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px rgba(0, 0, 0, 0.24), 0 1px 1px rgba(0, 0, 0, 0.07), 0 1px 2px rgba(0, 0, 0, 0.08); }
    tab:checked:backdrop, tab:selected:backdrop {
      background-color: shade(@tab_base_color, 0.97); }

window.notification .draw-area, bottom-sheet sheet.notification .draw-area,
floating-sheet sheet.notification .draw-area {
  background-color: #333;
  border-radius: 0.500000001rem;
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px rgba(0, 0, 0, 0.75), 0 3px 8px 2px rgba(0, 0, 0, 0.2), 0 5px 5px -3px rgba(0, 0, 0, 0.5), 0 8px 5px 1px rgba(0, 0, 0, 0.2); }
  window.notification .draw-area image, bottom-sheet sheet.notification .draw-area image,
  floating-sheet sheet.notification .draw-area image {
    color: rgba(255, 255, 255, 0.78); }
  window.notification .draw-area label.title, bottom-sheet sheet.notification .draw-area label.title,
  floating-sheet sheet.notification .draw-area label.title {
    font-weight: 700; }
  window.notification .draw-area .urgent label.title, bottom-sheet sheet.notification .draw-area .urgent label.title,
  floating-sheet sheet.notification .draw-area .urgent label.title {
    color: @error_color; }

.osd, toastoverlay toast, .app-notification {
  background-color: rgba(255, 255, 255, 0.9);
  border: none;
  color: #3a3a3a;
  padding: 0.500000001rem;
  border-radius: 0.500000001rem;
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.42), 0 1px 2px rgba(0, 0, 0, 0.44);
  margin: 0.500000001rem; }
  .osd button.flat.image-button, toastoverlay toast button.flat.image-button, .osd .sidebar .inline-toolbar button.image-button, toastoverlay toast .sidebar .inline-toolbar button.image-button, .osd .sidebar actionbar.flat button.image-button, toastoverlay toast .sidebar actionbar.flat button.image-button,
  .osd .sidebar .bottom-toolbar.flat button.image-button,
  toastoverlay toast .sidebar .bottom-toolbar.flat button.image-button,
  .osd .sidebar window.preferences.csd headerbar.bottom-toolbar button.image-button,
  toastoverlay toast .sidebar window.preferences.csd headerbar.bottom-toolbar button.image-button,
  window.preferences.csd .osd .sidebar headerbar.bottom-toolbar button.image-button,
  window.preferences.csd toastoverlay toast .sidebar headerbar.bottom-toolbar button.image-button,
  toastoverlay window.preferences.csd toast .sidebar headerbar.bottom-toolbar button.image-button,
  .osd .sidebar .dialog.csd > headerbar.bottom-toolbar button.image-button,
  toastoverlay toast .sidebar .dialog.csd > headerbar.bottom-toolbar button.image-button,
  .osd .sidebar window.csd.preferences > headerbar.bottom-toolbar button.image-button,
  toastoverlay toast .sidebar window.csd.preferences > headerbar.bottom-toolbar button.image-button,
  .osd .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.image-button,
  toastoverlay toast .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.image-button,
  bottom-sheet .osd .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button,
  bottom-sheet toastoverlay toast .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button,
  toastoverlay bottom-sheet toast .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button,
  .osd .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.image-button,
  toastoverlay toast .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.image-button,
  floating-sheet .osd .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button,
  floating-sheet toastoverlay toast .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button,
  toastoverlay floating-sheet toast .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button,
  .osd .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.image-button,
  toastoverlay toast .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.image-button,
  .osd .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  toastoverlay toast .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  .osd .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  toastoverlay toast .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  floating-sheet .osd .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  floating-sheet toastoverlay toast .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  toastoverlay floating-sheet toast .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  bottom-sheet .osd .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button,
  bottom-sheet toastoverlay toast .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button,
  toastoverlay bottom-sheet toast .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button,
  bottom-sheet .osd .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  bottom-sheet toastoverlay toast .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  toastoverlay bottom-sheet toast .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  bottom-sheet .osd .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  bottom-sheet toastoverlay toast .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  toastoverlay bottom-sheet toast .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  floating-sheet bottom-sheet .osd .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  floating-sheet bottom-sheet toastoverlay toast .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  toastoverlay floating-sheet bottom-sheet toast .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  .osd .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.image-button,
  toastoverlay toast .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.image-button,
  .osd .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  toastoverlay toast .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  bottom-sheet .osd .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  bottom-sheet toastoverlay toast .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  toastoverlay bottom-sheet toast .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  .osd .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  toastoverlay toast .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  floating-sheet .osd .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button,
  floating-sheet toastoverlay toast .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button,
  toastoverlay floating-sheet toast .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button,
  floating-sheet .osd .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  floating-sheet toastoverlay toast .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  toastoverlay floating-sheet toast .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  bottom-sheet floating-sheet .osd .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  bottom-sheet floating-sheet toastoverlay toast .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  toastoverlay bottom-sheet floating-sheet toast .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  floating-sheet .osd .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  floating-sheet toastoverlay toast .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  toastoverlay floating-sheet toast .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  .osd .sidebar dialog.csd.about > headerbar.bottom-toolbar button.image-button,
  toastoverlay toast .sidebar dialog.csd.about > headerbar.bottom-toolbar button.image-button,
  .osd .sidebar window.csd.about > headerbar.bottom-toolbar button.image-button,
  toastoverlay toast .sidebar window.csd.about > headerbar.bottom-toolbar button.image-button,
  popover.emoji-picker .osd .sidebar .emoji-toolbar button.bottom-toolbar button.image-button,
  popover.emoji-picker toastoverlay toast .sidebar .emoji-toolbar button.bottom-toolbar button.image-button,
  toastoverlay popover.emoji-picker toast .sidebar .emoji-toolbar button.bottom-toolbar button.image-button, .sidebar .inline-toolbar .osd button.image-button, .sidebar .inline-toolbar toastoverlay toast button.image-button, toastoverlay .sidebar .inline-toolbar toast button.image-button, .sidebar actionbar.flat .osd button.image-button, .sidebar actionbar.flat toastoverlay toast button.image-button, toastoverlay .sidebar actionbar.flat toast button.image-button,
  .sidebar .bottom-toolbar.flat .osd button.image-button,
  .sidebar .bottom-toolbar.flat toastoverlay toast button.image-button,
  toastoverlay .sidebar .bottom-toolbar.flat toast button.image-button,
  .sidebar window.preferences.csd headerbar.bottom-toolbar .osd button.image-button,
  .sidebar window.preferences.csd headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay .sidebar window.preferences.csd headerbar.bottom-toolbar toast button.image-button,
  window.preferences.csd .sidebar headerbar.bottom-toolbar .osd button.image-button,
  window.preferences.csd .sidebar headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay window.preferences.csd .sidebar headerbar.bottom-toolbar toast button.image-button,
  .sidebar .dialog.csd > headerbar.bottom-toolbar .osd button.image-button,
  .sidebar .dialog.csd > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay .sidebar .dialog.csd > headerbar.bottom-toolbar toast button.image-button,
  .sidebar window.csd.preferences > headerbar.bottom-toolbar .osd button.image-button,
  .sidebar window.csd.preferences > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay .sidebar window.csd.preferences > headerbar.bottom-toolbar toast button.image-button,
  .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .osd button.image-button,
  .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar toast button.image-button,
  bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .osd button.image-button,
  bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar toast button.image-button,
  .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .osd button.image-button,
  .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar toast button.image-button,
  floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .osd button.image-button,
  floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar toast button.image-button,
  .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .osd button.image-button,
  .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar toast button.image-button,
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .osd button.image-button,
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay .sidebar bottom-sheet sheet > headerbar.bottom-toolbar toast button.image-button,
  .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .osd button.image-button,
  .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar toast button.image-button,
  floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .osd button.image-button,
  floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar toast button.image-button,
  bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .osd button.image-button,
  bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar toast button.image-button,
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .osd button.image-button,
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay bottom-sheet .sidebar sheet > headerbar.bottom-toolbar toast button.image-button,
  bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .osd button.image-button,
  bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar toast button.image-button,
  floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .osd button.image-button,
  floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar toast button.image-button,
  .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .osd button.image-button,
  .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar toast button.image-button,
  .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .osd button.image-button,
  .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar toast button.image-button,
  bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .osd button.image-button,
  bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar toast button.image-button,
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar .osd button.image-button,
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay .sidebar floating-sheet sheet > headerbar.bottom-toolbar toast button.image-button,
  floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .osd button.image-button,
  floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar toast button.image-button,
  floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .osd button.image-button,
  floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar toast button.image-button,
  bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .osd button.image-button,
  bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar toast button.image-button,
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar .osd button.image-button,
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay floating-sheet .sidebar sheet > headerbar.bottom-toolbar toast button.image-button,
  .sidebar dialog.csd.about > headerbar.bottom-toolbar .osd button.image-button,
  .sidebar dialog.csd.about > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay .sidebar dialog.csd.about > headerbar.bottom-toolbar toast button.image-button,
  .sidebar window.csd.about > headerbar.bottom-toolbar .osd button.image-button,
  .sidebar window.csd.about > headerbar.bottom-toolbar toastoverlay toast button.image-button,
  toastoverlay .sidebar window.csd.about > headerbar.bottom-toolbar toast button.image-button, .osd .sidebar popover.emoji-picker .emoji-toolbar button.image-button, toastoverlay toast .sidebar popover.emoji-picker .emoji-toolbar button.image-button, .sidebar popover.emoji-picker .emoji-toolbar .osd button.image-button, .sidebar popover.emoji-picker .emoji-toolbar toastoverlay toast button.image-button, toastoverlay .sidebar popover.emoji-picker .emoji-toolbar toast button.image-button, .osd popover.emoji-picker .sidebar .emoji-toolbar button.image-button, toastoverlay toast popover.emoji-picker .sidebar .emoji-toolbar button.image-button, popover.emoji-picker .sidebar .emoji-toolbar .osd button.image-button, popover.emoji-picker .sidebar .emoji-toolbar toastoverlay toast button.image-button, toastoverlay popover.emoji-picker .sidebar .emoji-toolbar toast button.image-button, .app-notification button.flat.image-button, .app-notification .sidebar .inline-toolbar button.image-button, .app-notification .sidebar actionbar.flat button.image-button,
  .app-notification .sidebar .bottom-toolbar.flat button.image-button,
  .app-notification .sidebar window.preferences.csd headerbar.bottom-toolbar button.image-button,
  window.preferences.csd .app-notification .sidebar headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar .dialog.csd > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar window.csd.preferences > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.image-button,
  bottom-sheet .app-notification .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.image-button,
  floating-sheet .app-notification .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  floating-sheet .app-notification .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  bottom-sheet .app-notification .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button,
  bottom-sheet .app-notification .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  bottom-sheet .app-notification .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  floating-sheet bottom-sheet .app-notification .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  bottom-sheet .app-notification .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  floating-sheet .app-notification .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button,
  floating-sheet .app-notification .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  bottom-sheet floating-sheet .app-notification .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  floating-sheet .app-notification .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar dialog.csd.about > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar window.csd.about > headerbar.bottom-toolbar button.image-button,
  popover.emoji-picker .app-notification .sidebar .emoji-toolbar button.bottom-toolbar button.image-button, .sidebar .inline-toolbar .app-notification button.image-button, .sidebar actionbar.flat .app-notification button.image-button,
  .sidebar .bottom-toolbar.flat .app-notification button.image-button,
  .sidebar window.preferences.csd headerbar.bottom-toolbar .app-notification button.image-button,
  window.preferences.csd .sidebar headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar .dialog.csd > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar window.csd.preferences > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .app-notification button.image-button,
  bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .app-notification button.image-button,
  floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .app-notification button.image-button,
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .app-notification button.image-button,
  floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar dialog.csd.about > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar window.csd.about > headerbar.bottom-toolbar .app-notification button.image-button, .app-notification .sidebar popover.emoji-picker .emoji-toolbar button.image-button, .sidebar popover.emoji-picker .emoji-toolbar .app-notification button.image-button, .app-notification popover.emoji-picker .sidebar .emoji-toolbar button.image-button, popover.emoji-picker .sidebar .emoji-toolbar .app-notification button.image-button, .osd button.circular.image-button, toastoverlay toast button.circular.image-button, .app-notification button.circular.image-button {
    background: transparent;
    box-shadow: none;
    color: rgba(58, 58, 58, 0.9); }
    .osd button.flat.image-button:active, toastoverlay toast button.flat.image-button:active, .osd .sidebar .inline-toolbar button.image-button:active, toastoverlay toast .sidebar .inline-toolbar button.image-button:active, .osd .sidebar actionbar.flat button.image-button:active, toastoverlay toast .sidebar actionbar.flat button.image-button:active,
    .osd .sidebar .bottom-toolbar.flat button.image-button:active,
    toastoverlay toast .sidebar .bottom-toolbar.flat button.image-button:active,
    .osd .sidebar window.preferences.csd headerbar.bottom-toolbar button.image-button:active,
    toastoverlay toast .sidebar window.preferences.csd headerbar.bottom-toolbar button.image-button:active,
    window.preferences.csd .osd .sidebar headerbar.bottom-toolbar button.image-button:active,
    window.preferences.csd toastoverlay toast .sidebar headerbar.bottom-toolbar button.image-button:active,
    toastoverlay window.preferences.csd toast .sidebar headerbar.bottom-toolbar button.image-button:active,
    .osd .sidebar .dialog.csd > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay toast .sidebar .dialog.csd > headerbar.bottom-toolbar button.image-button:active,
    .osd .sidebar window.csd.preferences > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay toast .sidebar window.csd.preferences > headerbar.bottom-toolbar button.image-button:active,
    .osd .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay toast .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet .osd .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet toastoverlay toast .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay bottom-sheet toast .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button:active,
    .osd .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay toast .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet .osd .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet toastoverlay toast .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay floating-sheet toast .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button:active,
    .osd .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay toast .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.image-button:active,
    .osd .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay toast .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    .osd .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay toast .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet .osd .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet toastoverlay toast .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay floating-sheet toast .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet .osd .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet toastoverlay toast .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay bottom-sheet toast .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet .osd .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet toastoverlay toast .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay bottom-sheet toast .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet .osd .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet toastoverlay toast .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay bottom-sheet toast .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet bottom-sheet .osd .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet bottom-sheet toastoverlay toast .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay floating-sheet bottom-sheet toast .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    .osd .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay toast .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.image-button:active,
    .osd .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay toast .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet .osd .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet toastoverlay toast .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay bottom-sheet toast .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    .osd .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay toast .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet .osd .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet toastoverlay toast .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay floating-sheet toast .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet .osd .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet toastoverlay toast .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay floating-sheet toast .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet floating-sheet .osd .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet floating-sheet toastoverlay toast .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay bottom-sheet floating-sheet toast .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet .osd .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet toastoverlay toast .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay floating-sheet toast .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    .osd .sidebar dialog.csd.about > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay toast .sidebar dialog.csd.about > headerbar.bottom-toolbar button.image-button:active,
    .osd .sidebar window.csd.about > headerbar.bottom-toolbar button.image-button:active,
    toastoverlay toast .sidebar window.csd.about > headerbar.bottom-toolbar button.image-button:active,
    popover.emoji-picker .osd .sidebar .emoji-toolbar button.bottom-toolbar button.image-button:active,
    popover.emoji-picker toastoverlay toast .sidebar .emoji-toolbar button.bottom-toolbar button.image-button:active,
    toastoverlay popover.emoji-picker toast .sidebar .emoji-toolbar button.bottom-toolbar button.image-button:active, .sidebar .inline-toolbar .osd button.image-button:active, .sidebar .inline-toolbar toastoverlay toast button.image-button:active, toastoverlay .sidebar .inline-toolbar toast button.image-button:active, .sidebar actionbar.flat .osd button.image-button:active, .sidebar actionbar.flat toastoverlay toast button.image-button:active, toastoverlay .sidebar actionbar.flat toast button.image-button:active,
    .sidebar .bottom-toolbar.flat .osd button.image-button:active,
    .sidebar .bottom-toolbar.flat toastoverlay toast button.image-button:active,
    toastoverlay .sidebar .bottom-toolbar.flat toast button.image-button:active,
    .sidebar window.preferences.csd headerbar.bottom-toolbar .osd button.image-button:active,
    .sidebar window.preferences.csd headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay .sidebar window.preferences.csd headerbar.bottom-toolbar toast button.image-button:active,
    window.preferences.csd .sidebar headerbar.bottom-toolbar .osd button.image-button:active,
    window.preferences.csd .sidebar headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay window.preferences.csd .sidebar headerbar.bottom-toolbar toast button.image-button:active,
    .sidebar .dialog.csd > headerbar.bottom-toolbar .osd button.image-button:active,
    .sidebar .dialog.csd > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay .sidebar .dialog.csd > headerbar.bottom-toolbar toast button.image-button:active,
    .sidebar window.csd.preferences > headerbar.bottom-toolbar .osd button.image-button:active,
    .sidebar window.csd.preferences > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay .sidebar window.csd.preferences > headerbar.bottom-toolbar toast button.image-button:active,
    .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .osd button.image-button:active,
    .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar toast button.image-button:active,
    bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .osd button.image-button:active,
    bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar toast button.image-button:active,
    .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .osd button.image-button:active,
    .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar toast button.image-button:active,
    floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .osd button.image-button:active,
    floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar toast button.image-button:active,
    .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .osd button.image-button:active,
    .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar toast button.image-button:active,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .osd button.image-button:active,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay .sidebar bottom-sheet sheet > headerbar.bottom-toolbar toast button.image-button:active,
    .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .osd button.image-button:active,
    .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar toast button.image-button:active,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .osd button.image-button:active,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar toast button.image-button:active,
    bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .osd button.image-button:active,
    bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar toast button.image-button:active,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .osd button.image-button:active,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay bottom-sheet .sidebar sheet > headerbar.bottom-toolbar toast button.image-button:active,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .osd button.image-button:active,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar toast button.image-button:active,
    floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .osd button.image-button:active,
    floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar toast button.image-button:active,
    .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .osd button.image-button:active,
    .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar toast button.image-button:active,
    .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .osd button.image-button:active,
    .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar toast button.image-button:active,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .osd button.image-button:active,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar toast button.image-button:active,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar .osd button.image-button:active,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay .sidebar floating-sheet sheet > headerbar.bottom-toolbar toast button.image-button:active,
    floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .osd button.image-button:active,
    floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar toast button.image-button:active,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .osd button.image-button:active,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar toast button.image-button:active,
    bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .osd button.image-button:active,
    bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar toast button.image-button:active,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar .osd button.image-button:active,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay floating-sheet .sidebar sheet > headerbar.bottom-toolbar toast button.image-button:active,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar .osd button.image-button:active,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay .sidebar dialog.csd.about > headerbar.bottom-toolbar toast button.image-button:active,
    .sidebar window.csd.about > headerbar.bottom-toolbar .osd button.image-button:active,
    .sidebar window.csd.about > headerbar.bottom-toolbar toastoverlay toast button.image-button:active,
    toastoverlay .sidebar window.csd.about > headerbar.bottom-toolbar toast button.image-button:active, .osd .sidebar popover.emoji-picker .emoji-toolbar button.image-button:active, toastoverlay toast .sidebar popover.emoji-picker .emoji-toolbar button.image-button:active, .sidebar popover.emoji-picker .emoji-toolbar .osd button.image-button:active, .sidebar popover.emoji-picker .emoji-toolbar toastoverlay toast button.image-button:active, toastoverlay .sidebar popover.emoji-picker .emoji-toolbar toast button.image-button:active, .osd popover.emoji-picker .sidebar .emoji-toolbar button.image-button:active, toastoverlay toast popover.emoji-picker .sidebar .emoji-toolbar button.image-button:active, popover.emoji-picker .sidebar .emoji-toolbar .osd button.image-button:active, popover.emoji-picker .sidebar .emoji-toolbar toastoverlay toast button.image-button:active, toastoverlay popover.emoji-picker .sidebar .emoji-toolbar toast button.image-button:active, .app-notification button.flat.image-button:active, .app-notification .sidebar .inline-toolbar button.image-button:active, .app-notification .sidebar actionbar.flat button.image-button:active,
    .app-notification .sidebar .bottom-toolbar.flat button.image-button:active,
    .app-notification .sidebar window.preferences.csd headerbar.bottom-toolbar button.image-button:active,
    window.preferences.csd .app-notification .sidebar headerbar.bottom-toolbar button.image-button:active,
    .app-notification .sidebar .dialog.csd > headerbar.bottom-toolbar button.image-button:active,
    .app-notification .sidebar window.csd.preferences > headerbar.bottom-toolbar button.image-button:active,
    .app-notification .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet .app-notification .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button:active,
    .app-notification .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet .app-notification .sidebar sheet.dialog > headerbar.bottom-toolbar button.image-button:active,
    .app-notification .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar button.image-button:active,
    .app-notification .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    .app-notification .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet .app-notification .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet .app-notification .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet .app-notification .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet .app-notification .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet bottom-sheet .app-notification .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    .app-notification .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar button.image-button:active,
    .app-notification .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet .app-notification .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    .app-notification .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet .app-notification .sidebar sheet.csd > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet .app-notification .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button:active,
    bottom-sheet floating-sheet .app-notification .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    floating-sheet .app-notification .sidebar sheet > headerbar.bottom-toolbar button.image-button:active,
    .app-notification .sidebar dialog.csd.about > headerbar.bottom-toolbar button.image-button:active,
    .app-notification .sidebar window.csd.about > headerbar.bottom-toolbar button.image-button:active,
    popover.emoji-picker .app-notification .sidebar .emoji-toolbar button.bottom-toolbar button.image-button:active, .sidebar .inline-toolbar .app-notification button.image-button:active, .sidebar actionbar.flat .app-notification button.image-button:active,
    .sidebar .bottom-toolbar.flat .app-notification button.image-button:active,
    .sidebar window.preferences.csd headerbar.bottom-toolbar .app-notification button.image-button:active,
    window.preferences.csd .sidebar headerbar.bottom-toolbar .app-notification button.image-button:active,
    .sidebar .dialog.csd > headerbar.bottom-toolbar .app-notification button.image-button:active,
    .sidebar window.csd.preferences > headerbar.bottom-toolbar .app-notification button.image-button:active,
    .sidebar bottom-sheet sheet.dialog > headerbar.bottom-toolbar .app-notification button.image-button:active,
    bottom-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .app-notification button.image-button:active,
    .sidebar floating-sheet sheet.dialog > headerbar.bottom-toolbar .app-notification button.image-button:active,
    floating-sheet .sidebar sheet.dialog > headerbar.bottom-toolbar .app-notification button.image-button:active,
    .sidebar bottom-sheet sheet.csd > headerbar.bottom-toolbar .app-notification button.image-button:active,
    .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button:active,
    .sidebar bottom-sheet floating-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button:active,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button:active,
    bottom-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .app-notification button.image-button:active,
    bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .app-notification button.image-button:active,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button:active,
    floating-sheet bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .app-notification button.image-button:active,
    .sidebar floating-sheet sheet.csd > headerbar.bottom-toolbar .app-notification button.image-button:active,
    .sidebar floating-sheet bottom-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button:active,
    bottom-sheet .sidebar floating-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button:active,
    .sidebar floating-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button:active,
    floating-sheet .sidebar sheet.csd > headerbar.bottom-toolbar .app-notification button.image-button:active,
    floating-sheet .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button:active,
    bottom-sheet floating-sheet .sidebar sheet > headerbar.bottom-toolbar .app-notification button.image-button:active,
    floating-sheet .sidebar sheet > headerbar.bottom-toolbar .app-notification button.image-button:active,
    .sidebar dialog.csd.about > headerbar.bottom-toolbar .app-notification button.image-button:active,
    .sidebar window.csd.about > headerbar.bottom-toolbar .app-notification button.image-button:active, .app-notification .sidebar popover.emoji-picker .emoji-toolbar button.image-button:active, .sidebar popover.emoji-picker .emoji-toolbar .app-notification button.image-button:active, .app-notification popover.emoji-picker .sidebar .emoji-toolbar button.image-button:active, popover.emoji-picker .sidebar .emoji-toolbar .app-notification button.image-button:active, .osd button.circular.image-button:active, toastoverlay toast button.circular.image-button:active, .app-notification button.circular.image-button:active {
      background: rgba(255, 255, 255, 0.7);
      box-shadow: none;
      color: rgba(58, 58, 58, 0.7); }
  .osd button.circular.image-button, toastoverlay toast button.circular.image-button, .app-notification button.circular.image-button {
    background: white; }
  .osd button.text-button, toastoverlay toast button.text-button, .app-notification button.text-button {
    background-color: rgba(58, 58, 58, 0.9);
    color: white;
    border-width: 0;
    box-shadow: none; }
    .osd button.text-button:active, toastoverlay toast button.text-button:active, .app-notification button.text-button:active {
      background-color: rgba(58, 58, 58, 0.7);
      box-shadow: none;
      color: rgba(255, 255, 255, 0.7); }
  .osd scale.horizontal, toastoverlay toast scale.horizontal, .app-notification scale.horizontal {
    margin: 0 1.000000001rem; }
  .osd scale.vertical, toastoverlay toast scale.vertical, .app-notification scale.vertical {
    margin: 1.000000001rem 0; }
  .osd scale highlight, toastoverlay toast scale highlight, .app-notification scale highlight,
  .osd scale trough,
  toastoverlay toast scale trough,
  .app-notification scale trough {
    border: none;
    box-shadow: none; }
  .osd scale.horizontal highlight.bottom, toastoverlay toast scale.horizontal highlight.bottom, .app-notification scale.horizontal highlight.bottom,
  .osd scale.horizontal highlight.top,
  toastoverlay toast scale.horizontal highlight.top,
  .app-notification scale.horizontal highlight.top, .osd scale.vertical highlight.bottom, toastoverlay toast scale.vertical highlight.bottom, .app-notification scale.vertical highlight.bottom,
  .osd scale.vertical highlight.top,
  toastoverlay toast scale.vertical highlight.top,
  .app-notification scale.vertical highlight.top {
    background: #3a3a3a;
    margin: 0; }
  .osd scale trough, toastoverlay toast scale trough, .app-notification scale trough {
    background: rgba(58, 58, 58, 0.3); }

paned.horizontal > separator {
  background-image: linear-gradient(to right, @menu_separator 1px, @menu_separator_shadow 1px, @menu_separator_shadow 2px, transparent 2px);
  margin-right: -8px;
  min-width: 9px; }

paned.vertical > separator {
  background-image: linear-gradient(to bottom, @menu_separator 1px, @menu_separator_shadow 1px, @menu_separator_shadow 2px, transparent 2px);
  margin-bottom: -8px;
  min-height: 9px; }

popover.background.menu > contents row,
popover.background modelbutton,
popover.background .menuitem, dropdown popover listview row,
dropdown popover listview.view row {
  background: transparent;
  border: none;
  border-radius: 0;
  border-spacing: 0.500000001rem;
  box-shadow: none;
  color: white;
  font: initial;
  letter-spacing: initial;
  min-width: 12.500000001rem;
  outline-style: none;
  padding: 0.500000001rem 1.000000001rem; }
  popover.background.menu > contents row:disabled,
  popover.background modelbutton:disabled,
  popover.background .menuitem:disabled, dropdown popover listview row:disabled {
    color: #999999; }
    popover.background.menu > contents row:disabled accelerator,
    popover.background modelbutton:disabled accelerator,
    popover.background .menuitem:disabled accelerator, dropdown popover listview row:disabled accelerator,
    popover.background.menu > contents row:disabled .keycap,
    popover.background modelbutton:disabled .keycap,
    popover.background .menuitem:disabled .keycap,
    dropdown popover listview row:disabled .keycap {
      opacity: 0.7; }
  popover.background.menu > contents row:hover,
  popover.background modelbutton:hover,
  popover.background .menuitem:hover, dropdown popover listview row:hover {
    box-shadow: none;
    background-color: rgba(255, 255, 255, 0.15); }
  popover.background.menu > contents row.destructive-action,
  popover.background modelbutton.destructive-action,
  popover.background .destructive-action.menuitem {
    color: #ed5353;
    text-shadow: none; }
    popover.background.menu > contents row.destructive-action:hover,
    popover.background modelbutton.destructive-action:hover,
    popover.background .destructive-action.menuitem:hover {
      background-color: rgba(237, 83, 83, 0.2); }
  popover.background.menu > contents row accelerator,
  popover.background modelbutton accelerator,
  popover.background .menuitem accelerator, dropdown popover listview row accelerator,
  dropdown popover listview.view row accelerator,
  popover.background.menu > contents row .keycap,
  popover.background modelbutton .keycap,
  popover.background .menuitem .keycap,
  dropdown popover listview row .keycap {
    background: rgba(0, 0, 0, 0.08);
    border: none;
    box-shadow: 0 1px 0 0 rgba(0, 0, 0, 0.15);
    color: alpha(@fg_color, 0.78);
    margin: 0 0 1px;
    padding: 0.250000001rem 0.500000001rem calc(0.250000001rem - 1px); }
  popover.background.menu > contents row check,
  popover.background modelbutton check,
  popover.background .menuitem check, dropdown popover listview row check,
  dropdown popover listview.view row check,
  popover.background.menu > contents row radio,
  popover.background modelbutton radio,
  popover.background .menuitem radio,
  dropdown popover listview row radio,
  dropdown popover listview.view row radio {
    margin: 0; }
  popover.background.menu > contents row switch slider,
  popover.background modelbutton switch slider,
  popover.background .menuitem switch slider, dropdown popover listview row switch slider,
  dropdown popover listview.view row switch slider {
    min-height: 1.6666666677rem;
    min-width: 1.6666666677rem; }

popover.background {
  background: transparent;
  font: initial; }
  popover.background > arrow,
  popover.background > contents {
    background-clip: padding-box;
    background-color: #333;
    border: 1px solid rgba(0, 0, 0, 0.75);
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 3px 4px rgba(0, 0, 0, 0.25), 0 3px 3px -3px rgba(0, 0, 0, 0.45);
    color: white; }
  popover.background > contents {
    border-radius: 0.500000001rem; }
    popover.background > contents header,
    popover.background > contents label.h4,
    popover.background > contents shortcuts-group > label,
    popover.background > contents popover.emoji-picker scrolledwindow.view box.vertical > label,
    popover.emoji-picker scrolledwindow.view popover.background > contents box.vertical > label {
      margin: 0 1.000000001rem; }
    popover.background > contents separator.horizontal {
      border-top: 1px solid @menu_separator;
      border-bottom: 1px solid @menu_separator_shadow;
      margin-bottom: -1px; }
    popover.background > contents separator.vertical {
      border-left: 1px solid @menu_separator;
      border-right: 1px solid @menu_separator_shadow;
      margin-right: -1px; }
    popover.background > contents undershoot.top {
      background: linear-gradient(#333 0%, rgba(51, 51, 51, 0) 50%); }
    popover.background > contents undershoot.bottom {
      background: linear-gradient(rgba(51, 51, 51, 0) 50%, #333 100%); }
    popover.background > contents arrow {
      -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
      min-height: 16px;
      min-width: 16px; }
      popover.background > contents arrow:dir(rtl) {
        -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }
      popover.background > contents arrow.top {
        border-bottom: 1px solid @menu_separator;
        margin-top: -6px;
        -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }
      popover.background > contents arrow.bottom {
        border-top: 1px solid @menu_separator;
        margin-bottom: -18px;
        margin-top: 16px;
        -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
      popover.background > contents arrow.left {
        -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }
      popover.background > contents arrow:disabled {
        color: #999999; }
  popover.background.entry-completion > contents treeview {
    margin: 0.500000001rem 0; }
    popover.background.entry-completion > contents treeview.view.cell {
      padding: 0.500000001rem 1.000000001rem; }
  popover.background.menu > contents {
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 3px 4px rgba(0, 0, 0, 0.25), 0 3px 3px -3px rgba(0, 0, 0, 0.45);
    padding: 0.500000001rem 0; }
    popover.background.menu > contents label.heading {
      margin: 0 1.000000001rem; }
    popover.background.menu > contents header label.heading {
      margin: 0; }
    popover.background.menu > contents popover {
      box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 3px 8px 2px rgba(0, 0, 0, 0.2), 0 5px 5px -3px rgba(0, 0, 0, 0.5), 0 8px 5px 1px rgba(0, 0, 0, 0.2); }
    popover.background.menu > contents listview {
      background: none; }
    popover.background.menu > contents .menuitem:dir(ltr) image:first-child {
      margin-left: -0.5833333343rem;
      padding-left: 0; }
    popover.background.menu > contents .menuitem:dir(ltr) > check,
    popover.background.menu > contents .menuitem:dir(ltr) > radio {
      margin-left: -0.500000001rem; }
    popover.background.menu > contents .menuitem:dir(rtl) image:first-child {
      margin-right: -1.9166666677rem;
      padding-right: 0; }
    popover.background.menu > contents .menuitem:dir(rtl) > check,
    popover.background.menu > contents .menuitem:dir(rtl) > radio {
      margin-right: -0.500000001rem; }
    popover.background.menu > contents separator {
      margin: 0.250000001rem 0; }
    popover.background.menu > contents box.circular-buttons,
    popover.background.menu > contents box.horizontal-buttons,
    popover.background.menu > contents widget > scale {
      margin: 0.500000001rem 1.000000001rem; }
    popover.background.menu > contents widget:dir(ltr) > scale {
      margin: 0.500000001rem 1.000000001rem 0.500000001rem 2.6666666677rem; }
    popover.background.menu > contents box.circular-buttons button.circular.image-button {
      padding: 0.750000001rem; }
    popover.background.menu > contents box.inline-buttons {
      margin: 0.250000001rem 1.000000001rem; }
      popover.background.menu > contents box.inline-buttons > box {
        border-spacing: 0.500000001rem; }
    popover.background.menu > contents .title {
      font-weight: 700; }
      popover.background.menu > contents .title.separator {
        margin: 0.500000001rem 2.6666666677rem;
        opacity: 0.8; }
  popover.background.menu > contents row.heading label, popover.background.menu > contents row.h4 label, popover.background.menu > contents row.title-4 label,
  popover.background modelbutton.heading label,
  popover.background modelbutton.h4 label,
  popover.background modelbutton.title-4 label,
  popover.background .menuitem.heading label,
  popover.background .menuitem.h4 label,
  popover.background shortcuts-group > label.menuitem label,
  popover.background popover.emoji-picker scrolledwindow.view box.vertical > label.menuitem label,
  popover.emoji-picker scrolledwindow.view popover.background box.vertical > label.menuitem label,
  popover.background .menuitem.title-4 label {
    padding: 0; }

progressbar {
  border-radius: 0.1666666677rem; }
  progressbar progress,
  progressbar trough {
    border: 1px solid rgba(0, 0, 0, 0.3);
    border-radius: 0.1666666677rem; }
  progressbar progress {
    background-color: @accent_color;
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07);
    background-clip: padding-box; }
    progressbar progress:backdrop {
      background-color: #252525; }
  progressbar trough {
    background-color: #404040;
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 1px 1px rgba(0, 0, 0, 0.05);
    background-clip: padding-box; }
  progressbar.horizontal progress,
  progressbar.horizontal trough {
    min-height: 0.500000001rem;
    min-width: 0.250000001rem; }
  progressbar.horizontal progress {
    margin: 0 -1px; }
    progressbar.horizontal progress:not(.pulse) {
      animation: progress 1.5s cubic-bezier(0.4, 0, 0.2, 1) infinite;
      background-size: cover, 48px 100%;
      background-repeat: no-repeat;
      background-image: linear-gradient(to bottom, alpha(@highlight_color, 0.2), rgba(255, 255, 255, 0)), linear-gradient(to right, rgba(255, 255, 255, 0), rgba(255, 255, 255, 0.25) 60%, rgba(255, 255, 255, 0)); }
      progressbar.horizontal progress:not(.pulse).right {
        animation-direction: reverse; }
    progressbar.horizontal progress:backdrop {
      animation: none;
      background-image: none; }
  progressbar.vertical progress,
  progressbar.vertical trough {
    min-height: 0.250000001rem;
    min-width: 0.500000001rem; }
  progressbar.vertical progress {
    margin: -1px 0; }
  progressbar.flat progress,
  progressbar.flat trough {
    box-shadow: none;
    border: none;
    border-radius: 0.500000001rem;
    margin: 0; }
  progressbar.flat progress,
  progressbar.flat progress:backdrop,
  progressbar.flat .horizontal progress {
    animation: none;
    background: alpha(@fg_color, 0.78); }
  progressbar.flat trough {
    background: alpha(@fg_color, 0.15); }

@keyframes progress {
  from {
    background-position: 0, calc(0% - 48px), 0%; }
  to {
    background-position: 0, calc(100% + 48px), 0%; } }

scale fill {
  background-color: rgba(0, 0, 0, 0.25); }

scale highlight {
  background-color: rgba(255, 255, 255, 0.7);
  border: 1px solid rgba(0, 0, 0, 0.3);
  box-shadow: inset 0 0 0 2px rgba(0, 0, 0, 0.03);
  background-clip: padding-box;
  border-color: transparent;
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07); }
  scale highlight:disabled {
    background-color: rgba(255, 255, 255, 0.25);
    border-color: transparent;
    box-shadow: none; }

scale mark indicator {
  background: #5c5c5c; }

scale slider {
  background-color: #404040;
  border-radius: 1.000000001rem;
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px rgba(0, 0, 0, 0.3), 0 1px 1px 1px rgba(0, 0, 0, 0.1);
  min-height: 1.1666666677rem;
  min-width: 1.1666666677rem; }
  scale slider:backdrop {
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px rgba(0, 0, 0, 0.2), 0 1px 1px 1px rgba(0, 0, 0, 0.08); }
  scale slider:disabled {
    background-color: transparent;
    background-image: none;
    border: none;
    box-shadow: none; }

scale trough {
  border: 1px solid rgba(0, 0, 0, 0.3);
  border-radius: 1.000000001rem;
  background-color: rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 0 0 1px rgba(0, 0, 0, 0.03), 0 1px 0 0 alpha(@highlight_color, 0.3);
  min-height: 0.250000001rem;
  min-width: 0.250000001rem; }
  scale trough:disabled {
    background-image: none; }

scale.color.horizontal trough, scale.color.vertical trough {
  padding: 0; }

scale.accent fill {
  background-color: alpha(@accent_color, 0.33); }

scale.accent highlight {
  background-color: @accent_color; }

scale.warmth trough, scale.temperature trough {
  background-clip: padding-box;
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 1px 0 0 alpha(@highlight_color, 0.3); }

scale.temperature trough {
  background-image: linear-gradient(to right, #3689e6, #f9c440); }

scale.temperature:dir(rtl) trough {
  background-image: linear-gradient(to left, #3689e6, #f9c440); }

scale.warmth trough {
  background-image: linear-gradient(to right, #fddebc, #f37329); }

scale.warmth:dir(rtl) trough {
  background-image: linear-gradient(to left, #fddebc, #f37329); }

scale.horizontal highlight.top,
scale.horizontal fill.top {
  border-radius: 1.000000001rem 0 0 1.000000001rem;
  margin: -1px 0 -1px -1px; }

scale.horizontal highlight.bottom,
scale.horizontal fill.bottom {
  border-radius: 0 1.000000001rem 1.000000001rem 0;
  margin: -1px -1px -1px 0; }

scale.horizontal marks.bottom {
  margin-top: 0.500000001rem; }

scale.horizontal marks.top {
  margin-top: 0.500000001rem; }

scale.horizontal marks mark indicator {
  min-height: 0.500000001rem;
  min-width: 1px; }

scale.horizontal slider {
  margin: -0.500000001rem -1px; }

scale.horizontal trough {
  margin: 0.500000001rem 0; }

scale.vertical highlight.top,
scale.vertical fill.top {
  border-radius: 1.000000001rem 1.000000001rem 0 0;
  margin: -1px -1px 0 -1px; }

scale.vertical highlight.bottom,
scale.vertical fill.bottom {
  border-radius: 0 0 1.000000001rem 1.000000001rem;
  margin: 0 -1px -1px -1px; }

scale.vertical marks.bottom {
  margin-left: 0.500000001rem; }

scale.vertical marks.top {
  margin-right: 0.500000001rem; }

scale.vertical marks mark indicator {
  min-height: 1px;
  min-width: 0.500000001rem; }

scale.vertical slider {
  margin: -1px -0.500000001rem; }

scale.vertical trough {
  margin: 0 0.500000001rem; }

scale:focus-visible slider {
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 0.250000001rem alpha(@accent_color, 0.3), 0 0 0 1px rgba(0, 0, 0, 0.3); }

.seek-bar scale slider {
  background: transparent;
  border: transparent;
  box-shadow: none;
  min-width: 0;
  min-height: 0; }

scrollbar {
  background-color: transparent;
  transition: all 200ms cubic-bezier(0.4, 0, 0.2, 1); }
  scrollbar:hover, scrollbar.hovering {
    transition: all 250ms cubic-bezier(0.4, 0, 0.2, 1); }
    scrollbar:hover trough, scrollbar.hovering trough {
      background-color: transparent;
      border-radius: 0; }
  scrollbar button {
    border: none;
    background-image: none;
    background-color: transparent; }
  scrollbar slider {
    background-clip: padding-box;
    background-color: rgba(255, 255, 255, 0.6);
    border: 1px solid rgba(51, 51, 51, 0.25);
    border-radius: 0.8333333343rem;
    margin: 1px;
    transition: all 300ms cubic-bezier(0.4, 0, 0.2, 1); }
  scrollbar.horizontal slider {
    min-width: 2.6666666677rem;
    min-height: 0.250000001rem; }
  scrollbar.horizontal:hover slider, scrollbar.horizontal.hovering slider {
    min-height: 0.750000001rem; }
  scrollbar.vertical slider {
    min-height: 1.6666666677rem;
    min-width: 0.250000001rem; }
  scrollbar.vertical:hover slider, scrollbar.vertical.hovering slider {
    min-width: 0.750000001rem; }
  scrollbar.overlay-indicator slider {
    border-radius: 1.6666666677rem; }
  scrollbar.overlay-indicator trough {
    background-color: transparent; }
  scrollbar.overlay-indicator:hover trough, scrollbar.overlay-indicator.hovering trough {
    background-color: rgba(255, 255, 255, 0.1); }
  scrollbar trough {
    padding: 0;
    transition: all 100ms cubic-bezier(0.4, 0, 0.2, 1); }

.search-bar, searchbar {
  background-color: #313131; }

searchbar > revealer > box {
  padding: 0.500000001rem; }

searchbar button.close {
  background: white;
  border-radius: 99px;
  color: rgba(58, 58, 58, 0.9);
  padding: 0.250000001rem; }
  searchbar button.close:active {
    background: rgba(255, 255, 255, 0.7);
    color: rgba(58, 58, 58, 0.7); }

separator.horizontal {
  border-top: 1px solid @menu_separator;
  border-bottom: 1px solid @menu_separator_shadow;
  margin-bottom: -1px; }

separator.vertical {
  border-left: 1px solid @menu_separator;
  border-right: 1px solid @menu_separator_shadow;
  margin-right: -1px; }

actionbar > separator, headerbar > windowhandle > box > box separator.horizontal, headerbar > windowhandle > box > box separator.vertical {
  border: none;
  margin: 0;
  min-height: 1px;
  min-width: 3.000000001rem; }

stacksidebar separator.horizontal {
  border: none; }

shortcuts-section {
  margin: 1.000000001rem; }

shortcut .dim-label, shortcut list.boxed-list > row .title + .subtitle, list.boxed-list > row shortcut .title + .subtitle, shortcut scale mark label, scale mark shortcut label {
  margin-left: 0.250000001rem;
  margin-right: 0.250000001rem; }

accelerator,
.keycap {
  background-color: #333;
  background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0), alpha(@highlight_color, 0.2));
  border: 1px solid rgba(0, 0, 0, 0.75);
  border-radius: 0.250000001rem;
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), inset 0 -1px 0 0 #252525, 0 1px 2px rgba(0, 0, 0, 0.05);
  font-size: 85%;
  min-width: 1.000000001rem;
  padding: 0.250000001rem 0.500000001rem calc(0.250000001rem + 1px); }
  accelerator:backdrop,
  .keycap:backdrop {
    background-image: linear-gradient(to bottom, alpha(@highlight_color, 0.3), alpha(@highlight_color, 0.35)); }

treeview.sidebar .view:hover, .sidebar-pane row:hover,
.sidebar-pane > label:hover,
.sidebar row:hover,
.sidebar > label:hover {
  background-color: rgba(255, 255, 255, 0.75);
  background-color: rgba(255, 255, 255, 0.05); }

treeview.sidebar .view:selected, .sidebar-pane row:selected,
.sidebar-pane > label:selected,
.sidebar row:selected,
.sidebar > label:selected, treeview.sidebar .highlight.view, .sidebar-pane row.highlight,
.sidebar-pane > label.highlight,
.sidebar row.highlight,
.sidebar > label.highlight {
  background-color: #252525;
  color: white; }

popover .sidebar-pane, popover .sidebar, popover .sidebar.view, popover .source-list {
  background: transparent; }

.sidebar-pane,
.sidebar-pane list,
.sidebar-pane .view,
.sidebar,
.sidebar list,
.sidebar .view,
.sidebar.view,
.sidebar.view list,
.sidebar.view .view,
.source-list,
.source-list list,
.source-list .view {
  background-color: #313131; }

.sidebar-pane:dir(ltr),
.sidebar:dir(ltr) {
  border-right: 1px solid @menu_separator; }

.sidebar-pane:dir(rtl),
.sidebar:dir(rtl) {
  border-left: 1px solid @menu_separator; }

paned.horizontal .sidebar-pane:dir(ltr), paned.horizontal .sidebar:dir(ltr) {
  border-right: none; }

paned.horizontal .sidebar-pane:dir(rtl), paned.horizontal .sidebar:dir(rtl) {
  border-left: none; }

.sidebar-pane row,
.sidebar-pane > label,
.sidebar row,
.sidebar > label {
  padding: 0.500000001rem 1.000000001rem; }

.sidebar-pane .content-pane {
  background: #3a3a3a; }

placessidebar.frame,
placessidebar viewport.frame {
  border: none; }
  placessidebar.frame .sidebar-icon,
  placessidebar viewport.frame .sidebar-icon {
    -gtk-icon-style: regular; }
  placessidebar.frame .sidebar-icon + .sidebar-label:dir(ltr),
  placessidebar.frame .sidebar-label + .sidebar-icon:dir(rtl),
  placessidebar viewport.frame .sidebar-icon + .sidebar-label:dir(ltr),
  placessidebar viewport.frame .sidebar-label + .sidebar-icon:dir(rtl) {
    margin-left: 0.500000001rem; }

treeview.sidebar entry.flat {
  background-color: #252525; }

spinbutton button.image-button:active {
  background: rgba(0, 0, 0, 0.05);
  color: @selected_fg_color;
  background: rgba(0, 0, 0, 0.15); }

spinbutton.horizontal button {
  padding: 0.3333333343rem; }
  spinbutton.horizontal button:dir(ltr) {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0; }
  spinbutton.horizontal button:dir(rtl) {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0; }
  spinbutton.horizontal button.down {
    border-color: rgba(0, 0, 0, 0.1);
    border-radius: 0;
    border-style: solid;
    border-width: 0 1px; }

spinbutton.horizontal text {
  margin: 0 0.500000001rem; }

spinbutton.vertical button.down {
  border-top: 1px solid rgba(0, 0, 0, 0.1);
  border-top-left-radius: 0;
  border-top-right-radius: 0; }

spinbutton.vertical button.up {
  border-bottom: 1px solid rgba(0, 0, 0, 0.1);
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0; }

spinbutton.vertical text {
  margin: 0.500000001rem 0; }

spinner {
  background-image: none;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic"); }
  spinner:checked {
    opacity: 1;
    animation: spin 600ms steps(12) infinite; }
    spinner:checked:backdrop {
      opacity: 0.8; }
    spinner:checked:disabled {
      opacity: 0.5; }

entry.spin:dir(ltr) image:last-child,
entry.spin:dir(rtl) image:first-child {
  animation: spin 600ms steps(12) infinite; }

navigation-view > dimming,
leaflet > dimming,
webkitwebview > dimming,
overlay-split-view > dimming {
  background: rgba(0, 0, 0, 0.15);
  background: rgba(0, 0, 0, 0.3); }

navigation-view > border,
leaflet > border,
webkitwebview > border,
overlay-split-view > border {
  min-width: 1px;
  min-height: 1px;
  background: rgba(0, 0, 0, 0.15); }

navigation-view > shadow.left,
leaflet > shadow.left,
webkitwebview > shadow.left,
overlay-split-view > shadow.left {
  background: linear-gradient(to right, rgba(0, 0, 0, 0.1), rgba(0, 0, 0, 0) 0.500000001rem);
  min-width: 0.500000001rem; }

navigation-view > shadow.right,
leaflet > shadow.right,
webkitwebview > shadow.right,
overlay-split-view > shadow.right {
  background: linear-gradient(to left, rgba(0, 0, 0, 0.1), rgba(0, 0, 0, 0) 0.500000001rem);
  min-width: 0.500000001rem; }

navigation-view > shadow.up,
leaflet > shadow.up,
webkitwebview > shadow.up,
overlay-split-view > shadow.up {
  background: linear-gradient(to bottom, rgba(0, 0, 0, 0.1), rgba(0, 0, 0, 0) 0.500000001rem);
  min-height: 0.500000001rem; }

navigation-view > shadow.down,
leaflet > shadow.down,
webkitwebview > shadow.down,
overlay-split-view > shadow.down {
  background: linear-gradient(to top, rgba(0, 0, 0, 0.1), rgba(0, 0, 0, 0) 0.500000001rem);
  min-height: 0.500000001rem; }

.storage-bar .trough {
  box-shadow: 0 2px 3px -1px rgba(0, 0, 0, 0.15); }

.storage-bar .fill-block {
  background-image: linear-gradient(to bottom, #d4d4d4, #abacae);
  border: 1px solid rgba(0, 0, 0, 0.35);
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07);
  transition: all 200ms ease-in-out;
  padding: 0.6666666677rem 0.250000001rem; }
  .storage-bar .fill-block:not(:first-child) {
    border-left-width: 0; }
  .storage-bar .fill-block:first-child {
    border-top-left-radius: 0.250000001rem;
    border-bottom-left-radius: 0.250000001rem; }
  .storage-bar .fill-block:last-child {
    border-top-right-radius: 0.250000001rem;
    border-bottom-right-radius: 0.250000001rem; }
  .storage-bar .fill-block.legend {
    padding: 0.6666666677rem;
    border-radius: 50%; }
  .storage-bar .fill-block.empty-block, .storage-bar .fill-block.unused {
    background-image: linear-gradient(to bottom, #ededed, #d4d4d4);
    border-color: rgba(0, 0, 0, 0.25); }
  .storage-bar .fill-block.app {
    background-image: linear-gradient(to bottom, #a56de2, #7239b3);
    border-color: rgba(69, 41, 129, 0.8); }
  .storage-bar .fill-block.audio {
    background-image: linear-gradient(to bottom, #ffa154, #f37329);
    border-color: rgba(204, 59, 2, 0.8); }
  .storage-bar .fill-block.files {
    background-image: linear-gradient(to bottom, #64baff, #3689e6);
    border-color: rgba(13, 82, 191, 0.8); }
  .storage-bar .fill-block.photo {
    background-image: linear-gradient(to bottom, #ffe16b, #f9c440);
    border-color: rgba(212, 142, 21, 0.8); }
  .storage-bar .fill-block.video {
    background-image: linear-gradient(to bottom, #ed5353, #c6262e);
    border-color: rgba(161, 7, 5, 0.8); }

switch {
  background-color: rgba(0, 0, 0, 0.05);
  border: 1px solid rgba(0, 0, 0, 0.3);
  box-shadow: 0 1px 0 0 alpha(@highlight_color, 0.3), inset 0 1px 1px rgba(0, 0, 0, 0.05), inset 0 0 1px 1px rgba(0, 0, 0, 0.05);
  border-radius: 1.3333333343rem;
  transition: all 100ms cubic-bezier(0.4, 0, 0.2, 1);
  background-color: rgba(0, 0, 0, 0.1); }
  switch:checked:not(.mode-switch):not(:backdrop) {
    background-color: @accent_color;
    background-clip: padding-box; }
    switch:checked:not(.mode-switch):not(:backdrop) slider {
      box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px rgba(0, 0, 0, 0.5), 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24); }
    switch:checked:not(.mode-switch):not(:backdrop):disabled {
      box-shadow: 0 1px 0 0 alpha(@highlight_color, 0.3), inset 0 1px 1px rgba(0, 0, 0, 0.05);
      background-image: none;
      background-color: mix(@theme_bg_color, @accent_color, 0.5);
      border-color: shade(mix(@theme_bg_color, @accent_color, 0.5), 0.5); }
  switch image {
    color: transparent; }
  switch slider {
    background-color: #404040;
    background-clip: padding-box;
    border-radius: 99px;
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px rgba(0, 0, 0, 0.3), 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
    min-height: 2.000000001rem;
    min-width: 2.000000001rem; }
  switch.mode-switch slider {
    min-height: 1.3333333343rem;
    min-width: 1.3333333343rem; }
  switch:disabled {
    background-color: rgba(0, 0, 0, 0.075);
    box-shadow: 0 1px 0 0 alpha(@highlight_color, 0.3), inset 0 1px 1px rgba(0, 0, 0, 0.05); }
    switch:disabled slider {
      background-color: #313131;
      box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px rgba(0, 0, 0, 0.15), 0 1px 1px rgba(0, 0, 0, 0.07), 0 1px 2px rgba(0, 0, 0, 0.08); }
  switch:focus-visible {
    color: @selected_fg_color;
    outline-color: alpha(@accent_color, 0.3);
    outline-width: 0.1666666677rem;
    outline-style: solid; }
    switch:focus-visible slider {
      color: @selected_fg_color;
      outline-color: alpha(@accent_color, 0.3);
      outline-width: 0.250000001rem;
      outline-style: solid; }

.app-notification {
  padding: 0; }
  .app-notification button.flat.image-button, .app-notification .sidebar .inline-toolbar button.image-button, .app-notification .sidebar actionbar.flat button.image-button,
  .app-notification .sidebar .bottom-toolbar.flat button.image-button,
  .app-notification .sidebar window.preferences.csd headerbar.bottom-toolbar button.image-button,
  window.preferences.csd .app-notification .sidebar headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar .dialog.csd > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.image-button,
  bottom-sheet .app-notification .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.image-button,
  floating-sheet .app-notification .sidebar sheet > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar dialog.csd.about > headerbar.bottom-toolbar button.image-button,
  .app-notification .sidebar window.csd.about > headerbar.bottom-toolbar button.image-button,
  popover.emoji-picker .app-notification .sidebar .emoji-toolbar button.bottom-toolbar button.image-button, .sidebar .inline-toolbar .app-notification button.image-button, .sidebar actionbar.flat .app-notification button.image-button,
  .sidebar .bottom-toolbar.flat .app-notification button.image-button,
  .sidebar window.preferences.csd headerbar.bottom-toolbar .app-notification button.image-button,
  window.preferences.csd .sidebar headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar .dialog.csd > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar dialog.csd.about > headerbar.bottom-toolbar .app-notification button.image-button,
  .sidebar window.csd.about > headerbar.bottom-toolbar .app-notification button.image-button, .app-notification .sidebar popover.emoji-picker .emoji-toolbar button.image-button, .sidebar popover.emoji-picker .emoji-toolbar .app-notification button.image-button, .app-notification popover.emoji-picker .sidebar .emoji-toolbar button.image-button, popover.emoji-picker .sidebar .emoji-toolbar .app-notification button.image-button {
    background: white;
    border-radius: 50%;
    padding: 0.3333333343rem; }
  .app-notification box > label {
    margin: 0;
    text-shadow: 0 1px 2px rgba(255, 255, 255, 0.6); }

.inline-toolbar, actionbar.flat,
.bottom-toolbar.flat,
window.preferences.csd headerbar.bottom-toolbar,
.dialog.csd > headerbar.bottom-toolbar,
bottom-sheet sheet.dialog > headerbar.bottom-toolbar,
floating-sheet sheet.dialog > headerbar.bottom-toolbar,
bottom-sheet sheet.csd > headerbar.bottom-toolbar,
bottom-sheet sheet > headerbar.bottom-toolbar,
floating-sheet sheet.csd > headerbar.bottom-toolbar,
floating-sheet sheet > headerbar.bottom-toolbar,
dialog.csd.about > headerbar.bottom-toolbar,
window.csd.about > headerbar.bottom-toolbar,
.sidebar .inline-toolbar button.bottom-toolbar,
.sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar,
popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar, popover.emoji-picker .emoji-toolbar {
  background-color: #333;
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.3) 1px, rgba(0, 0, 0, 0.07) 1px, transparent 0.250000001rem);
  box-shadow: none; }
  .inline-toolbar:backdrop, actionbar.flat:backdrop,
  .bottom-toolbar.flat:backdrop,
  window.preferences.csd headerbar.bottom-toolbar:backdrop,
  .dialog.csd > headerbar.bottom-toolbar:backdrop,
  bottom-sheet sheet > headerbar.bottom-toolbar:backdrop,
  floating-sheet sheet > headerbar.bottom-toolbar:backdrop,
  dialog.csd.about > headerbar.bottom-toolbar:backdrop,
  window.csd.about > headerbar.bottom-toolbar:backdrop,
  .sidebar .inline-toolbar button.bottom-toolbar:backdrop,
  .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar:backdrop,
  popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar:backdrop, popover.emoji-picker .emoji-toolbar:backdrop {
    background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.3) 1px, rgba(0, 0, 0, 0.04) 1px, transparent 0.250000001rem);
    box-shadow: none; }
  .sidebar .inline-toolbar, .sidebar actionbar.flat,
  .sidebar .bottom-toolbar.flat,
  .sidebar window.preferences.csd headerbar.bottom-toolbar,
  window.preferences.csd .sidebar headerbar.bottom-toolbar,
  .sidebar .dialog.csd > headerbar.bottom-toolbar,
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar,
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar,
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar,
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar,
  .sidebar dialog.csd.about > headerbar.bottom-toolbar,
  .sidebar window.csd.about > headerbar.bottom-toolbar,
  .sidebar .inline-toolbar button.bottom-toolbar,
  .sidebar popover.emoji-picker .emoji-toolbar button.bottom-toolbar,
  popover.emoji-picker .sidebar .emoji-toolbar button.bottom-toolbar, .sidebar popover.emoji-picker .emoji-toolbar, popover.emoji-picker .sidebar .emoji-toolbar {
    background-color: #2b2b2b;
    background-image: linear-gradient(to bottom, @menu_separator 1px, rgba(0, 0, 0, 0.04) 1px, transparent 0.250000001rem);
    padding: 0.250000001rem 0.500000001rem; }

actionbar,
.bottom-toolbar {
  background-color: @color_primary;
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px alpha(shade(@color_primary, 0.7), 0.4), 0 -0.0833333343rem 0.1666666677rem rgba(0, 0, 0, 0.2);
  padding: 0.250000001rem 0.500000001rem;
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px alpha(shade(@color_primary, 0.5), 0.5), 0 -0.0833333343rem 0.0833333343rem rgba(0, 0, 0, 0.2);
  /* Workaround for border */ }
  revealer > actionbar, revealer > .bottom-toolbar {
    margin-top: 1px; }
  actionbar:backdrop,
  .bottom-toolbar:backdrop {
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px alpha(shade(@color_primary, 0.7), 0.3), 0 -0.0833333343rem 0.0833333343rem rgba(0, 0, 0, 0.15); }

tooltip {
  padding: 0.500000001rem;
  border-radius: 0.250000001rem;
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.42), 0 1px 2px rgba(0, 0, 0, 0.44);
  margin: 0.250000001rem; }
  tooltip.background {
    background-color: rgba(26, 26, 26, 0.9);
    color: white; }
    tooltip.background label {
      text-shadow: 0 0.0833333343rem 0.1666666677rem rgba(0, 0, 0, 0.6);
      -gtk-icon-shadow: 0 0.0833333343rem 0.1666666677rem rgba(0, 0, 0, 0.6); }

treeview.view.cell:selected {
  background: rgba(255, 255, 255, 0.15); }

treeview entry.flat {
  padding: 0.3333333343rem 0.0833333343rem;
  background: inherit; }

treeview header button {
  border-left-width: 0;
  border-radius: 0;
  border-top-width: 0; }
  treeview header button:last-child {
    border-right-width: 0; }
  treeview header button label {
    font-weight: bold;
    opacity: 0.8; }
  treeview header button:backdrop label {
    opacity: 0.6; }
  treeview header button sort-indicator {
    min-height: 16px;
    min-width: 16px; }
    treeview header button sort-indicator.ascending {
      -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
    treeview header button sort-indicator.descending {
      -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

frame,
.frame,
list.boxed-list {
  border: 1px solid rgba(0, 0, 0, 0.75); }
  frame.flat,
  .frame.flat,
  window.preferences.csd headerbar.frame,
  list.flat.boxed-list,
  .dialog.csd > headerbar.frame,
  bottom-sheet sheet.dialog > headerbar.frame,
  floating-sheet sheet.dialog > headerbar.frame,
  bottom-sheet sheet.csd > headerbar.frame,
  bottom-sheet sheet > headerbar.frame,
  floating-sheet sheet.csd > headerbar.frame,
  floating-sheet sheet > headerbar.frame,
  dialog.csd.about > headerbar.frame,
  window.csd.about > headerbar.frame,
  .sidebar .inline-toolbar button.frame,
  .sidebar popover.emoji-picker .emoji-toolbar button.frame,
  popover.emoji-picker .sidebar .emoji-toolbar button.frame,
  .sidebar actionbar.flat button.frame,
  .sidebar .bottom-toolbar.flat button.frame,
  .sidebar window.preferences.csd headerbar.bottom-toolbar button.frame,
  window.preferences.csd .sidebar headerbar.bottom-toolbar button.frame,
  .sidebar .dialog.csd > headerbar.bottom-toolbar button.frame,
  .sidebar bottom-sheet sheet > headerbar.bottom-toolbar button.frame,
  bottom-sheet .sidebar sheet > headerbar.bottom-toolbar button.frame,
  .sidebar floating-sheet sheet > headerbar.bottom-toolbar button.frame,
  floating-sheet .sidebar sheet > headerbar.bottom-toolbar button.frame,
  .sidebar dialog.csd.about > headerbar.bottom-toolbar button.frame,
  .sidebar window.csd.about > headerbar.bottom-toolbar button.frame {
    border-style: none; }

iconview.view.cell {
  border-radius: 0.250000001rem; }
  iconview.view.cell:selected {
    background: rgba(255, 255, 255, 0.15); }

gridview child,
flowboxchild {
  border-radius: 0.250000001rem; }
  gridview child:focus-visible, gridview child:selected,
  flowboxchild:focus-visible,
  flowboxchild:selected {
    background: rgba(255, 255, 255, 0.15); }

scrolledwindow > viewport.frame {
  border-style: none; }

.view {
  background: @base_color;
  color: white;
  -gtk-secondary-caret-color: @selected_bg_color; }
  .view:disabled {
    background: rgba(0, 0, 0, 0.075);
    color: #999999; }

scrolledwindow.terminal viewport {
  padding: 1.000000001rem; }

.terminal {
  background-color: #252e32;
  border-radius: 0.250000001rem;
  color: #94a3a5;
  font-family: monospace; }
  .terminal selection, .terminal dialog.about .main-page .app-version, dialog.about .main-page .terminal .app-version,
  .terminal window.about .main-page .app-version,
  .terminal bottom-sheet sheet.about .main-page .app-version,
  bottom-sheet .terminal sheet.about .main-page .app-version,
  .terminal floating-sheet sheet.about .main-page .app-version,
  floating-sheet .terminal sheet.about .main-page .app-version,
  window.about .main-page .terminal .app-version,
  bottom-sheet sheet.about .main-page .terminal .app-version,
  floating-sheet sheet.about .main-page .terminal .app-version, .terminal .badge.flat, .terminal window.preferences.csd headerbar.badge, window.preferences.csd .terminal headerbar.badge, .terminal button.flat:focus-visible, .terminal button.image-button:not(.text-button):focus-visible, .terminal .linked button.flat.suggested-action:not(:disabled), .linked .terminal button.flat.suggested-action:not(:disabled), .terminal .linked button.image-button.suggested-action:not(:disabled), .linked .terminal button.image-button.suggested-action:not(:disabled), .terminal button.circular.image-button.suggested-action:not(:disabled), .terminal button.model.image-button.suggested-action:not(:disabled), .terminal button.raised.suggested-action:not(:disabled), .terminal .messagedialog .response-area button.suggested-action:not(:disabled), .messagedialog .response-area .terminal button.suggested-action:not(:disabled), .terminal button.suggested-action:not(:disabled), .terminal .linked button.flat.suggested:not(:disabled), .linked .terminal button.flat.suggested:not(:disabled), .terminal .linked button.suggested:not(.text-button):not(:disabled), .linked .terminal button.suggested:not(.text-button):not(:disabled), .terminal button.image-button.suggested:not(:disabled), .terminal button.raised.suggested:not(:disabled), .terminal .messagedialog .response-area button.suggested:not(:disabled), .messagedialog .response-area .terminal button.suggested:not(:disabled), .terminal button.suggested:not(:disabled), .terminal calendar.view .day-number:selected, calendar.view .terminal .day-number:selected, .terminal dropdown popover listview row.activatable image:last-child, dropdown popover listview row.activatable .terminal image:last-child, .terminal .dialog.csd > headerbar.badge, .terminal bottom-sheet sheet > headerbar.badge, bottom-sheet .terminal sheet > headerbar.badge,
  .terminal floating-sheet sheet > headerbar.badge,
  floating-sheet .terminal sheet > headerbar.badge, .terminal dialog.csd.about > headerbar.badge,
  .terminal window.csd.about > headerbar.badge, .terminal list row:focus-visible:selected, list .terminal row:focus-visible:selected,
  .terminal listview row:focus-visible:selected,
  listview .terminal row:focus-visible:selected, .terminal .sidebar .inline-toolbar button.badge, .sidebar .inline-toolbar .terminal button.badge, .terminal .sidebar popover.emoji-picker .emoji-toolbar button.badge, .sidebar popover.emoji-picker .emoji-toolbar .terminal button.badge, .terminal popover.emoji-picker .sidebar .emoji-toolbar button.badge, popover.emoji-picker .sidebar .emoji-toolbar .terminal button.badge, .terminal .sidebar .inline-toolbar button:focus-visible, .sidebar .inline-toolbar .terminal button:focus-visible, .terminal .sidebar popover.emoji-picker .emoji-toolbar button:focus-visible, .sidebar popover.emoji-picker .emoji-toolbar .terminal button:focus-visible, .terminal popover.emoji-picker .sidebar .emoji-toolbar button:focus-visible, popover.emoji-picker .sidebar .emoji-toolbar .terminal button:focus-visible, .terminal .linked .sidebar .inline-toolbar button.suggested-action:not(:disabled), .linked .sidebar .inline-toolbar .terminal button.suggested-action:not(:disabled), .terminal .sidebar .inline-toolbar .linked button.suggested-action:not(:disabled), .sidebar .inline-toolbar .linked .terminal button.suggested-action:not(:disabled), .terminal .linked .sidebar popover.emoji-picker .emoji-toolbar button.suggested-action:not(:disabled), .linked .sidebar popover.emoji-picker .emoji-toolbar .terminal button.suggested-action:not(:disabled), .terminal .sidebar popover.emoji-picker .emoji-toolbar .linked button.suggested-action:not(:disabled), .sidebar popover.emoji-picker .emoji-toolbar .linked .terminal button.suggested-action:not(:disabled), .terminal .linked popover.emoji-picker .sidebar .emoji-toolbar button.suggested-action:not(:disabled), .linked popover.emoji-picker .sidebar .emoji-toolbar .terminal button.suggested-action:not(:disabled), .terminal popover.emoji-picker .sidebar .emoji-toolbar .linked button.suggested-action:not(:disabled), popover.emoji-picker .sidebar .emoji-toolbar .linked .terminal button.suggested-action:not(:disabled), .terminal treeview.view.cell:focus-visible:selected, .terminal iconview.view.cell:focus-visible:selected, .terminal gridview child:focus-visible:selected, gridview .terminal child:focus-visible:selected,
  .terminal flowboxchild:focus-visible:selected {
    background-color: #93a1a1;
    color: #252e32; }

rubberband {
  background-color: alpha(@accent_color, 0.15);
  border: 1px solid alpha(@accent_color, 0.5);
  border-radius: 0.250000001rem; }

windowcontrols.end:dir(ltr), windowcontrols.start:dir(rtl) {
  margin-left: 1.000000001rem; }

windowcontrols.start:dir(ltr), windowcontrols.end:dir(rtl) {
  margin-right: 1.000000001rem; }

windowcontrols button {
  background: none;
  border-color: transparent;
  border-radius: 0.500000001rem;
  box-shadow: none;
  padding: 0.3333333343rem; }
  windowcontrols button:active {
    background: rgba(255, 255, 255, 0.15);
    border-color: transparent;
    box-shadow: none; }

.background,
.gtkstyle-fallback {
  background-color: #333;
  color: white; }

window.csd, bottom-sheet sheet,
floating-sheet sheet {
  border-radius: 0.500000001rem;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.75), 0 13px 16px 4px transparent, 0 2px 4px 2px rgba(0, 0, 0, 0.2), 0 15px 12px -10px rgba(0, 0, 0, 0.5), 0 8px 14px 4px rgba(0, 0, 0, 0.25); }
  window.csd:backdrop, bottom-sheet sheet:backdrop,
  floating-sheet sheet:backdrop {
    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.75), 0 13px 16px 4px transparent, 0 3px 4px rgba(0, 0, 0, 0.25), 0 3px 3px -3px rgba(0, 0, 0, 0.45); }
  window.csd.maximized, bottom-sheet sheet.maximized,
  floating-sheet sheet.maximized {
    box-shadow: 0 0 0 0.250000001rem black; }
  window.csd.tiled-right:not(.maximized), bottom-sheet sheet.tiled-right:not(.maximized),
  floating-sheet sheet.tiled-right:not(.maximized), window.csd.tiled-left:not(.maximized), bottom-sheet sheet.tiled-left:not(.maximized),
  floating-sheet sheet.tiled-left:not(.maximized) {
    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.75), 0 13px 16px 4px transparent, 0 3px 4px rgba(0, 0, 0, 0.25), 0 3px 3px -3px rgba(0, 0, 0, 0.45); }
  window.csd.tiled-right:not(.maximized).tiled-top, bottom-sheet sheet.tiled-right:not(.maximized).tiled-top,
  floating-sheet sheet.tiled-right:not(.maximized).tiled-top {
    border-top-left-radius: 0; }
  window.csd.tiled-right:not(.maximized).tiled-bottom, bottom-sheet sheet.tiled-right:not(.maximized).tiled-bottom,
  floating-sheet sheet.tiled-right:not(.maximized).tiled-bottom {
    border-bottom-left-radius: 0; }
  window.csd.tiled-left:not(.maximized).tiled-top, bottom-sheet sheet.tiled-left:not(.maximized).tiled-top,
  floating-sheet sheet.tiled-left:not(.maximized).tiled-top {
    border-top-right-radius: 0; }
  window.csd.tiled-left:not(.maximized).tiled-bottom, bottom-sheet sheet.tiled-left:not(.maximized).tiled-bottom,
  floating-sheet sheet.tiled-left:not(.maximized).tiled-bottom {
    border-bottom-right-radius: 0; }
  window.csd.fullscreen, bottom-sheet sheet.fullscreen,
  floating-sheet sheet.fullscreen {
    border-radius: 0; }

window.ssd, bottom-sheet sheet.ssd,
floating-sheet sheet.ssd {
  border-radius: 6px 6px 0 0;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.75); }

window.dialog, window.preferences.csd, bottom-sheet sheet,
floating-sheet sheet {
  border-radius: 0;
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07); }
  window.dialog.csd, window.csd.preferences, bottom-sheet sheet,
  floating-sheet sheet {
    border-radius: 0.500000001rem;
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px rgba(0, 0, 0, 0.75), 0 13px 16px 4px transparent, 0 3px 8px 2px rgba(0, 0, 0, 0.2), 0 5px 5px -3px rgba(0, 0, 0, 0.5), 0 8px 5px 1px rgba(0, 0, 0, 0.2); }
    window.dialog.csd:backdrop, window.csd.preferences:backdrop, bottom-sheet sheet:backdrop,
    floating-sheet sheet:backdrop {
      box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px rgba(0, 0, 0, 0.75), 0 13px 16px 4px transparent, 0 3px 4px rgba(0, 0, 0, 0.25), 0 3px 3px -3px rgba(0, 0, 0, 0.45); }
  window.dialog .dialog-content-area, window.preferences.csd .dialog-content-area, bottom-sheet sheet .dialog-content-area,
  floating-sheet sheet .dialog-content-area {
    margin: 1.000000001rem;
    margin-top: 1.500000001rem; }
  window.dialog .dialog-action-area, window.preferences.csd .dialog-action-area, bottom-sheet sheet .dialog-action-area,
  floating-sheet sheet .dialog-action-area {
    margin: 1.000000001rem; }
  window.dialog.message .dialog-content-area box + expander-widget, window.message.preferences.csd .dialog-content-area box + expander-widget, bottom-sheet sheet.message .dialog-content-area box + expander-widget,
  floating-sheet sheet.message .dialog-content-area box + expander-widget {
    margin-bottom: 6px; }
  window.dialog.message .dialog-action-area, window.message.preferences.csd .dialog-action-area, bottom-sheet sheet.message .dialog-action-area,
  floating-sheet sheet.message .dialog-action-area {
    margin-top: 1.3333333343rem; }

/******************
 * AdwAboutWindow *
 ******************/
dialog.about .main-page > viewport > clamp > box,
window.about .main-page > viewport > clamp > box,
bottom-sheet sheet.about .main-page > viewport > clamp > box,
floating-sheet sheet.about .main-page > viewport > clamp > box {
  border-spacing: 0.500000001rem;
  margin: 1.000000001rem; }
  dialog.about .main-page > viewport > clamp > box > box,
  window.about .main-page > viewport > clamp > box > box,
  bottom-sheet sheet.about .main-page > viewport > clamp > box > box,
  floating-sheet sheet.about .main-page > viewport > clamp > box > box {
    border-spacing: 1.500000001rem;
    margin-top: 1.500000001rem; }

dialog.about .main-page .app-version,
window.about .main-page .app-version,
bottom-sheet sheet.about .main-page .app-version,
floating-sheet sheet.about .main-page .app-version {
  border: none;
  border-radius: 999px;
  box-shadow: none;
  margin-top: 0.250000001rem; }

dialog.about .subpage > viewport > clamp > box,
window.about .subpage > viewport > clamp > box,
bottom-sheet sheet.about .subpage > viewport > clamp > box,
floating-sheet sheet.about .subpage > viewport > clamp > box {
  border-spacing: 1.500000001rem;
  margin: 1.500000001rem 1.000000001rem; }

dialog.about .subpage > clamp > textview,
window.about .subpage > clamp > textview,
bottom-sheet sheet.about .subpage > clamp > textview,
floating-sheet sheet.about .subpage > clamp > textview {
  background: none;
  color: inherit; }

bottom-sheet > dimming,
floating-sheet > dimming {
  background: rgba(0, 0, 0, 0.4); }

bottom-sheet sheet {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0; }
  bottom-sheet sheet > stack > widget > drag-handle {
    background: rgba(255, 255, 255, 0.5);
    min-width: 3em;
    min-height: 0.5em;
    margin: 1em;
    border-radius: 1em; }

list.boxed-list {
  border-radius: 0.500000001rem;
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1); }
  list.boxed-list > row:first-child, list.boxed-list > row:first-child.expander row.header {
    border-top-left-radius: 0.500000001rem;
    border-top-right-radius: 0.500000001rem; }
  list.boxed-list > row:last-child, list.boxed-list > row:last-child.expander:not(:checked), list.boxed-list > row:last-child.expander:not(:checked) row.header, list.boxed-list > row:last-child.expander:checked list.nested, list.boxed-list > row:last-child.expander:checked list.nested > row:last-child {
    border-bottom-left-radius: 0.500000001rem;
    border-bottom-right-radius: 0.500000001rem;
    border-bottom-width: 0; }
  list.boxed-list > row .icon:dir(ltr),
  list.boxed-list > row .prefixes:dir(ltr) {
    margin-right: 0.250000001rem; }
  list.boxed-list > row .icon:dir(rtl),
  list.boxed-list > row .prefixes:dir(rtl) {
    margin-left: 0.250000001rem; }
  list.boxed-list > row .prefixes,
  list.boxed-list > row .suffixes {
    border-spacing: 0.500000001rem; }
  list.boxed-list > row .title + .subtitle {
    margin-top: 0.25em; }
  list.boxed-list > row box.header {
    padding: 0.500000001rem 0.750000001rem;
    min-height: 2.6666666677rem; }
  list.boxed-list > row:not(.separator) + row:not(.separator) {
    border-top: 1px solid @menu_separator; }
  list.boxed-list row.entry .edit-icon,
  list.boxed-list row.entry .indicator {
    min-width: 2.000000001rem; }
  list.boxed-list row.entry .edit-icon {
    opacity: 0; }
  list.boxed-list row.entry:hover:not(:focus-within) .edit-icon {
    opacity: 1; }
  list.boxed-list row.expander image.expander-row-arrow {
    transition: all 100ms cubic-bezier(0.4, 0, 0.2, 1); }
    list.boxed-list row.expander image.expander-row-arrow:dir(ltr) {
      -gtk-icon-transform: rotate(0.25turn); }
    list.boxed-list row.expander image.expander-row-arrow:dir(rtl) {
      -gtk-icon-transform: rotate(-0.25turn); }
  list.boxed-list row.expander:checked image.expander-row-arrow:dir(ltr) {
    -gtk-icon-transform: rotate(0.5turn); }
  list.boxed-list row.expander:checked image.expander-row-arrow:dir(rtl) {
    -gtk-icon-transform: rotate(-0.5turn); }
  list.boxed-list row.expander list {
    background: transparent; }

.messagedialog {
  padding: 1.000000001rem; }
  .messagedialog .message-area .title-2 {
    font-size: 1.22em;
    font-weight: 500;
    margin-bottom: 0.25em; }
  .messagedialog separator {
    opacity: 0; }
  .messagedialog .response-area {
    margin-top: 1.500000001rem; }
    .messagedialog .response-area separator {
      min-height: 0.750000001rem;
      min-width: 0.500000001rem; }

window.preferences.csd preferencespage > scrolledwindow undershoot.top {
  background: linear-gradient(rgba(0, 0, 0, 0.75), rgba(0, 0, 0, 0.05) 1px, rgba(0, 0, 0, 0) 0.444rem); }

preferencespage > scrolledwindow > viewport > clamp > box {
  margin: 2.000000001rem 1.000000001rem;
  border-spacing: 2em; }

preferencesgroup > box, preferencesgroup > box box.labels {
  border-spacing: 0.500000001rem; }

preferencesgroup > box > box.header:not(.single-line) {
  margin-bottom: 0.500000001rem; }

preferencesgroup > box row.button,
preferencesgroup > box > box.single-line {
  min-height: 34px; }

preferencesgroup > box label.h4, popover.emoji-picker scrolledwindow.view preferencesgroup > box.vertical > label, preferencesgroup > box shortcuts-group > label {
  font-weight: 700; }

statuspage > scrolledwindow > viewport > box {
  margin: 3.000000001rem 1.000000001rem;
  border-spacing: 3.000000001rem; }
  statuspage > scrolledwindow > viewport > box > clamp > box {
    border-spacing: 1.000000001rem; }
    statuspage > scrolledwindow > viewport > box > clamp > box > .icon {
      -gtk-icon-size: 128px; }
      statuspage > scrolledwindow > viewport > box > clamp > box > .icon:not(:last-child) {
        margin-bottom: 2.000000001rem; }

statuspage.compact > scrolledwindow > viewport > box {
  margin: 2.000000001rem 1.000000001rem;
  border-spacing: 2.000000001rem; }
  statuspage.compact > scrolledwindow > viewport > box > clamp > box > .icon {
    -gtk-icon-size: 96px; }
    statuspage.compact > scrolledwindow > viewport > box > clamp > box > .icon:not(:last-child) {
      margin-bottom: 1.000000001rem; }
  statuspage.compact > scrolledwindow > viewport > box > clamp > box > .title {
    font-size: 18pt; }

toolbarview.undershoot-top scrolledwindow overshoot.top {
  background: linear-gradient(to top, alpha(@accent_color, 0) 80%, alpha(@accent_color, 0.25) 100%), linear-gradient(to bottom, @borders, rgba(0, 0, 0, 0.05) 1px, rgba(0, 0, 0, 0) 0.250000001rem); }
  toolbarview.undershoot-top scrolledwindow overshoot.top:backdrop {
    background: linear-gradient(to top, rgba(255, 255, 255, 0) 80%, rgba(255, 255, 255, 0.15) 100%), linear-gradient(to bottom, @borders, rgba(0, 0, 0, 0.05) 1px, rgba(0, 0, 0, 0) 0.250000001rem); }

toolbarview.undershoot-top scrolledwindow undershoot.top {
  background: linear-gradient(to bottom, @borders, rgba(0, 0, 0, 0.05) 1px, rgba(0, 0, 0, 0) 0.250000001rem); }

toolbarview.undershoot-bottom scrolledwindow overshoot.bottom {
  background: linear-gradient(to bottom, alpha(@accent_color, 0) 80%, alpha(@accent_color, 0.25) 100%), linear-gradient(to top, @borders, rgba(0, 0, 0, 0.05) 1px, rgba(0, 0, 0, 0) 0.250000001rem); }
  toolbarview.undershoot-bottom scrolledwindow overshoot.bottom:backdrop {
    background: linear-gradient(to bottom, rgba(255, 255, 255, 0) 80%, rgba(255, 255, 255, 0.15) 100%), linear-gradient(to bottom, @borders, rgba(0, 0, 0, 0.05) 1px, rgba(0, 0, 0, 0) 0.250000001rem); }

toolbarview.undershoot-bottom scrolledwindow undershoot.bottom {
  background: linear-gradient(to top, @borders, rgba(0, 0, 0, 0.05) 1px, rgba(0, 0, 0, 0) 0.250000001rem); }

toolbarview revealer.top-bar headerbar,
toolbarview revealer.top-bar headerbar:backdrop,
toolbarview revealer.bottom-bar actionbar,
toolbarview revealer.bottom-bar actionbar:backdrop {
  background: inherit;
  box-shadow: none;
  border-radius: 0; }

toolbarview revealer.top-bar.raised, toolbarview .messagedialog .response-area button.top-bar, .messagedialog .response-area toolbarview button.top-bar {
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 1px 0 0 alpha(@borders, 0.4), 0 1px 0.1666666677rem rgba(0, 0, 0, 0.2); }
  toolbarview revealer.top-bar.raised:backdrop, toolbarview .messagedialog .response-area button.top-bar:backdrop, .messagedialog .response-area toolbarview button.top-bar:backdrop {
    box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px alpha(@borders, 0.3), 0 1px 0.1666666677rem rgba(0, 0, 0, 0.15); }

toolbarview revealer.top-bar.raised.border, toolbarview .messagedialog .response-area button.top-bar.border, .messagedialog .response-area toolbarview button.top-bar.border {
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 1px 0 0 alpha(@borders, 0.8); }

toolbarview revealer.bottom-bar.raised, toolbarview .messagedialog .response-area button.bottom-bar, .messagedialog .response-area toolbarview button.bottom-bar {
  background-color: rgba(0, 0, 0, 0.01);
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.3) 1px, rgba(0, 0, 0, 0.07) 1px, transparent 0.250000001rem);
  box-shadow: 0 -1px alpha(@highlight_color, 0.2); }
  toolbarview revealer.bottom-bar.raised:backdrop, toolbarview .messagedialog .response-area button.bottom-bar:backdrop, .messagedialog .response-area toolbarview button.bottom-bar:backdrop {
    background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.3) 1px, rgba(0, 0, 0, 0.04) 1px, transparent 0.250000001rem);
    box-shadow: none; }

toolbarview revealer.bottom-bar.raised.border, toolbarview .messagedialog .response-area button.bottom-bar.border, .messagedialog .response-area toolbarview button.bottom-bar.border {
  background: rgba(0, 0, 0, 0.03);
  box-shadow: 0 -1px @borders, inset 0 1px alpha(@highlight_color, 0.3); }

toolbarview revealer.bottom-bar actionbar {
  padding: 0.500000001rem; }

tabbar {
  background-color: shade(@tab_base_color, 0.95);
  background-color: shade(@tab_base_color, 0.87);
  background-image: linear-gradient(to bottom, shade(@color_primary, 0.7), rgba(0, 0, 0, 0.1) 1px, transparent 0.1666666677rem);
  background-image: linear-gradient(to bottom, shade(@color_primary, 0.5), rgba(0, 0, 0, 0.1) 1px, transparent 0.1666666677rem); }
  tabbar .box {
    margin-top: 0.1666666677rem;
    padding-bottom: 0.1666666677rem; }
    tabbar .box tabbox {
      background: transparent; }
  tabbar tab {
    background-clip: padding-box;
    margin: 1px;
    min-height: 24px; }
  tabbar tabbox > separator.vertical {
    margin: 6px 0;
    border-right: none;
    transition: opacity 150ms ease-in; }
    tabbar tabbox > separator.vertical.hidden {
      opacity: 0; }
  tabbar .start-action button,
  tabbar .end-action button {
    margin: 0.250000001rem;
    padding: 0.250000001rem 0.500000001rem; }

.tab-drag-icon tab {
  box-shadow: inset 0 -1px 0 0 alpha(@highlight_color, 0.2), inset 0 1px 0 0 alpha(@highlight_color, 0.3), inset 1px 0 0 0 alpha(@highlight_color, 0.07), inset -1px 0 0 0 alpha(@highlight_color, 0.07), 0 0 0 1px rgba(0, 0, 0, 0.24), 0 1px 3px rgba(0, 0, 0, 0.42), 0 1px 2px rgba(0, 0, 0, 0.44);
  margin: 12px; }

toolbarview revealer.top-bar tabbar {
  box-shadow: 0 -1px alpha(@highlight_color, 0.2);
  background-image: linear-gradient(to bottom, @borders, alpha(@borders, 0.5) 1px, transparent 0.1666666677rem); }
  toolbarview revealer.top-bar tabbar .box {
    background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0), rgba(0, 0, 0, 0) calc(100% - 2px), alpha(@borders, 0.05) calc(100% - 1px), alpha(@borders, 0.25)); }

taboverview tabthumbnail .card {
  border-radius: 0.500000001rem;
  margin: 1.000000001rem; }
  taboverview tabthumbnail .card button.circular {
    background: rgba(255, 255, 255, 0.9);
    border: none;
    color: #3a3a3a;
    box-shadow: 0 1px 3px rgba(0, 0, 0, 0.42), 0 1px 2px rgba(0, 0, 0, 0.44);
    margin: 0.250000001rem; }

taboverview tabthumbnail.pinned .card {
  padding: 1.000000001rem; }
  taboverview tabthumbnail.pinned .card .tab-unpin-icon.left {
    margin-right: 0.500000001rem; }
  taboverview tabthumbnail.pinned .card .tab-unpin-icon.right {
    margin-left: 0.500000001rem; }

taboverview .new-tab-button {
  margin: 1.000000001rem; }

toastoverlay toast {
  border-spacing: 0.500000001rem;
  margin: 1.000000001rem; }
  toastoverlay toast > widget {
    margin: 0 0.500000001rem; }

viewswitcher button stack > box {
  border-spacing: 0.5em; }
  viewswitcher button stack > box label.active {
    font-weight: bold; }
  viewswitcher button stack > box.narrow {
    padding-top: 0.250000001rem;
    padding-bottom: 0.250000001rem; }
    viewswitcher button stack > box.narrow image, viewswitcher button stack > box.narrow label {
      padding-left: 0.500000001rem;
      padding-right: 0.500000001rem; }
  viewswitcher button stack > box.wide {
    padding: 0 9px; }

headerbar viewswitcher button {
  border-radius: 0.250000001rem; }

viewswitcherbar actionbar {
  background: transparent;
  box-shadow: none;
  padding: 0; }

viewswitcherbar revealer > box {
  border-top: 1px solid rgba(0, 0, 0, 0.75); }
  viewswitcherbar revealer > box viewswitcher button {
    margin: 0;
    border-radius: 0;
    border-top: 0;
    border-bottom: 0;
    box-shadow: none; }
    viewswitcherbar revealer > box viewswitcher button:not(:checked):not(:hover) {
      background: transparent; }
    viewswitcherbar revealer > box viewswitcher button:not(:only-child):not(:last-child) {
      border-right-width: 0; }
    viewswitcherbar revealer > box viewswitcher button:not(only-child):first-child:not(:checked):not(:hover), viewswitcherbar revealer > box viewswitcher button:not(:checked):not(:hover) + viewswitcherbar revealer > box viewswitcher button:not(:checked):not(:hover) {
      border-left-color: transparent; }
    viewswitcherbar revealer > box viewswitcher button:not(only-child):last-child:not(:checked):not(:hover) {
      border-right-color: transparent; }
    viewswitcherbar revealer > box viewswitcher button:not(only-child):first-child:not(:checked):hover, viewswitcherbar revealer > box viewswitcher button:not(:checked):hover + viewswitcherbar revealer > box viewswitcher button:not(:checked):not(:hover), viewswitcherbar revealer > box viewswitcher button:not(:checked):not(:hover) + viewswitcherbar revealer > box viewswitcher button:not(:checked):hover {
      border-left-color: shade(@color_primary, 1.15); }
    viewswitcherbar revealer > box viewswitcher button:not(only-child):last-child:not(:checked):hover {
      border-right-color: shade(@color_primary, 1.15); }
    viewswitcherbar revealer > box viewswitcher button:not(:checked):hover:not(:backdrop) {
      background-image: linear-gradient(to top, shade(alpha(@color_primary, 0.7), 0.96) 0.1666666677rem, alpha(@color_primary, 0.7)); }
    viewswitcherbar revealer > box viewswitcher button:not(:checked):not(only-child):first-child:hover, viewswitcherbar revealer > box viewswitcher button:not(:checked):hover + viewswitcherbar revealer > box viewswitcher button:not(:checked):not(:hover), viewswitcherbar revealer > box viewswitcher button:not(:checked):not(:hover) + viewswitcherbar revealer > box viewswitcher button:not(:checked):hover {
      border-left-color: @color_primary; }
    viewswitcherbar revealer > box viewswitcher button:not(:checked):not(only-child):last-child:hover {
      border-right-color: @color_primary; }
    viewswitcherbar revealer > box viewswitcher button:not(:checked):hover:backdrop {
      background-image: image(@color_primary); }
    viewswitcherbar revealer > box viewswitcher button image {
      -gtk-icon-palette: error @text_color, success @text_color, warning @text_color; }
